/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2003 file and create a SAS dataset.                                                    *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\opafy03nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = opafy03nid ;

/***********************************************************************************/
/************** SHOULD NOT NEED TO CHANGE ANYTHING BELOW THIS POINT ****************/
/***********************************************************************************/

DATA library.&dataset ;
INFILE datafile LRECL=26660;
INPUT
   SAFETY $ 1-3             ZONE $ 4                 AMTFINEC  5-12        
   AMTREST  13-22           AMTTOTAL  23-32          COSTSUP  33-38        
   FINE  39-46              TOTREST  47-56           SENTTOT  57-62        
   SENTTOT0  63-68          SENSPLT  69-74           SENSPLT0  75-80       
   TIMESERV  81-87          USSCIDN  88-93           ACCAP  94             
   ACCCAT  95               ACCGDLN  96              ACCOFFLV  97-98       
   ACCTRESP  99-100         CAROFFAP  101            AGE  102-104          
   ALTDUM  105              ALTMO  106-107           AMENDYR  108-111      
   ARMCRIM  112-113         CAROFFEN  114-115        CAROFFLV  116-117     
   CHAP2  118-119           CIRCDIST  120-121        CITIZEN  122          
   CITWHERE  123-125        COADJLEV  126-127        COMBDRG2  128-129     
   COMDUM  130              COSTSDUM  131            CRIMHIST  132         
   CRIMLIV  133-134         CRIMPTS  135-137         DAYSDUM  138          
   DEFCONSL  139-140        DEPART  141              DISPOSIT  142         
   DISTRICT  143-144        DRUGTYP1  145-147        DRUGTYP2  148-150     
   DRUGTYP3  151-153        DRUGTYP4  154-156        DRUGTYP5  157-159     
   DSIND  160               DSJANDC  161             DSPLEA  162           
   DSPSR  163               DSSOR  164               DUFROM1  165-166      
   DUFROM2  167-168         DUFROM3  169             DUFROM4  170          
   DUFROM5  171             DUTO1  172-173           DUTO2  174-175        
   DUTO3  176               DUTO4  177               DUTO5  178            
   ECONDUM  179             EDUCATN  180-181         ENCRYPT1  182         
   ENCRYPT2  183            FINECDUM  184            FINEWAIV  185         
   HISPORIG  186            HOMDUM  187              HRCOMSRV  188-191     
   INOUT  192               INTDUM  193              IS924C  194           
   MARRIED  195             MOCOMCON  196-197        MOHOMDET  198-199     
   MOINTCON  200-201        MONACCEP  202-203        MONCIRC  204-205      
   MONRACE  206             MONSEX  207              NEWCIT  208           
   NEWCNVTN  209            NEWEDUC  210             NEWRACE  211          
   NOCOMP  212-213          NOCOUNTS  214-216        NOUSTAT  217-218      
   NUMDEPEN  219-220        OFFTYPE2  221-222        POINT1  223-224       
   POINT2  225-227          POINT3  228-229          PRESENT  230          
   PRISDUM  231             PROBATN  232-234         PROBDUM  235          
   RANGEPT  236             REASON1  237-239         REASON2  240-242      
   REASON3  243-245         REL2PTS  246             RESNTDOC  247-248     
   RESTDUM  249             SAFE  250                SENTIMP  251          
   SENTPTS  252             SEXOFFNA  253-254        SEXOFFNB  255-256     
   SOURCES  257             SUPRDUM  258             SUPREL  259-261       
   TOTCHPTS  262-263        SEXACCA  264-265         SEXACCB  266-267      
   TOTDAYS  268-269         TOTUNIT  270-280         TYPEMONY  281         
   TYPEOTHS  282-283        UNIT1  284-285           UNIT2  286-287        
   UNIT3  288-289           UNIT4  290-291           UNIT5  292-293        
   VIOL1PTS  294            WEAPON  295              WEAPSOC  296          
   XCRHISSR  297            XFOLSOR  298-299         YEARS  300            
   DRUGMIN  301-304         GLMIN  305-308           GLMAX  309-312        
   GUNMIN1  313-316         GUNMIN2  317-319         STATMAX  320-324      
   STATMIN  325-328         TOTPRISN  329-332        XMAXSOR  333-336      
   XMINSOR  337-340         SMIN1  341-344           SMIN2  345-348        
   SMIN3  349-352           SMIN4  353-356           SMIN5  357-360        
   SMIN6  361-364           SMIN7  365-368           SMIN8  369-371        
   SMIN9  372-374           SMIN10  375-378          SMIN11  379-382       
   SMIN12  383-385          SMIN13  386-388          SMIN14  389-391       
   SMIN15  392-395          SMIN16  396-398          SMIN17  399-401       
   SMIN18  402-404          SMIN19  405-407          SMIN20  408-411       
   SMIN21  412-414          SMIN22  415-417          SMIN23  418-420       
   SMIN24  421-423          SMIN25  424-426          SMIN26  427-429       
   SMIN27  430-431          SMIN28  432-433          SMIN29  434-435       
   SMIN30  436-437          SMIN31  438-440          SMIN32  441-442       
   SMIN33  443-444          SMIN34  445-446          SMIN35  447-449       
   SMIN36  450-452          SMIN37  453-455          SMIN38  456-458       
   SMIN39  459-461          SMIN40  462-464          SMIN41  465-467       
   SMIN42  468-469          SMIN43  470-471          SMIN44  472-473       
   SMIN45  474-475          SMIN46  476-477          SMIN47  478-479       
   SMIN48  480-481          SMIN49  482-483          SMIN50  484-485       
   SMIN51  486-487          SMIN52  488-489          SMIN53  490-491       
   SMIN54  492-493          SMIN55  494-495          SMIN56  496-497       
   SMIN57  498-499          SMIN58  500-501          SMIN59  502-503       
   SMIN60  504-505          SMIN61  506-507          SMIN62  508-509       
   SMIN63  510-511          SMIN64  512-513          SMIN65  514-515       
   SMIN66  516-517          SMIN67  518-519          SMIN68  520           
   SMIN69  521              SMIN70  522              SMIN71  523           
   SMIN72  524              SMIN73  525              SMIN74  526           
   SMIN75  527              SMIN76  528              SMIN77  529           
   SMIN78  530              SMIN79  531              SMIN80  532           
   SMIN81  533              SMIN82  534              SMIN83  535           
   SMIN84  536              SMIN85  537              SMIN86  538           
   SMIN87  539              SMIN88  540              SMIN89  541           
   SMIN90  542              SMIN91  543              SMIN92  544           
   SMIN93  545              SMIN94  546              SMIN95  547           
   SMIN96  548              SMIN97  549              SMIN98  550           
   SMIN99  551              SMIN100  552             SMIN101  553          
   SMIN102  554             SMIN103  555             SMIN104  556          
   SMIN105  557             SMIN106  558             SMIN107  559          
   SMIN108  560             SMIN109  561             SMIN110  562          
   SMIN111  563             SMIN112  564             SMIN113  565          
   SMIN114  566             SMIN115  567             SMIN116  568          
   SMIN117  569             SMIN118  570             SMIN119  571          
   SMIN120  572             SMIN121  573             SMIN122  574          
   SMIN123  575             SMIN124  576             SMIN125  577          
   SMIN126  578             SMIN127  579             SMIN128  580          
   SMIN129  581             SMIN130  582             SMIN131  583          
   SMIN132  584             SMIN133  585             SMIN134  586          
   SMIN135  587             SMIN136  588             SMIN137  589          
   SMIN138  590             SMIN139  591             SMIN140  592          
   SMIN141  593             SMIN142  594             SMIN143  595          
   SMIN144  596             SMIN145  597             SMIN146  598          
   SMIN147  599             SMIN148  600             SMIN149  601          
   SMIN150  602             SMIN151  603             SMIN152  604          
   SMIN153  605             SMIN154  606             SMIN155  607          
   SMIN156  608             SMIN157  609             SMIN158  610          
   SMIN159  611             SMIN160  612             SMIN161  613          
   SMIN162  614             SMIN163  615             SMIN164  616          
   SMIN165  617             SMIN166  618             SMIN167  619          
   SMIN168  620             SMIN169  621             SMIN170  622          
   SMIN171  623             SMIN172  624             SMIN173  625          
   SMIN174  626             SMIN175  627             SMIN176  628          
   SMIN177  629             SMIN178  630             SMIN179  631          
   SMIN180  632             SMIN181  633             SMIN182  634          
   SMIN183  635             SMIN184  636             SMIN185  637          
   SMIN186  638             SMIN187  639             SMIN188  640          
   SMIN189  641             SMIN190  642             SMIN191  643          
   SMIN192  644             SMIN193  645             SMIN194  646          
   SMIN195  647             SMIN196  648             SMIN197  649          
   SMIN198  650             SMIN199  651             SMIN200  652          
   SMIN201  653             SMIN202  654             SMIN203  655          
   SMIN204  656             SMIN205  657             SMIN206  658          
   SMIN207  659             SMIN208  660             SMIN209  661          
   SMIN210  662             SMIN211  663             SMIN212  664          
   SMIN213  665             SMIN214  666             SMIN215  667          
   SMIN216  668             SMIN217  669             SMIN218  670          
   SMIN219  671             SMIN220  672             SMIN221  673          
   SMIN222  674             SMIN223  675             SMIN224  676          
   SMIN225  677             SMIN226  678             SMIN227  679          
   SMIN228  680             SMIN229  681             SMIN230  682          
   SMIN231  683             SMIN232  684             SMIN233  685          
   SMIN234  686             SMIN235  687             SMIN236  688          
   SMIN237  689             SMIN238  690             SMIN239  691          
   SMIN240  692             SMIN241  693             SMIN242  694          
   SMIN243  695             SMIN244  696             SMIN245  697          
   SMIN246  698             SMIN247  699             SMIN248  700          
   SMIN249  701             SMIN250  702             SMIN251  703          
   SMIN252  704             SMIN253  705             SMIN254  706          
   SMIN255  707             SMIN256  708             SMIN257  709          
   SMIN258  710             SMIN259  711             SMIN260  712          
   SMIN261  713             SMIN262  714             SMIN263  715          
   SMIN264  716             SMIN265  717             SMIN266  718          
   SMIN267  719             SMIN268  720             SMIN269  721          
   SMIN270  722             SMIN271  723             SMIN272  724          
   SMIN273  725             SMIN274  726             SMIN275  727          
   SMIN276  728             SMIN277  729             SMIN278  730          
   SMIN279  731             SMIN280  732             SMIN281  733          
   SMIN282  734             SMIN283  735             SMIN284  736          
   SMIN285  737             SMIN286  738             SMIN287  739          
   SMIN288  740             SMIN289  741             SMIN290  742          
   SMIN291  743             SMIN292  744             SMIN293  745          
   SMIN294  746             SMIN295  747             SMIN296  748          
   SMIN297  749             SMIN298  750             SMIN299  751          
   SMIN300  752             SMIN301  753             SMIN302  754          
   SMIN303  755             SMIN304  756             SMIN305  757          
   SMIN306  758             SMIN307  759             SMIN308  760          
   SMIN309  761             SMIN310  762             SMIN311  763          
   SMIN312  764             SMIN313  765             SMIN314  766          
   SMIN315  767             SMIN316  768             SMIN317  769          
   SMIN318  770             SMIN319  771             SMIN320  772          
   SMIN321  773             SMIN322  774             SMIN323  775          
   SMIN324  776             SMIN325  777             SMIN326  778          
   SMIN327  779             SMIN328  780             SMIN329  781          
   SMIN330  782             SMIN331  783             SMIN332  784          
   SMIN333  785             SMIN334  786             SMIN335  787          
   SMIN336  788             SMIN337  789             SMIN338  790          
   SMIN339  791             SMIN340  792             SMIN341  793          
   SMIN342  794             SMIN343  795             SMIN344  796          
   SMIN345  797             SMIN346  798             SMIN347  799          
   SMIN348  800             SMIN349  801             SMIN350  802          
   SMIN351  803             SMIN352  804             SMIN353  805          
   SMIN354  806             SMIN355  807             SMIN356  808          
   SMIN357  809             SMIN358  810             SMIN359  811          
   SMIN360  812             SMIN361  813             SMIN362  814          
   SMIN363  815             SMIN364  816             SMIN365  817          
   SMIN366  818             SMIN367  819             SMIN368  820          
   SMIN369  821             SMIN370  822             SMIN371  823          
   SMIN372  824             SMIN373  825             SMIN374  826          
   SMIN375  827             SMIN376  828             SMIN377  829          
   SMIN378  830             SMIN379  831             SMIN380  832          
   SMIN381  833             SMIN382  834             SMIN383  835          
   SMIN384  836             SMIN385  837             SMIN386  838          
   SMIN387  839             SMIN388  840             SMIN389  841          
   SMIN390  842             SMIN391  843             SMIN392  844          
   SMIN393  845             SMIN394  846             SMIN395  847          
   SMIN396  848             SMIN397  849             SMIN398  850          
   SMIN399  851             SMIN400  852             SMIN401  853          
   SMIN402  854             SMIN403  855             SMIN404  856          
   SMIN405  857             SMIN406  858             SMIN407  859          
   SMIN408  860             SMIN409  861             SMIN410  862          
   SMIN411  863             SMIN412  864             SMIN413  865          
   SMIN414  866             SMIN415  867             SMIN416  868          
   SMIN417  869             SMIN418  870             SMIN419  871          
   SMIN420  872             SMIN421  873             SMIN422  874          
   SMIN423  875             SMIN424  876             SMIN425  877          
   SMIN426  878             SMIN427  879             SMIN428  880          
   SMIN429  881             SMIN430  882             SMIN431  883          
   SMIN432  884             SMIN433  885             SMIN434  886          
   SMIN435  887             SMIN436  888             SMIN437  889          
   SMIN438  890             SMIN439  891             SMIN440  892          
   SMIN441  893             SMIN442  894             SMIN443  895          
   SMIN444  896             SMIN445  897             SMIN446  898          
   SMIN447  899             SMIN448  900             SMIN449  901          
   SMIN450  902             SMIN451  903             SMIN452  904          
   SMIN453  905             SMIN454  906             SMIN455  907          
   SMIN456  908             SMIN457  909             SMIN458  910          
   SMIN459  911             SMIN460  912             SMIN461  913          
   SMIN462  914             SMIN463  915             SMIN464  916          
   SMIN465  917             SMIN466  918             SMIN467  919          
   SMIN468  920             SMIN469  921             SMIN470  922          
   SMIN471  923             SMIN472  924             SMIN473  925          
   SMIN474  926             SMIN475  927             SMIN476  928          
   SMIN477  929             SMIN478  930             SMIN479  931          
   SMIN480  932             SMIN481  933             SMIN482  934          
   SMIN483  935             SMIN484  936             SMIN485  937          
   SMIN486  938             SMIN487  939             SMIN488  940          
   SMIN489  941             SMIN490  942             SMIN491  943          
   SMIN492  944             SMIN493  945             SMIN494  946          
   SMIN495  947             SMAX1  948-951           SMAX2  952-955        
   SMAX3  956-959           SMAX4  960-963           SMAX5  964-967        
   SMAX6  968-971           SMAX7  972-975           SMAX8  976-979        
   SMAX9  980-983           SMAX10  984-987          SMAX11  988-991       
   SMAX12  992-995          SMAX13  996-999          SMAX14  1000-1003     
   SMAX15  1004-1007        SMAX16  1008-1011        SMAX17  1012-1015     
   SMAX18  1016-1019        SMAX19  1020-1022        SMAX20  1023-1026     
   SMAX21  1027-1029        SMAX22  1030-1032        SMAX23  1033-1035     
   SMAX24  1036-1039        SMAX25  1040-1042        SMAX26  1043-1045     
   SMAX27  1046-1048        SMAX28  1049-1051        SMAX29  1052-1054     
   SMAX30  1055-1057        SMAX31  1058-1060        SMAX32  1061-1063     
   SMAX33  1064-1066        SMAX34  1067-1069        SMAX35  1070-1073     
   SMAX36  1074-1077        SMAX37  1078-1081        SMAX38  1082-1085     
   SMAX39  1086-1089        SMAX40  1090-1093        SMAX41  1094-1097     
   SMAX42  1098-1100        SMAX43  1101-1103        SMAX44  1104-1106     
   SMAX45  1107-1109        SMAX46  1110-1112        SMAX47  1113-1115     
   SMAX48  1116-1118        SMAX49  1119-1121        SMAX50  1122-1124     
   SMAX51  1125-1127        SMAX52  1128-1130        SMAX53  1131-1133     
   SMAX54  1134-1136        SMAX55  1137-1139        SMAX56  1140-1142     
   SMAX57  1143-1145        SMAX58  1146-1148        SMAX59  1149-1151     
   SMAX60  1152-1154        SMAX61  1155-1157        SMAX62  1158-1160     
   SMAX63  1161-1163        SMAX64  1164-1166        SMAX65  1167-1169     
   SMAX66  1170-1172        SMAX67  1173-1175        SMAX68  1176-1178     
   SMAX69  1179-1181        SMAX70  1182-1184        SMAX71  1185-1187     
   SMAX72  1188-1190        SMAX73  1191-1193        SMAX74  1194-1196     
   SMAX75  1197-1199        SMAX76  1200-1202        SMAX77  1203-1205     
   SMAX78  1206-1208        SMAX79  1209-1211        SMAX80  1212-1214     
   SMAX81  1215-1217        SMAX82  1218-1220        SMAX83  1221-1223     
   SMAX84  1224-1226        SMAX85  1227-1229        SMAX86  1230-1232     
   SMAX87  1233-1235        SMAX88  1236-1238        SMAX89  1239-1241     
   SMAX90  1242-1244        SMAX91  1245-1247        SMAX92  1248-1250     
   SMAX93  1251-1253        SMAX94  1254-1256        SMAX95  1257-1259     
   SMAX96  1260-1262        SMAX97  1263-1265        SMAX98  1266-1268     
   SMAX99  1269-1271        SMAX100  1272-1274       SMAX101  1275-1277    
   SMAX102  1278-1280       SMAX103  1281-1283       SMAX104  1284-1286    
   SMAX105  1287-1289       SMAX106  1290-1292       SMAX107  1293-1295    
   SMAX108  1296-1298       SMAX109  1299-1301       SMAX110  1302-1304    
   SMAX111  1305-1307       SMAX112  1308-1310       SMAX113  1311-1313    
   SMAX114  1314-1316       SMAX115  1317-1319       SMAX116  1320-1322    
   SMAX117  1323-1325       SMAX118  1326-1328       SMAX119  1329-1331    
   SMAX120  1332-1334       SMAX121  1335-1337       SMAX122  1338-1340    
   SMAX123  1341-1343       SMAX124  1344-1346       SMAX125  1347-1349    
   SMAX126  1350-1352       SMAX127  1353-1355       SMAX128  1356-1358    
   SMAX129  1359-1361       SMAX130  1362-1364       SMAX131  1365-1367    
   SMAX132  1368-1370       SMAX133  1371-1373       SMAX134  1374-1376    
   SMAX135  1377-1379       SMAX136  1380-1382       SMAX137  1383-1385    
   SMAX138  1386-1388       SMAX139  1389-1391       SMAX140  1392-1394    
   SMAX141  1395-1397       SMAX142  1398-1400       SMAX143  1401-1403    
   SMAX144  1404-1406       SMAX145  1407-1409       SMAX146  1410-1412    
   SMAX147  1413-1415       SMAX148  1416-1418       SMAX149  1419-1421    
   SMAX150  1422-1424       SMAX151  1425-1427       SMAX152  1428-1430    
   SMAX153  1431-1433       SMAX154  1434-1436       SMAX155  1437-1439    
   SMAX156  1440-1442       SMAX157  1443-1445       SMAX158  1446-1448    
   SMAX159  1449-1451       SMAX160  1452-1454       SMAX161  1455-1457    
   SMAX162  1458-1460       SMAX163  1461-1463       SMAX164  1464-1466    
   SMAX165  1467-1469       SMAX166  1470-1472       SMAX167  1473-1475    
   SMAX168  1476-1478       SMAX169  1479-1481       SMAX170  1482-1484    
   SMAX171  1485-1487       SMAX172  1488-1490       SMAX173  1491-1493    
   SMAX174  1494-1496       SMAX175  1497-1499       SMAX176  1500-1502    
   SMAX177  1503-1505       SMAX178  1506-1508       SMAX179  1509-1511    
   SMAX180  1512-1514       SMAX181  1515-1517       SMAX182  1518-1520    
   SMAX183  1521-1523       SMAX184  1524-1526       SMAX185  1527-1529    
   SMAX186  1530-1532       SMAX187  1533-1535       SMAX188  1536-1538    
   SMAX189  1539-1541       SMAX190  1542-1544       SMAX191  1545-1547    
   SMAX192  1548-1550       SMAX193  1551-1553       SMAX194  1554-1556    
   SMAX195  1557-1559       SMAX196  1560-1562       SMAX197  1563-1565    
   SMAX198  1566-1568       SMAX199  1569-1571       SMAX200  1572-1574    
   SMAX201  1575-1577       SMAX202  1578-1580       SMAX203  1581-1583    
   SMAX204  1584-1586       SMAX205  1587-1589       SMAX206  1590-1592    
   SMAX207  1593-1595       SMAX208  1596-1598       SMAX209  1599-1601    
   SMAX210  1602-1604       SMAX211  1605-1607       SMAX212  1608-1610    
   SMAX213  1611-1613       SMAX214  1614-1616       SMAX215  1617-1619    
   SMAX216  1620-1622       SMAX217  1623-1625       SMAX218  1626-1628    
   SMAX219  1629-1631       SMAX220  1632-1634       SMAX221  1635-1637    
   SMAX222  1638-1640       SMAX223  1641-1643       SMAX224  1644-1646    
   SMAX225  1647-1649       SMAX226  1650-1652       SMAX227  1653-1655    
   SMAX228  1656-1658       SMAX229  1659-1661       SMAX230  1662-1664    
   SMAX231  1665-1667       SMAX232  1668-1670       SMAX233  1671-1673    
   SMAX234  1674-1676       SMAX235  1677-1679       SMAX236  1680-1682    
   SMAX237  1683-1685       SMAX238  1686-1688       SMAX239  1689-1691    
   SMAX240  1692-1694       SMAX241  1695-1697       SMAX242  1698-1700    
   SMAX243  1701-1703       SMAX244  1704-1706       SMAX245  1707-1709    
   SMAX246  1710-1712       SMAX247  1713-1715       SMAX248  1716-1718    
   SMAX249  1719-1721       SMAX250  1722-1724       SMAX251  1725-1727    
   SMAX252  1728-1730       SMAX253  1731-1733       SMAX254  1734-1736    
   SMAX255  1737-1739       SMAX256  1740-1742       SMAX257  1743-1745    
   SMAX258  1746-1748       SMAX259  1749-1751       SMAX260  1752-1754    
   SMAX261  1755-1757       SMAX262  1758-1760       SMAX263  1761-1763    
   SMAX264  1764-1766       SMAX265  1767-1769       SMAX266  1770-1772    
   SMAX267  1773-1775       SMAX268  1776-1778       SMAX269  1779-1781    
   SMAX270  1782-1784       SMAX271  1785-1787       SMAX272  1788-1790    
   SMAX273  1791-1793       SMAX274  1794-1796       SMAX275  1797-1799    
   SMAX276  1800-1802       SMAX277  1803-1805       SMAX278  1806-1808    
   SMAX279  1809-1811       SMAX280  1812-1814       SMAX281  1815-1817    
   SMAX282  1818-1820       SMAX283  1821-1823       SMAX284  1824-1826    
   SMAX285  1827-1829       SMAX286  1830-1832       SMAX287  1833-1835    
   SMAX288  1836-1838       SMAX289  1839-1841       SMAX290  1842-1844    
   SMAX291  1845-1847       SMAX292  1848-1850       SMAX293  1851-1853    
   SMAX294  1854-1856       SMAX295  1857-1859       SMAX296  1860-1862    
   SMAX297  1863-1865       SMAX298  1866-1868       SMAX299  1869-1871    
   SMAX300  1872-1874       SMAX301  1875-1877       SMAX302  1878-1880    
   SMAX303  1881-1883       SMAX304  1884-1886       SMAX305  1887-1889    
   SMAX306  1890-1892       SMAX307  1893-1895       SMAX308  1896-1898    
   SMAX309  1899-1901       SMAX310  1902-1904       SMAX311  1905-1907    
   SMAX312  1908-1910       SMAX313  1911-1913       SMAX314  1914-1916    
   SMAX315  1917-1919       SMAX316  1920-1922       SMAX317  1923-1925    
   SMAX318  1926-1928       SMAX319  1929-1931       SMAX320  1932-1934    
   SMAX321  1935-1937       SMAX322  1938-1940       SMAX323  1941-1943    
   SMAX324  1944-1946       SMAX325  1947-1949       SMAX326  1950-1952    
   SMAX327  1953-1955       SMAX328  1956-1958       SMAX329  1959-1961    
   SMAX330  1962-1964       SMAX331  1965-1967       SMAX332  1968-1970    
   SMAX333  1971-1973       SMAX334  1974-1976       SMAX335  1977-1979    
   SMAX336  1980-1982       SMAX337  1983-1985       SMAX338  1986-1988    
   SMAX339  1989-1991       SMAX340  1992-1994       SMAX341  1995-1997    
   SMAX342  1998-2000       SMAX343  2001-2003       SMAX344  2004-2006    
   SMAX345  2007-2009       SMAX346  2010-2012       SMAX347  2013-2015    
   SMAX348  2016-2018       SMAX349  2019-2021       SMAX350  2022-2024    
   SMAX351  2025-2027       SMAX352  2028-2030       SMAX353  2031-2033    
   SMAX354  2034-2036       SMAX355  2037-2039       SMAX356  2040-2042    
   SMAX357  2043-2045       SMAX358  2046-2048       SMAX359  2049-2051    
   SMAX360  2052-2054       SMAX361  2055-2057       SMAX362  2058-2060    
   SMAX363  2061-2063       SMAX364  2064-2066       SMAX365  2067-2069    
   SMAX366  2070-2072       SMAX367  2073-2075       SMAX368  2076-2078    
   SMAX369  2079-2081       SMAX370  2082-2084       SMAX371  2085-2087    
   SMAX372  2088-2090       SMAX373  2091-2093       SMAX374  2094-2096    
   SMAX375  2097-2099       SMAX376  2100-2102       SMAX377  2103-2105    
   SMAX378  2106-2108       SMAX379  2109-2111       SMAX380  2112-2114    
   SMAX381  2115-2117       SMAX382  2118-2120       SMAX383  2121-2123    
   SMAX384  2124-2126       SMAX385  2127-2129       SMAX386  2130-2132    
   SMAX387  2133-2135       SMAX388  2136-2138       SMAX389  2139-2141    
   SMAX390  2142-2144       SMAX391  2145-2147       SMAX392  2148-2150    
   SMAX393  2151-2153       SMAX394  2154-2156       SMAX395  2157-2159    
   SMAX396  2160-2162       SMAX397  2163-2165       SMAX398  2166-2168    
   SMAX399  2169-2171       SMAX400  2172-2174       SMAX401  2175-2177    
   SMAX402  2178-2180       SMAX403  2181-2183       SMAX404  2184-2186    
   SMAX405  2187-2189       SMAX406  2190-2192       SMAX407  2193-2195    
   SMAX408  2196-2198       SMAX409  2199-2201       SMAX410  2202-2204    
   SMAX411  2205-2207       SMAX412  2208-2210       SMAX413  2211-2213    
   SMAX414  2214-2216       SMAX415  2217-2219       SMAX416  2220-2222    
   SMAX417  2223-2225       SMAX418  2226-2228       SMAX419  2229-2231    
   SMAX420  2232-2234       SMAX421  2235-2237       SMAX422  2238-2240    
   SMAX423  2241-2243       SMAX424  2244-2246       SMAX425  2247-2249    
   SMAX426  2250-2252       SMAX427  2253-2255       SMAX428  2256-2258    
   SMAX429  2259-2261       SMAX430  2262-2264       SMAX431  2265-2267    
   SMAX432  2268-2270       SMAX433  2271-2273       SMAX434  2274-2276    
   SMAX435  2277-2279       SMAX436  2280-2282       SMAX437  2283-2285    
   SMAX438  2286-2288       SMAX439  2289-2291       SMAX440  2292-2294    
   SMAX441  2295-2297       SMAX442  2298-2300       SMAX443  2301-2303    
   SMAX444  2304-2306       SMAX445  2307-2309       SMAX446  2310-2312    
   SMAX447  2313-2315       SMAX448  2316-2318       SMAX449  2319-2321    
   SMAX450  2322-2324       SMAX451  2325-2327       SMAX452  2328-2330    
   SMAX453  2331-2333       SMAX454  2334-2336       SMAX455  2337-2339    
   SMAX456  2340-2342       SMAX457  2343-2345       SMAX458  2346-2348    
   SMAX459  2349-2351       SMAX460  2352-2354       SMAX461  2355-2357    
   SMAX462  2358-2360       SMAX463  2361-2363       SMAX464  2364-2366    
   SMAX465  2367-2369       SMAX466  2370-2372       SMAX467  2373-2375    
   SMAX468  2376-2378       SMAX469  2379-2381       SMAX470  2382-2384    
   SMAX471  2385-2387       SMAX472  2388-2390       SMAX473  2391-2393    
   SMAX474  2394-2396       SMAX475  2397-2399       SMAX476  2400-2402    
   SMAX477  2403-2405       SMAX478  2406-2408       SMAX479  2409-2411    
   SMAX480  2412-2414       SMAX481  2415-2417       SMAX482  2418-2420    
   SMAX483  2421-2423       SMAX484  2424-2426       SMAX485  2427-2429    
   SMAX486  2430-2432       SMAX487  2433-2435       SMAX488  2436-2438    
   SMAX489  2439-2441       SMAX490  2442-2444       SMAX491  2445-2447    
   SMAX492  2448-2450       SMAX493  2451-2453       SMAX494  2454-2456    
   SMAX495  2457-2459       DEFCONTX $ 2460-2480     DESCRIP1 $ 2481-2520  
   DESCRIP2 $ 2521-2538     DESCRIP3 $ 2539-2553     DESCRIP4 $ 2554-2603  
   DESCRIP5 $ 2604          CHEMDES1 $ 2605-2623     CHEMDES2 $ 2624       
   CHEMDES3 $ 2625          CHEMDES4 $ 2626          CHEMDES5 $ 2627       
   TYPEOTTX $ 2628-2693     ABERTXT $ 2694-2743      REASTXT1 $ 2744-2839  
   REASTXT2 $ 2840-2935     REASTXT3 $ 2936-3031     REASTXT4 $ 3032-3086  
   REASTXT5 $ 3087-3152     REASTXT6 $ 3153          POOFFICE $ 3154       
   CH5G13ST  3155-3156      TIMSERVD  3157-3159      TIMSERVM  3160-3162   
   SPECASSM  3163-3167      ABERCASE $ 3168          CHMAM1  3169-3176     
   CHMAM2  3177-3180        CHMAM3  3181             CHMAM4  3182          
   CHMAM5  3183             CUNIT1  3184-3185        CUNIT2  3186          
   CUNIT3  3187             CUNIT4  3188             CUNIT5  3189          
   CHEMTYP1  3190-3191      CHEMTYP2  3192-3193      CHEMTYP3  3194        
   CHEMTYP4  3195           CHEMTYP5  3196           CAFROM1  3197-3201    
   CAFROM2  3202            CAFROM3  3203            CAFROM4  3204         
   CAFROM5  3205            CATO1  3206-3210         CATO2  3211           
   CATO3  3212              CATO4  3213              CATO5  3214           
   REASON4  3215-3217       REASON5  3218-3220       REASON6  3221         
   SENTDATE DATE11.         DOB DATE11.              ABUS1  3244           
   ABUS2  3245              ABUS3  3246              ABUS4  3247           
   ABUS5  3248              ABUS6  3249              ABUS7  3250           
   ABUS8  3251              ABUS9  3252              ABUS10  3253          
   ABUS11  3254             ABUS12  3255             ABUS13  3256          
   ABUS14  3257             ABUS15  3258             ABUS16  3259          
   ABUS17  3260             ABUS18  3261             ABUS19  3262          
   ABUS20  3263             ABUS21  3264             ABUS22  3265          
   ABUS23  3266             ABUS24  3267             ABUS25  3268          
   ABUS26  3269             ABUS27  3270             ABUS28  3271          
   ABUS29  3272             ABUS30  3273             ABUS31  3274          
   ABUS32  3275             ABUS33  3276             ABUS34  3277          
   ABUS35  3278             ABUS36  3279             ABUS37  3280          
   ABUS38  3281             ABUS39  3282             ABUS40  3283          
   ABUS41  3284             ABUS42  3285             ABUSHI  3286          
   ABUSR1  3287             ABUSR2  3288             ABUSR3  3289          
   ABUSR4  3290             ABUSR5  3291             ABUSR6  3292          
   ABUSR7  3293             ABUSR8  3294             ABUSR9  3295          
   ABUSR10  3296            ABUSR11  3297            ABUSR12  3298         
   ABUSR13  3299            ABUSR14  3300            ABUSR15  3301         
   ABUSR16  3302            ABUSR17  3303            ABUSR18  3304         
   ABUSR19  3305            ABUSR20  3306            ABUSR21  3307         
   ABUSR22  3308            ABUSR23  3309            ABUSR24  3310         
   ABUSR25  3311            ABUSR26  3312            ABUSR27  3313         
   ABUSR28  3314            ABUSR29  3315            ABUSR30  3316         
   ABUSR31  3317            ABUSR32  3318            ABUSR33  3319         
   ABUSR34  3320            ABUSR35  3321            ABUSR36  3322         
   ABUSR37  3323            ABUSR38  3324            ABUSR39  3325         
   ABUSR40  3326            ABUSR41  3327            ABUSR42  3328         
   ABUSRHI  3329            ADJOFL1  3330-3331       ADJOFL2  3332-3333    
   ADJOFL3  3334-3335       ADJOFL4  3336-3337       ADJOFL5  3338-3339    
   ADJOFL6  3340-3341       ADJOFL7  3342-3343       ADJOFL8  3344-3345    
   ADJOFL9  3346-3347       ADJOFL10  3348-3349      ADJOFL11  3350-3351   
   ADJOFL12  3352-3353      ADJOFL13  3354-3355      ADJOFL14  3356-3357   
   ADJOFL15  3358-3359      ADJOFL16  3360-3361      ADJOFL17  3362-3363   
   ADJOFL18  3364-3365      ADJOFL19  3366-3367      ADJOFL20  3368-3369   
   ADJOFL21  3370-3371      ADJOFL22  3372-3373      ADJOFL23  3374-3375   
   ADJOFL24  3376-3377      ADJOFL25  3378-3379      ADJOFL26  3380-3381   
   ADJOFL27  3382-3383      ADJOFL28  3384-3385      ADJOFL29  3386-3387   
   ADJOFL30  3388-3389      ADJOFL31  3390-3391      ADJOFL32  3392-3393   
   ADJOFL33  3394-3395      ADJOFL34  3396-3397      ADJOFL35  3398-3399   
   ADJOFL36  3400-3401      ADJOFL37  3402-3403      ADJOFL38  3404-3405   
   ADJOFL39  3406-3407      ADJOFL40  3408-3409      ADJOFL41  3410-3411   
   ADJOFL42  3412-3413      ADJOFLHI  3414-3415      ADJOFR1  3416-3417    
   ADJOFR2  3418-3419       ADJOFR3  3420-3421       ADJOFR4  3422-3423    
   ADJOFR5  3424-3425       ADJOFR6  3426-3427       ADJOFR7  3428-3429    
   ADJOFR8  3430-3431       ADJOFR9  3432-3433       ADJOFR10  3434-3435   
   ADJOFR11  3436-3437      ADJOFR12  3438-3439      ADJOFR13  3440-3441   
   ADJOFR14  3442-3443      ADJOFR15  3444-3445      ADJOFR16  3446-3447   
   ADJOFR17  3448-3449      ADJOFR18  3450-3451      ADJOFR19  3452-3453   
   ADJOFR20  3454-3455      ADJOFR21  3456-3457      ADJOFR22  3458-3459   
   ADJOFR23  3460-3461      ADJOFR24  3462-3463      ADJOFR25  3464-3465   
   ADJOFR26  3466-3467      ADJOFR27  3468-3469      ADJOFR28  3470-3471   
   ADJOFR29  3472-3473      ADJOFR30  3474-3475      ADJOFR31  3476-3477   
   ADJOFR32  3478-3479      ADJOFR33  3480-3481      ADJOFR34  3482-3483   
   ADJOFR35  3484-3485      ADJOFR36  3486-3487      ADJOFR37  3488-3489   
   ADJOFR38  3490-3491      ADJOFR39  3492-3493      ADJOFR40  3494-3495   
   ADJOFR41  3496-3497      ADJOFR42  3498           ADJOFRHI  3499-3500   
   ADJR_B1  3501-3502       ADJR_B2  3503-3504       ADJR_B3  3505-3506    
   ADJR_B4  3507-3508       ADJR_B5  3509            ADJR_B6  3510         
   ADJR_B7  3511            ADJR_B8  3512            ADJR_B9  3513         
   ADJR_B10  3514           ADJR_B11  3515           ADJR_B12  3516        
   ADJR_B13  3517           ADJR_B14  3518           ADJR_B15  3519        
   ADJR_B16  3520           ADJR_B17  3521           ADJR_B18  3522        
   ADJR_B19  3523           ADJR_B20  3524           ADJR_B21  3525        
   ADJR_B22  3526           ADJR_B23  3527           ADJR_B24  3528        
   ADJR_B25  3529           ADJR_B26  3530           ADJR_B27  3531        
   ADJR_B28  3532           ADJR_B29  3533           ADJR_B30  3534        
   ADJR_B31  3535           ADJR_B32  3536           ADJR_B33  3537        
   ADJR_B34  3538           ADJR_B35  3539           ADJR_B36  3540        
   ADJR_B37  3541           ADJR_B38  3542           ADJR_B39  3543        
   ADJR_B40  3544           ADJR_B41  3545           ADJR_B42  3546        
   ADJR_BHI  3547-3548      ADJR_C1  3549-3550       ADJR_C2  3551-3552    
   ADJR_C3  3553            ADJR_C4  3554            ADJR_C5  3555         
   ADJR_C6  3556            ADJR_C7  3557            ADJR_C8  3558         
   ADJR_C9  3559            ADJR_C10  3560           ADJR_C11  3561        
   ADJR_C12  3562           ADJR_C13  3563           ADJR_C14  3564        
   ADJR_C15  3565           ADJR_C16  3566           ADJR_C17  3567        
   ADJR_C18  3568           ADJR_C19  3569           ADJR_C20  3570        
   ADJR_C21  3571           ADJR_C22  3572           ADJR_C23  3573        
   ADJR_C24  3574           ADJR_C25  3575           ADJR_C26  3576        
   ADJR_C27  3577           ADJR_C28  3578           ADJR_C29  3579        
   ADJR_C30  3580           ADJR_C31  3581           ADJR_C32  3582        
   ADJR_C33  3583           ADJR_C34  3584           ADJR_C35  3585        
   ADJR_C36  3586           ADJR_C37  3587           ADJR_C38  3588        
   ADJR_C39  3589           ADJR_C40  3590           ADJR_C41  3591        
   ADJR_C42  3592           ADJR_CHI  3593-3594      ADJR_D1  3595         
   ADJR_D2  3596            ADJR_D3  3597            ADJR_D4  3598         
   ADJR_D5  3599            ADJR_D6  3600            ADJR_D7  3601         
   ADJR_D8  3602            ADJR_D9  3603            ADJR_D10  3604        
   ADJR_D11  3605           ADJR_D12  3606           ADJR_D13  3607        
   ADJR_D14  3608           ADJR_D15  3609           ADJR_D16  3610        
   ADJR_D17  3611           ADJR_D18  3612           ADJR_D19  3613        
   ADJR_D20  3614           ADJR_D21  3615           ADJR_D22  3616        
   ADJR_D23  3617           ADJR_D24  3618           ADJR_D25  3619        
   ADJR_D26  3620           ADJR_D27  3621           ADJR_D28  3622        
   ADJR_D29  3623           ADJR_D30  3624           ADJR_D31  3625        
   ADJR_D32  3626           ADJR_D33  3627           ADJR_D34  3628        
   ADJR_D35  3629           ADJR_D36  3630           ADJR_D37  3631        
   ADJR_D38  3632           ADJR_D39  3633           ADJR_D40  3634        
   ADJR_D41  3635           ADJR_D42  3636           ADJR_DHI  3637        
   ADJR_E1  3638-3639       ADJR_E2  3640            ADJR_E3  3641         
   ADJR_E4  3642            ADJR_E5  3643            ADJR_E6  3644         
   ADJR_E7  3645            ADJR_E8  3646            ADJR_E9  3647         
   ADJR_E10  3648           ADJR_E11  3649           ADJR_E12  3650        
   ADJR_E13  3651           ADJR_E14  3652           ADJR_E15  3653        
   ADJR_E16  3654           ADJR_E17  3655           ADJR_E18  3656        
   ADJR_E19  3657           ADJR_E20  3658           ADJR_E21  3659        
   ADJR_E22  3660           ADJR_E23  3661           ADJR_E24  3662        
   ADJR_E25  3663           ADJR_E26  3664           ADJR_E27  3665        
   ADJR_E28  3666           ADJR_E29  3667           ADJR_E30  3668        
   ADJR_E31  3669           ADJR_E32  3670           ADJR_E33  3671        
   ADJR_E34  3672           ADJR_E35  3673           ADJR_E36  3674        
   ADJR_E37  3675           ADJR_E38  3676           ADJR_E39  3677        
   ADJR_E40  3678           ADJR_E41  3679           ADJR_E42  3680        
   ADJR_EHI  3681-3682      ADJR_F1  3683            ADJR_F2  3684         
   ADJR_F3  3685            ADJR_F4  3686            ADJR_F5  3687         
   ADJR_F6  3688            ADJR_F7  3689            ADJR_F8  3690         
   ADJR_F9  3691            ADJR_F10  3692           ADJR_F11  3693        
   ADJR_F12  3694           ADJR_F13  3695           ADJR_F14  3696        
   ADJR_F15  3697           ADJR_F16  3698           ADJR_F17  3699        
   ADJR_F18  3700           ADJR_F19  3701           ADJR_F20  3702        
   ADJR_F21  3703           ADJR_F22  3704           ADJR_F23  3705        
   ADJR_F24  3706           ADJR_F25  3707           ADJR_F26  3708        
   ADJR_F27  3709           ADJR_F28  3710           ADJR_F29  3711        
   ADJR_F30  3712           ADJR_F31  3713           ADJR_F32  3714        
   ADJR_F33  3715           ADJR_F34  3716           ADJR_F35  3717        
   ADJR_F36  3718           ADJR_F37  3719           ADJR_F38  3720        
   ADJR_F39  3721           ADJR_F40  3722           ADJR_F41  3723        
   ADJR_F42  3724           ADJR_FHI  3725           ADJR_G1  3726-3727    
   ADJR_G2  3728-3729       ADJR_G3  3730            ADJR_G4  3731         
   ADJR_G5  3732            ADJR_G6  3733            ADJR_G7  3734         
   ADJR_G8  3735            ADJR_G9  3736            ADJR_G10  3737        
   ADJR_G11  3738           ADJR_G12  3739           ADJR_G13  3740        
   ADJR_G14  3741           ADJR_G15  3742           ADJR_G16  3743        
   ADJR_G17  3744           ADJR_G18  3745           ADJR_G19  3746        
   ADJR_G20  3747           ADJR_G21  3748           ADJR_G22  3749        
   ADJR_G23  3750           ADJR_G24  3751           ADJR_G25  3752        
   ADJR_G26  3753           ADJR_G27  3754           ADJR_G28  3755        
   ADJR_G29  3756           ADJR_G30  3757           ADJR_G31  3758        
   ADJR_G32  3759           ADJR_G33  3760           ADJR_G34  3761        
   ADJR_G35  3762           ADJR_G36  3763           ADJR_G37  3764        
   ADJR_G38  3765           ADJR_G39  3766           ADJR_G40  3767        
   ADJR_G41  3768           ADJR_G42  3769           ADJR_GHI  3770-3771   
   ADJR_H1  3772            ADJR_H2  3773            ADJR_H3  3774         
   ADJR_H4  3775            ADJR_H5  3776            ADJR_H6  3777         
   ADJR_H7  3778            ADJR_H8  3779            ADJR_H9  3780         
   ADJR_H10  3781           ADJR_H11  3782           ADJR_H12  3783        
   ADJR_H13  3784           ADJR_H14  3785           ADJR_H15  3786        
   ADJR_H16  3787           ADJR_H17  3788           ADJR_H18  3789        
   ADJR_H19  3790           ADJR_H20  3791           ADJR_H21  3792        
   ADJR_H22  3793           ADJR_H23  3794           ADJR_H24  3795        
   ADJR_H25  3796           ADJR_H26  3797           ADJR_H27  3798        
   ADJR_H28  3799           ADJR_H29  3800           ADJR_H30  3801        
   ADJR_H31  3802           ADJR_H32  3803           ADJR_H33  3804        
   ADJR_H34  3805           ADJR_H35  3806           ADJR_H36  3807        
   ADJR_H37  3808           ADJR_H38  3809           ADJR_H39  3810        
   ADJR_H40  3811           ADJR_H41  3812           ADJR_H42  3813        
   ADJR_HHI  3814           ADJR_I1  3815            ADJR_I2  3816         
   ADJR_I3  3817            ADJR_I4  3818            ADJR_I5  3819         
   ADJR_I6  3820            ADJR_I7  3821            ADJR_I8  3822         
   ADJR_I9  3823            ADJR_I10  3824           ADJR_I11  3825        
   ADJR_I12  3826           ADJR_I13  3827           ADJR_I14  3828        
   ADJR_I15  3829           ADJR_I16  3830           ADJR_I17  3831        
   ADJR_I18  3832           ADJR_I19  3833           ADJR_I20  3834        
   ADJR_I21  3835           ADJR_I22  3836           ADJR_I23  3837        
   ADJR_I24  3838           ADJR_I25  3839           ADJR_I26  3840        
   ADJR_I27  3841           ADJR_I28  3842           ADJR_I29  3843        
   ADJR_I30  3844           ADJR_I31  3845           ADJR_I32  3846        
   ADJR_I33  3847           ADJR_I34  3848           ADJR_I35  3849        
   ADJR_I36  3850           ADJR_I37  3851           ADJR_I38  3852        
   ADJR_I39  3853           ADJR_I40  3854           ADJR_I41  3855        
   ADJR_I42  3856           ADJR_IHI  3857           ADJR_J1  3858         
   ADJR_J2  3859            ADJR_J3  3860            ADJR_J4  3861         
   ADJR_J5  3862            ADJR_J6  3863            ADJR_J7  3864         
   ADJR_J8  3865            ADJR_J9  3866            ADJR_J10  3867        
   ADJR_J11  3868           ADJR_J12  3869           ADJR_J13  3870        
   ADJR_J14  3871           ADJR_J15  3872           ADJR_J16  3873        
   ADJR_J17  3874           ADJR_J18  3875           ADJR_J19  3876        
   ADJR_J20  3877           ADJR_J21  3878           ADJR_J22  3879        
   ADJR_J23  3880           ADJR_J24  3881           ADJR_J25  3882        
   ADJR_J26  3883           ADJR_J27  3884           ADJR_J28  3885        
   ADJR_J29  3886           ADJR_J30  3887           ADJR_J31  3888        
   ADJR_J32  3889           ADJR_J33  3890           ADJR_J34  3891        
   ADJR_J35  3892           ADJR_J36  3893           ADJR_J37  3894        
   ADJR_J38  3895           ADJR_J39  3896           ADJR_J40  3897        
   ADJR_J41  3898           ADJR_J42  3899           ADJR_JHI  3900        
   ADJR_K1  3901            ADJR_K2  3902            ADJR_K3  3903         
   ADJR_K4  3904            ADJR_K5  3905            ADJR_K6  3906         
   ADJR_K7  3907            ADJR_K8  3908            ADJR_K9  3909         
   ADJR_K10  3910           ADJR_K11  3911           ADJR_K12  3912        
   ADJR_K13  3913           ADJR_K14  3914           ADJR_K15  3915        
   ADJR_K16  3916           ADJR_K17  3917           ADJR_K18  3918        
   ADJR_K19  3919           ADJR_K20  3920           ADJR_K21  3921        
   ADJR_K22  3922           ADJR_K23  3923           ADJR_K24  3924        
   ADJR_K25  3925           ADJR_K26  3926           ADJR_K27  3927        
   ADJR_K28  3928           ADJR_K29  3929           ADJR_K30  3930        
   ADJR_K31  3931           ADJR_K32  3932           ADJR_K33  3933        
   ADJR_K34  3934           ADJR_K35  3935           ADJR_K36  3936        
   ADJR_K37  3937           ADJR_K38  3938           ADJR_K39  3939        
   ADJR_K40  3940           ADJR_K41  3941           ADJR_K42  3942        
   ADJR_KHI  3943           ADJR_L1  3944            ADJR_L2  3945         
   ADJR_L3  3946            ADJR_L4  3947            ADJR_L5  3948         
   ADJR_L6  3949            ADJR_L7  3950            ADJR_L8  3951         
   ADJR_L9  3952            ADJR_L10  3953           ADJR_L11  3954        
   ADJR_L12  3955           ADJR_L13  3956           ADJR_L14  3957        
   ADJR_L15  3958           ADJR_L16  3959           ADJR_L17  3960        
   ADJR_L18  3961           ADJR_L19  3962           ADJR_L20  3963        
   ADJR_L21  3964           ADJR_L22  3965           ADJR_L23  3966        
   ADJR_L24  3967           ADJR_L25  3968           ADJR_L26  3969        
   ADJR_L27  3970           ADJR_L28  3971           ADJR_L29  3972        
   ADJR_L30  3973           ADJR_L31  3974           ADJR_L32  3975        
   ADJR_L33  3976           ADJR_L34  3977           ADJR_L35  3978        
   ADJR_L36  3979           ADJR_L37  3980           ADJR_L38  3981        
   ADJR_L39  3982           ADJR_L40  3983           ADJR_L41  3984        
   ADJR_L42  3985           ADJR_LHI  3986           ADJR_M1  3987         
   ADJR_M2  3988            ADJR_M3  3989            ADJR_M4  3990         
   ADJR_M5  3991            ADJR_M6  3992            ADJR_M7  3993         
   ADJR_M8  3994            ADJR_M9  3995            ADJR_M10  3996        
   ADJR_M11  3997           ADJR_M12  3998           ADJR_M13  3999        
   ADJR_M14  4000           ADJR_M15  4001           ADJR_M16  4002        
   ADJR_M17  4003           ADJR_M18  4004           ADJR_M19  4005        
   ADJR_M20  4006           ADJR_M21  4007           ADJR_M22  4008        
   ADJR_M23  4009           ADJR_M24  4010           ADJR_M25  4011        
   ADJR_M26  4012           ADJR_M27  4013           ADJR_M28  4014        
   ADJR_M29  4015           ADJR_M30  4016           ADJR_M31  4017        
   ADJR_M32  4018           ADJR_M33  4019           ADJR_M34  4020        
   ADJR_M35  4021           ADJR_M36  4022           ADJR_M37  4023        
   ADJR_M38  4024           ADJR_M39  4025           ADJR_M40  4026        
   ADJR_M41  4027           ADJR_M42  4028           ADJR_MHI  4029        
   ADJR_N1  4030            ADJR_N2  4031            ADJR_N3  4032         
   ADJR_N4  4033            ADJR_N5  4034            ADJR_N6  4035         
   ADJR_N7  4036            ADJR_N8  4037            ADJR_N9  4038         
   ADJR_N10  4039           ADJR_N11  4040           ADJR_N12  4041        
   ADJR_N13  4042           ADJR_N14  4043           ADJR_N15  4044        
   ADJR_N16  4045           ADJR_N17  4046           ADJR_N18  4047        
   ADJR_N19  4048           ADJR_N20  4049           ADJR_N21  4050        
   ADJR_N22  4051           ADJR_N23  4052           ADJR_N24  4053        
   ADJR_N25  4054           ADJR_N26  4055           ADJR_N27  4056        
   ADJR_N28  4057           ADJR_N29  4058           ADJR_N30  4059        
   ADJR_N31  4060           ADJR_N32  4061           ADJR_N33  4062        
   ADJR_N34  4063           ADJR_N35  4064           ADJR_N36  4065        
   ADJR_N37  4066           ADJR_N38  4067           ADJR_N39  4068        
   ADJR_N40  4069           ADJR_N41  4070           ADJR_N42  4071        
   ADJR_NHI  4072           ADJR_O1  4073            ADJR_O2  4074         
   ADJR_O3  4075            ADJR_O4  4076            ADJR_O5  4077         
   ADJR_O6  4078            ADJR_O7  4079            ADJR_O8  4080         
   ADJR_O9  4081            ADJR_O10  4082           ADJR_O11  4083        
   ADJR_O12  4084           ADJR_O13  4085           ADJR_O14  4086        
   ADJR_O15  4087           ADJR_O16  4088           ADJR_O17  4089        
   ADJR_O18  4090           ADJR_O19  4091           ADJR_O20  4092        
   ADJR_O21  4093           ADJR_O22  4094           ADJR_O23  4095        
   ADJR_O24  4096           ADJR_O25  4097           ADJR_O26  4098        
   ADJR_O27  4099           ADJR_O28  4100           ADJR_O29  4101        
   ADJR_O30  4102           ADJR_O31  4103           ADJR_O32  4104        
   ADJR_O33  4105           ADJR_O34  4106           ADJR_O35  4107        
   ADJR_O36  4108           ADJR_O37  4109           ADJR_O38  4110        
   ADJR_O39  4111           ADJR_O40  4112           ADJR_O41  4113        
   ADJR_O42  4114           ADJR_OHI  4115           ADJR_P1  4116         
   ADJR_P2  4117            ADJR_P3  4118            ADJR_P4  4119         
   ADJR_P5  4120            ADJR_P6  4121            ADJR_P7  4122         
   ADJR_P8  4123            ADJR_P9  4124            ADJR_P10  4125        
   ADJR_P11  4126           ADJR_P12  4127           ADJR_P13  4128        
   ADJR_P14  4129           ADJR_P15  4130           ADJR_P16  4131        
   ADJR_P17  4132           ADJR_P18  4133           ADJR_P19  4134        
   ADJR_P20  4135           ADJR_P21  4136           ADJR_P22  4137        
   ADJR_P23  4138           ADJR_P24  4139           ADJR_P25  4140        
   ADJR_P26  4141           ADJR_P27  4142           ADJR_P28  4143        
   ADJR_P29  4144           ADJR_P30  4145           ADJR_P31  4146        
   ADJR_P32  4147           ADJR_P33  4148           ADJR_P34  4149        
   ADJR_P35  4150           ADJR_P36  4151           ADJR_P37  4152        
   ADJR_P38  4153           ADJR_P39  4154           ADJR_P40  4155        
   ADJR_P41  4156           ADJR_P42  4157           ADJR_PHI  4158        
   ADJ_B1  4159-4160        ADJ_B2  4161-4162        ADJ_B3  4163-4164     
   ADJ_B4  4165-4166        ADJ_B5  4167             ADJ_B6  4168          
   ADJ_B7  4169             ADJ_B8  4170             ADJ_B9  4171          
   ADJ_B10  4172-4173       ADJ_B11  4174            ADJ_B12  4175         
   ADJ_B13  4176            ADJ_B14  4177            ADJ_B15  4178         
   ADJ_B16  4179            ADJ_B17  4180            ADJ_B18  4181         
   ADJ_B19  4182            ADJ_B20  4183            ADJ_B21  4184         
   ADJ_B22  4185            ADJ_B23  4186            ADJ_B24  4187         
   ADJ_B25  4188            ADJ_B26  4189            ADJ_B27  4190         
   ADJ_B28  4191            ADJ_B29  4192            ADJ_B30  4193         
   ADJ_B31  4194            ADJ_B32  4195            ADJ_B33  4196         
   ADJ_B34  4197            ADJ_B35  4198            ADJ_B36  4199         
   ADJ_B37  4200            ADJ_B38  4201            ADJ_B39  4202         
   ADJ_B40  4203            ADJ_B41  4204            ADJ_B42  4205         
   ADJ_BHI  4206-4207       ADJ_C1  4208-4210        ADJ_C2  4211-4213     
   ADJ_C3  4214-4215        ADJ_C4  4216             ADJ_C5  4217-4218     
   ADJ_C6  4219             ADJ_C7  4220-4221        ADJ_C8  4222-4223     
   ADJ_C9  4224-4225        ADJ_C10  4226            ADJ_C11  4227         
   ADJ_C12  4228            ADJ_C13  4229            ADJ_C14  4230         
   ADJ_C15  4231            ADJ_C16  4232            ADJ_C17  4233         
   ADJ_C18  4234            ADJ_C19  4235            ADJ_C20  4236         
   ADJ_C21  4237            ADJ_C22  4238            ADJ_C23  4239         
   ADJ_C24  4240            ADJ_C25  4241            ADJ_C26  4242         
   ADJ_C27  4243            ADJ_C28  4244            ADJ_C29  4245         
   ADJ_C30  4246            ADJ_C31  4247            ADJ_C32  4248         
   ADJ_C33  4249            ADJ_C34  4250            ADJ_C35  4251         
   ADJ_C36  4252            ADJ_C37  4253            ADJ_C38  4254         
   ADJ_C39  4255            ADJ_C40  4256            ADJ_C41  4257         
   ADJ_C42  4258            ADJ_CHI  4259-4261       ADJ_D1  4262-4264     
   ADJ_D2  4265-4266        ADJ_D3  4267-4268        ADJ_D4  4269          
   ADJ_D5  4270             ADJ_D6  4271             ADJ_D7  4272          
   ADJ_D8  4273             ADJ_D9  4274             ADJ_D10  4275         
   ADJ_D11  4276            ADJ_D12  4277            ADJ_D13  4278         
   ADJ_D14  4279            ADJ_D15  4280            ADJ_D16  4281         
   ADJ_D17  4282            ADJ_D18  4283            ADJ_D19  4284         
   ADJ_D20  4285            ADJ_D21  4286            ADJ_D22  4287         
   ADJ_D23  4288            ADJ_D24  4289            ADJ_D25  4290         
   ADJ_D26  4291            ADJ_D27  4292            ADJ_D28  4293         
   ADJ_D29  4294            ADJ_D30  4295            ADJ_D31  4296         
   ADJ_D32  4297            ADJ_D33  4298            ADJ_D34  4299         
   ADJ_D35  4300            ADJ_D36  4301            ADJ_D37  4302         
   ADJ_D38  4303            ADJ_D39  4304            ADJ_D40  4305         
   ADJ_D41  4306            ADJ_D42  4307            ADJ_DHI  4308-4310    
   ADJ_E1  4311-4312        ADJ_E2  4313-4314        ADJ_E3  4315-4316     
   ADJ_E4  4317-4318        ADJ_E5  4319-4320        ADJ_E6  4321-4322     
   ADJ_E7  4323             ADJ_E8  4324             ADJ_E9  4325          
   ADJ_E10  4326            ADJ_E11  4327            ADJ_E12  4328         
   ADJ_E13  4329            ADJ_E14  4330            ADJ_E15  4331         
   ADJ_E16  4332            ADJ_E17  4333            ADJ_E18  4334         
   ADJ_E19  4335            ADJ_E20  4336            ADJ_E21  4337         
   ADJ_E22  4338            ADJ_E23  4339            ADJ_E24  4340         
   ADJ_E25  4341            ADJ_E26  4342            ADJ_E27  4343         
   ADJ_E28  4344            ADJ_E29  4345            ADJ_E30  4346         
   ADJ_E31  4347            ADJ_E32  4348            ADJ_E33  4349         
   ADJ_E34  4350            ADJ_E35  4351            ADJ_E36  4352         
   ADJ_E37  4353            ADJ_E38  4354            ADJ_E39  4355         
   ADJ_E40  4356            ADJ_E41  4357            ADJ_E42  4358         
   ADJ_EHI  4359-4360       ADJ_F1  4361-4362        ADJ_F2  4363-4364     
   ADJ_F3  4365             ADJ_F4  4366             ADJ_F5  4367          
   ADJ_F6  4368             ADJ_F7  4369             ADJ_F8  4370          
   ADJ_F9  4371             ADJ_F10  4372            ADJ_F11  4373         
   ADJ_F12  4374            ADJ_F13  4375            ADJ_F14  4376         
   ADJ_F15  4377            ADJ_F16  4378            ADJ_F17  4379         
   ADJ_F18  4380            ADJ_F19  4381            ADJ_F20  4382         
   ADJ_F21  4383            ADJ_F22  4384            ADJ_F23  4385         
   ADJ_F24  4386            ADJ_F25  4387            ADJ_F26  4388         
   ADJ_F27  4389            ADJ_F28  4390            ADJ_F29  4391         
   ADJ_F30  4392            ADJ_F31  4393            ADJ_F32  4394         
   ADJ_F33  4395            ADJ_F34  4396            ADJ_F35  4397         
   ADJ_F36  4398            ADJ_F37  4399            ADJ_F38  4400         
   ADJ_F39  4401            ADJ_F40  4402            ADJ_F41  4403         
   ADJ_F42  4404            ADJ_FHI  4405-4406       ADJ_G1  4407-4408     
   ADJ_G2  4409-4410        ADJ_G3  4411             ADJ_G4  4412-4413     
   ADJ_G5  4414             ADJ_G6  4415             ADJ_G7  4416          
   ADJ_G8  4417             ADJ_G9  4418             ADJ_G10  4419         
   ADJ_G11  4420            ADJ_G12  4421            ADJ_G13  4422         
   ADJ_G14  4423            ADJ_G15  4424            ADJ_G16  4425         
   ADJ_G17  4426            ADJ_G18  4427            ADJ_G19  4428         
   ADJ_G20  4429            ADJ_G21  4430            ADJ_G22  4431         
   ADJ_G23  4432            ADJ_G24  4433            ADJ_G25  4434         
   ADJ_G26  4435            ADJ_G27  4436            ADJ_G28  4437         
   ADJ_G29  4438            ADJ_G30  4439            ADJ_G31  4440         
   ADJ_G32  4441            ADJ_G33  4442            ADJ_G34  4443         
   ADJ_G35  4444            ADJ_G36  4445            ADJ_G37  4446         
   ADJ_G38  4447            ADJ_G39  4448            ADJ_G40  4449         
   ADJ_G41  4450            ADJ_G42  4451            ADJ_GHI  4452-4453    
   ADJ_H1  4454-4455        ADJ_H2  4456-4457        ADJ_H3  4458-4459     
   ADJ_H4  4460             ADJ_H5  4461             ADJ_H6  4462          
   ADJ_H7  4463             ADJ_H8  4464             ADJ_H9  4465          
   ADJ_H10  4466            ADJ_H11  4467            ADJ_H12  4468         
   ADJ_H13  4469            ADJ_H14  4470            ADJ_H15  4471         
   ADJ_H16  4472            ADJ_H17  4473            ADJ_H18  4474         
   ADJ_H19  4475            ADJ_H20  4476            ADJ_H21  4477         
   ADJ_H22  4478            ADJ_H23  4479            ADJ_H24  4480         
   ADJ_H25  4481            ADJ_H26  4482            ADJ_H27  4483         
   ADJ_H28  4484            ADJ_H29  4485            ADJ_H30  4486         
   ADJ_H31  4487            ADJ_H32  4488            ADJ_H33  4489         
   ADJ_H34  4490            ADJ_H35  4491            ADJ_H36  4492         
   ADJ_H37  4493            ADJ_H38  4494            ADJ_H39  4495         
   ADJ_H40  4496            ADJ_H41  4497            ADJ_H42  4498         
   ADJ_HHI  4499-4500       ADJ_I1  4501             ADJ_I2  4502          
   ADJ_I3  4503             ADJ_I4  4504             ADJ_I5  4505          
   ADJ_I6  4506             ADJ_I7  4507             ADJ_I8  4508          
   ADJ_I9  4509             ADJ_I10  4510            ADJ_I11  4511         
   ADJ_I12  4512            ADJ_I13  4513            ADJ_I14  4514         
   ADJ_I15  4515            ADJ_I16  4516            ADJ_I17  4517         
   ADJ_I18  4518            ADJ_I19  4519            ADJ_I20  4520         
   ADJ_I21  4521            ADJ_I22  4522            ADJ_I23  4523         
   ADJ_I24  4524            ADJ_I25  4525            ADJ_I26  4526         
   ADJ_I27  4527            ADJ_I28  4528            ADJ_I29  4529         
   ADJ_I30  4530            ADJ_I31  4531            ADJ_I32  4532         
   ADJ_I33  4533            ADJ_I34  4534            ADJ_I35  4535         
   ADJ_I36  4536            ADJ_I37  4537            ADJ_I38  4538         
   ADJ_I39  4539            ADJ_I40  4540            ADJ_I41  4541         
   ADJ_I42  4542            ADJ_IHI  4543            ADJ_J1  4544          
   ADJ_J2  4545             ADJ_J3  4546             ADJ_J4  4547          
   ADJ_J5  4548             ADJ_J6  4549             ADJ_J7  4550          
   ADJ_J8  4551             ADJ_J9  4552             ADJ_J10  4553         
   ADJ_J11  4554            ADJ_J12  4555            ADJ_J13  4556         
   ADJ_J14  4557            ADJ_J15  4558            ADJ_J16  4559         
   ADJ_J17  4560            ADJ_J18  4561            ADJ_J19  4562         
   ADJ_J20  4563            ADJ_J21  4564            ADJ_J22  4565         
   ADJ_J23  4566            ADJ_J24  4567            ADJ_J25  4568         
   ADJ_J26  4569            ADJ_J27  4570            ADJ_J28  4571         
   ADJ_J29  4572            ADJ_J30  4573            ADJ_J31  4574         
   ADJ_J32  4575            ADJ_J33  4576            ADJ_J34  4577         
   ADJ_J35  4578            ADJ_J36  4579            ADJ_J37  4580         
   ADJ_J38  4581            ADJ_J39  4582            ADJ_J40  4583         
   ADJ_J41  4584            ADJ_J42  4585            ADJ_JHI  4586         
   ADJ_K1  4587             ADJ_K2  4588             ADJ_K3  4589          
   ADJ_K4  4590             ADJ_K5  4591             ADJ_K6  4592          
   ADJ_K7  4593             ADJ_K8  4594             ADJ_K9  4595          
   ADJ_K10  4596            ADJ_K11  4597            ADJ_K12  4598         
   ADJ_K13  4599            ADJ_K14  4600            ADJ_K15  4601         
   ADJ_K16  4602            ADJ_K17  4603            ADJ_K18  4604         
   ADJ_K19  4605            ADJ_K20  4606            ADJ_K21  4607         
   ADJ_K22  4608            ADJ_K23  4609            ADJ_K24  4610         
   ADJ_K25  4611            ADJ_K26  4612            ADJ_K27  4613         
   ADJ_K28  4614            ADJ_K29  4615            ADJ_K30  4616         
   ADJ_K31  4617            ADJ_K32  4618            ADJ_K33  4619         
   ADJ_K34  4620            ADJ_K35  4621            ADJ_K36  4622         
   ADJ_K37  4623            ADJ_K38  4624            ADJ_K39  4625         
   ADJ_K40  4626            ADJ_K41  4627            ADJ_K42  4628         
   ADJ_KHI  4629            ADJ_L1  4630             ADJ_L2  4631          
   ADJ_L3  4632             ADJ_L4  4633             ADJ_L5  4634          
   ADJ_L6  4635             ADJ_L7  4636             ADJ_L8  4637          
   ADJ_L9  4638             ADJ_L10  4639            ADJ_L11  4640         
   ADJ_L12  4641            ADJ_L13  4642            ADJ_L14  4643         
   ADJ_L15  4644            ADJ_L16  4645            ADJ_L17  4646         
   ADJ_L18  4647            ADJ_L19  4648            ADJ_L20  4649         
   ADJ_L21  4650            ADJ_L22  4651            ADJ_L23  4652         
   ADJ_L24  4653            ADJ_L25  4654            ADJ_L26  4655         
   ADJ_L27  4656            ADJ_L28  4657            ADJ_L29  4658         
   ADJ_L30  4659            ADJ_L31  4660            ADJ_L32  4661         
   ADJ_L33  4662            ADJ_L34  4663            ADJ_L35  4664         
   ADJ_L36  4665            ADJ_L37  4666            ADJ_L38  4667         
   ADJ_L39  4668            ADJ_L40  4669            ADJ_L41  4670         
   ADJ_L42  4671            ADJ_LHI  4672            ADJ_M1  4673          
   ADJ_M2  4674             ADJ_M3  4675             ADJ_M4  4676          
   ADJ_M5  4677             ADJ_M6  4678             ADJ_M7  4679          
   ADJ_M8  4680             ADJ_M9  4681             ADJ_M10  4682         
   ADJ_M11  4683            ADJ_M12  4684            ADJ_M13  4685         
   ADJ_M14  4686            ADJ_M15  4687            ADJ_M16  4688         
   ADJ_M17  4689            ADJ_M18  4690            ADJ_M19  4691         
   ADJ_M20  4692            ADJ_M21  4693            ADJ_M22  4694         
   ADJ_M23  4695            ADJ_M24  4696            ADJ_M25  4697         
   ADJ_M26  4698            ADJ_M27  4699            ADJ_M28  4700         
   ADJ_M29  4701            ADJ_M30  4702            ADJ_M31  4703         
   ADJ_M32  4704            ADJ_M33  4705            ADJ_M34  4706         
   ADJ_M35  4707            ADJ_M36  4708            ADJ_M37  4709         
   ADJ_M38  4710            ADJ_M39  4711            ADJ_M40  4712         
   ADJ_M41  4713            ADJ_M42  4714            ADJ_MHI  4715         
   ADJ_N1  4716             ADJ_N2  4717             ADJ_N3  4718          
   ADJ_N4  4719             ADJ_N5  4720             ADJ_N6  4721          
   ADJ_N7  4722             ADJ_N8  4723             ADJ_N9  4724          
   ADJ_N10  4725            ADJ_N11  4726            ADJ_N12  4727         
   ADJ_N13  4728            ADJ_N14  4729            ADJ_N15  4730         
   ADJ_N16  4731            ADJ_N17  4732            ADJ_N18  4733         
   ADJ_N19  4734            ADJ_N20  4735            ADJ_N21  4736         
   ADJ_N22  4737            ADJ_N23  4738            ADJ_N24  4739         
   ADJ_N25  4740            ADJ_N26  4741            ADJ_N27  4742         
   ADJ_N28  4743            ADJ_N29  4744            ADJ_N30  4745         
   ADJ_N31  4746            ADJ_N32  4747            ADJ_N33  4748         
   ADJ_N34  4749            ADJ_N35  4750            ADJ_N36  4751         
   ADJ_N37  4752            ADJ_N38  4753            ADJ_N39  4754         
   ADJ_N40  4755            ADJ_N41  4756            ADJ_N42  4757         
   ADJ_NHI  4758            ADJ_O1  4759             ADJ_O2  4760          
   ADJ_O3  4761             ADJ_O4  4762             ADJ_O5  4763          
   ADJ_O6  4764             ADJ_O7  4765             ADJ_O8  4766          
   ADJ_O9  4767             ADJ_O10  4768            ADJ_O11  4769         
   ADJ_O12  4770            ADJ_O13  4771            ADJ_O14  4772         
   ADJ_O15  4773            ADJ_O16  4774            ADJ_O17  4775         
   ADJ_O18  4776            ADJ_O19  4777            ADJ_O20  4778         
   ADJ_O21  4779            ADJ_O22  4780            ADJ_O23  4781         
   ADJ_O24  4782            ADJ_O25  4783            ADJ_O26  4784         
   ADJ_O27  4785            ADJ_O28  4786            ADJ_O29  4787         
   ADJ_O30  4788            ADJ_O31  4789            ADJ_O32  4790         
   ADJ_O33  4791            ADJ_O34  4792            ADJ_O35  4793         
   ADJ_O36  4794            ADJ_O37  4795            ADJ_O38  4796         
   ADJ_O39  4797            ADJ_O40  4798            ADJ_O41  4799         
   ADJ_O42  4800            ADJ_OHI  4801            ADJ_P1  4802          
   ADJ_P2  4803             ADJ_P3  4804             ADJ_P4  4805          
   ADJ_P5  4806             ADJ_P6  4807             ADJ_P7  4808          
   ADJ_P8  4809             ADJ_P9  4810             ADJ_P10  4811         
   ADJ_P11  4812            ADJ_P12  4813            ADJ_P13  4814         
   ADJ_P14  4815            ADJ_P15  4816            ADJ_P16  4817         
   ADJ_P17  4818            ADJ_P18  4819            ADJ_P19  4820         
   ADJ_P20  4821            ADJ_P21  4822            ADJ_P22  4823         
   ADJ_P23  4824            ADJ_P24  4825            ADJ_P25  4826         
   ADJ_P26  4827            ADJ_P27  4828            ADJ_P28  4829         
   ADJ_P29  4830            ADJ_P30  4831            ADJ_P31  4832         
   ADJ_P32  4833            ADJ_P33  4834            ADJ_P34  4835         
   ADJ_P35  4836            ADJ_P36  4837            ADJ_P37  4838         
   ADJ_P38  4839            ADJ_P39  4840            ADJ_P40  4841         
   ADJ_P41  4842            ADJ_P42  4843            ADJ_PHI  4844         
   AGGRLR1  4845            AGGRLR2  4846            AGGRLR3  4847         
   AGGRLR4  4848            AGGRLR5  4849            AGGRLR6  4850         
   AGGRLR7  4851            AGGRLR8  4852            AGGRLR9  4853         
   AGGRLR10  4854           AGGRLR11  4855           AGGRLR12  4856        
   AGGRLR13  4857           AGGRLR14  4858           AGGRLR15  4859        
   AGGRLR16  4860           AGGRLR17  4861           AGGRLR18  4862        
   AGGRLR19  4863           AGGRLR20  4864           AGGRLR21  4865        
   AGGRLR22  4866           AGGRLR23  4867           AGGRLR24  4868        
   AGGRLR25  4869           AGGRLR26  4870           AGGRLR27  4871        
   AGGRLR28  4872           AGGRLR29  4873           AGGRLR30  4874        
   AGGRLR31  4875           AGGRLR32  4876           AGGRLR33  4877        
   AGGRLR34  4878           AGGRLR35  4879           AGGRLR36  4880        
   AGGRLR37  4881           AGGRLR38  4882           AGGRLR39  4883        
   AGGRLR40  4884           AGGRLR41  4885           AGGRLR42  4886        
   AGGRLRHI  4887           AGGROL1  4888-4889       AGGROL2  4890         
   AGGROL3  4891            AGGROL4  4892            AGGROL5  4893         
   AGGROL6  4894            AGGROL7  4895            AGGROL8  4896         
   AGGROL9  4897            AGGROL10  4898           AGGROL11  4899        
   AGGROL12  4900           AGGROL13  4901           AGGROL14  4902        
   AGGROL15  4903           AGGROL16  4904           AGGROL17  4905        
   AGGROL18  4906           AGGROL19  4907           AGGROL20  4908        
   AGGROL21  4909           AGGROL22  4910           AGGROL23  4911        
   AGGROL24  4912           AGGROL25  4913           AGGROL26  4914        
   AGGROL27  4915           AGGROL28  4916           AGGROL29  4917        
   AGGROL30  4918           AGGROL31  4919           AGGROL32  4920        
   AGGROL33  4921           AGGROL34  4922           AGGROL35  4923        
   AGGROL36  4924           AGGROL37  4925           AGGROL38  4926        
   AGGROL39  4927           AGGROL40  4928           AGGROL41  4929        
   AGGROL42  4930           AGGROLHI  4931-4932      BASADJ1  4933-4935    
   BASADJ2  4936-4937       BASADJ3  4938-4939       BASADJ4  4940-4941    
   BASADJ5  4942-4943       BASADJ6  4944-4945       BASADJ7  4946-4947    
   BASADJ8  4948-4949       BASADJ9  4950-4951       BASADJ10  4952-4953   
   BASADJ11  4954-4955      BASADJ12  4956-4957      BASADJ13  4958-4959   
   BASADJ14  4960-4961      BASADJ15  4962-4963      BASADJ16  4964-4965   
   BASADJ17  4966-4967      BASADJ18  4968-4969      BASADJ19  4970-4971   
   BASADJ20  4972-4973      BASADJ21  4974-4975      BASADJ22  4976-4977   
   BASADJ23  4978-4979      BASADJ24  4980-4981      BASADJ25  4982-4983   
   BASADJ26  4984-4985      BASADJ27  4986-4987      BASADJ28  4988-4989   
   BASADJ29  4990-4991      BASADJ30  4992-4993      BASADJ31  4994-4995   
   BASADJ32  4996-4997      BASADJ33  4998-4999      BASADJ34  5000-5001   
   BASADJ35  5002-5003      BASADJ36  5004-5005      BASADJ37  5006-5007   
   BASADJ38  5008-5009      BASADJ39  5010-5011      BASADJ40  5012-5013   
   BASADJ41  5014-5015      BASADJ42  5016           BASADJHI  5017-5019   
   BASADR1  5020-5021       BASADR2  5022-5023       BASADR3  5024-5025    
   BASADR4  5026-5027       BASADR5  5028-5029       BASADR6  5030-5031    
   BASADR7  5032-5033       BASADR8  5034-5035       BASADR9  5036-5037    
   BASADR10  5038-5039      BASADR11  5040-5041      BASADR12  5042-5043   
   BASADR13  5044-5045      BASADR14  5046-5047      BASADR15  5048-5049   
   BASADR16  5050-5051      BASADR17  5052-5053      BASADR18  5054-5055   
   BASADR19  5056-5057      BASADR20  5058-5059      BASADR21  5060-5061   
   BASADR22  5062-5063      BASADR23  5064-5065      BASADR24  5066-5067   
   BASADR25  5068-5069      BASADR26  5070-5071      BASADR27  5072-5073   
   BASADR28  5074-5075      BASADR29  5076-5077      BASADR30  5078-5079   
   BASADR31  5080-5081      BASADR32  5082-5083      BASADR33  5084-5085   
   BASADR34  5086-5087      BASADR35  5088-5089      BASADR36  5090-5091   
   BASADR37  5092-5093      BASADR38  5094-5095      BASADR39  5096-5097   
   BASADR40  5098-5099      BASADR41  5100-5101      BASADR42  5102        
   BASADRHI  5103-5104      BASE1  5105-5106         BASE2  5107-5108      
   BASE3  5109-5110         BASE4  5111-5112         BASE5  5113-5114      
   BASE6  5115-5116         BASE7  5117-5118         BASE8  5119-5120      
   BASE9  5121-5122         BASE10  5123-5124        BASE11  5125-5126     
   BASE12  5127-5128        BASE13  5129-5130        BASE14  5131-5132     
   BASE15  5133-5134        BASE16  5135-5136        BASE17  5137-5138     
   BASE18  5139-5140        BASE19  5141-5142        BASE20  5143-5144     
   BASE21  5145-5146        BASE22  5147-5148        BASE23  5149-5150     
   BASE24  5151-5152        BASE25  5153-5154        BASE26  5155-5156     
   BASE27  5157-5158        BASE28  5159-5160        BASE29  5161-5162     
   BASE30  5163-5164        BASE31  5165-5166        BASE32  5167-5168     
   BASE33  5169-5170        BASE34  5171-5172        BASE35  5173-5174     
   BASE36  5175-5176        BASE37  5177-5178        BASE38  5179-5180     
   BASE39  5181-5182        BASE40  5183-5184        BASE41  5185-5186     
   BASE42  5187-5188        BASEHI  5189-5190        BASER1  5191-5192     
   BASER2  5193-5194        BASER3  5195-5196        BASER4  5197-5198     
   BASER5  5199-5200        BASER6  5201-5202        BASER7  5203-5204     
   BASER8  5205-5206        BASER9  5207-5208        BASER10  5209-5210    
   BASER11  5211-5212       BASER12  5213-5214       BASER13  5215-5216    
   BASER14  5217-5218       BASER15  5219-5220       BASER16  5221-5222    
   BASER17  5223-5224       BASER18  5225-5226       BASER19  5227-5228    
   BASER20  5229-5230       BASER21  5231-5232       BASER22  5233-5234    
   BASER23  5235-5236       BASER24  5237-5238       BASER25  5239-5240    
   BASER26  5241-5242       BASER27  5243-5244       BASER28  5245-5246    
   BASER29  5247-5248       BASER30  5249-5250       BASER31  5251-5252    
   BASER32  5253-5254       BASER33  5255-5256       BASER34  5257-5258    
   BASER35  5259-5260       BASER36  5261-5262       BASER37  5263-5264    
   BASER38  5265-5266       BASER39  5267-5268       BASER40  5269-5270    
   BASER41  5271-5272       BASER42  5273            BASERHI  5274-5275    
   FLGHTR1  5276            FLGHTR2  5277            FLGHTR3  5278         
   FLGHTR4  5279            FLGHTR5  5280            FLGHTR6  5281         
   FLGHTR7  5282            FLGHTR8  5283            FLGHTR9  5284         
   FLGHTR10  5285           FLGHTR11  5286           FLGHTR12  5287        
   FLGHTR13  5288           FLGHTR14  5289           FLGHTR15  5290        
   FLGHTR16  5291           FLGHTR17  5292           FLGHTR18  5293        
   FLGHTR19  5294           FLGHTR20  5295           FLGHTR21  5296        
   FLGHTR22  5297           FLGHTR23  5298           FLGHTR24  5299        
   FLGHTR25  5300           FLGHTR26  5301           FLGHTR27  5302        
   FLGHTR28  5303           FLGHTR29  5304           FLGHTR30  5305        
   FLGHTR31  5306           FLGHTR32  5307           FLGHTR33  5308        
   FLGHTR34  5309           FLGHTR35  5310           FLGHTR36  5311        
   FLGHTR37  5312           FLGHTR38  5313           FLGHTR39  5314        
   FLGHTR40  5315           FLGHTR41  5316           FLGHTR42  5317        
   FLGHTRHI  5318           FLIGHT1  5319            FLIGHT2  5320         
   FLIGHT3  5321            FLIGHT4  5322            FLIGHT5  5323         
   FLIGHT6  5324            FLIGHT7  5325            FLIGHT8  5326         
   FLIGHT9  5327            FLIGHT10  5328           FLIGHT11  5329        
   FLIGHT12  5330           FLIGHT13  5331           FLIGHT14  5332        
   FLIGHT15  5333           FLIGHT16  5334           FLIGHT17  5335        
   FLIGHT18  5336           FLIGHT19  5337           FLIGHT20  5338        
   FLIGHT21  5339           FLIGHT22  5340           FLIGHT23  5341        
   FLIGHT24  5342           FLIGHT25  5343           FLIGHT26  5344        
   FLIGHT27  5345           FLIGHT28  5346           FLIGHT29  5347        
   FLIGHT30  5348           FLIGHT31  5349           FLIGHT32  5350        
   FLIGHT33  5351           FLIGHT34  5352           FLIGHT35  5353        
   FLIGHT36  5354           FLIGHT37  5355           FLIGHT38  5356        
   FLIGHT39  5357           FLIGHT40  5358           FLIGHT41  5359        
   FLIGHT42  5360           FLIGHTHI  5361           MITRLR1  5362-5363    
   MITRLR2  5364-5365       MITRLR3  5366-5367       MITRLR4  5368-5369    
   MITRLR5  5370-5371       MITRLR6  5372-5373       MITRLR7  5374         
   MITRLR8  5375            MITRLR9  5376            MITRLR10  5377        
   MITRLR11  5378           MITRLR12  5379           MITRLR13  5380        
   MITRLR14  5381           MITRLR15  5382           MITRLR16  5383        
   MITRLR17  5384           MITRLR18  5385           MITRLR19  5386        
   MITRLR20  5387           MITRLR21  5388           MITRLR22  5389        
   MITRLR23  5390           MITRLR24  5391           MITRLR25  5392        
   MITRLR26  5393           MITRLR27  5394           MITRLR28  5395        
   MITRLR29  5396           MITRLR30  5397           MITRLR31  5398        
   MITRLR32  5399           MITRLR33  5400           MITRLR34  5401        
   MITRLR35  5402           MITRLR36  5403           MITRLR37  5404        
   MITRLR38  5405           MITRLR39  5406           MITRLR40  5407        
   MITRLR41  5408           MITRLR42  5409           MITRLRHI  5410-5411   
   MITROL1  5412-5413       MITROL2  5414-5415       MITROL3  5416-5417    
   MITROL4  5418-5419       MITROL5  5420-5421       MITROL6  5422-5423    
   MITROL7  5424-5425       MITROL8  5426-5427       MITROL9  5428-5429    
   MITROL10  5430           MITROL11  5431           MITROL12  5432        
   MITROL13  5433           MITROL14  5434           MITROL15  5435        
   MITROL16  5436           MITROL17  5437           MITROL18  5438        
   MITROL19  5439           MITROL20  5440           MITROL21  5441        
   MITROL22  5442           MITROL23  5443           MITROL24  5444        
   MITROL25  5445           MITROL26  5446           MITROL27  5447        
   MITROL28  5448           MITROL29  5449           MITROL30  5450        
   MITROL31  5451           MITROL32  5452           MITROL33  5453        
   MITROL34  5454           MITROL35  5455           MITROL36  5456        
   MITROL37  5457           MITROL38  5458           MITROL39  5459        
   MITROL40  5460           MITROL41  5461           MITROL42  5462        
   MITROLHI  5463-5464      OBSTRC1  5465            OBSTRC2  5466         
   OBSTRC3  5467            OBSTRC4  5468            OBSTRC5  5469         
   OBSTRC6  5470            OBSTRC7  5471            OBSTRC8  5472         
   OBSTRC9  5473            OBSTRC10  5474           OBSTRC11  5475        
   OBSTRC12  5476           OBSTRC13  5477           OBSTRC14  5478        
   OBSTRC15  5479           OBSTRC16  5480           OBSTRC17  5481        
   OBSTRC18  5482           OBSTRC19  5483           OBSTRC20  5484        
   OBSTRC21  5485           OBSTRC22  5486           OBSTRC23  5487        
   OBSTRC24  5488           OBSTRC25  5489           OBSTRC26  5490        
   OBSTRC27  5491           OBSTRC28  5492           OBSTRC29  5493        
   OBSTRC30  5494           OBSTRC31  5495           OBSTRC32  5496        
   OBSTRC33  5497           OBSTRC34  5498           OBSTRC35  5499        
   OBSTRC36  5500           OBSTRC37  5501           OBSTRC38  5502        
   OBSTRC39  5503           OBSTRC40  5504           OBSTRC41  5505        
   OBSTRC42  5506           OBSTRCHI  5507           OBSTRR1  5508         
   OBSTRR2  5509            OBSTRR3  5510            OBSTRR4  5511         
   OBSTRR5  5512            OBSTRR6  5513            OBSTRR7  5514         
   OBSTRR8  5515            OBSTRR9  5516            OBSTRR10  5517        
   OBSTRR11  5518           OBSTRR12  5519           OBSTRR13  5520        
   OBSTRR14  5521           OBSTRR15  5522           OBSTRR16  5523        
   OBSTRR17  5524           OBSTRR18  5525           OBSTRR19  5526        
   OBSTRR20  5527           OBSTRR21  5528           OBSTRR22  5529        
   OBSTRR23  5530           OBSTRR24  5531           OBSTRR25  5532        
   OBSTRR26  5533           OBSTRR27  5534           OBSTRR28  5535        
   OBSTRR29  5536           OBSTRR30  5537           OBSTRR31  5538        
   OBSTRR32  5539           OBSTRR33  5540           OBSTRR34  5541        
   OBSTRR35  5542           OBSTRR36  5543           OBSTRR37  5544        
   OBSTRR38  5545           OBSTRR39  5546           OBSTRR40  5547        
   OBSTRR41  5548           OBSTRR42  5549           OBSTRRHI  5550        
   OFFVCR1  5551            OFFVCR2  5552            OFFVCR3  5553         
   OFFVCR4  5554            OFFVCR5  5555            OFFVCR6  5556         
   OFFVCR7  5557            OFFVCR8  5558            OFFVCR9  5559         
   OFFVCR10  5560           OFFVCR11  5561           OFFVCR12  5562        
   OFFVCR13  5563           OFFVCR14  5564           OFFVCR15  5565        
   OFFVCR16  5566           OFFVCR17  5567           OFFVCR18  5568        
   OFFVCR19  5569           OFFVCR20  5570           OFFVCR21  5571        
   OFFVCR22  5572           OFFVCR23  5573           OFFVCR24  5574        
   OFFVCR25  5575           OFFVCR26  5576           OFFVCR27  5577        
   OFFVCR28  5578           OFFVCR29  5579           OFFVCR30  5580        
   OFFVCR31  5581           OFFVCR32  5582           OFFVCR33  5583        
   OFFVCR34  5584           OFFVCR35  5585           OFFVCR36  5586        
   OFFVCR37  5587           OFFVCR38  5588           OFFVCR39  5589        
   OFFVCR40  5590           OFFVCR41  5591           OFFVCR42  5592        
   OFFVCRHI  5593           OFFVCT1  5594            OFFVCT2  5595         
   OFFVCT3  5596            OFFVCT4  5597            OFFVCT5  5598         
   OFFVCT6  5599            OFFVCT7  5600            OFFVCT8  5601         
   OFFVCT9  5602            OFFVCT10  5603           OFFVCT11  5604        
   OFFVCT12  5605           OFFVCT13  5606           OFFVCT14  5607        
   OFFVCT15  5608           OFFVCT16  5609           OFFVCT17  5610        
   OFFVCT18  5611           OFFVCT19  5612           OFFVCT20  5613        
   OFFVCT21  5614           OFFVCT22  5615           OFFVCT23  5616        
   OFFVCT24  5617           OFFVCT25  5618           OFFVCT26  5619        
   OFFVCT27  5620           OFFVCT28  5621           OFFVCT29  5622        
   OFFVCT30  5623           OFFVCT31  5624           OFFVCT32  5625        
   OFFVCT33  5626           OFFVCT34  5627           OFFVCT35  5628        
   OFFVCT36  5629           OFFVCT37  5630           OFFVCT38  5631        
   OFFVCT39  5632           OFFVCT40  5633           OFFVCT41  5634        
   OFFVCT42  5635           OFFVCTHI  5636           RLADJR1  5637         
   RLADJR2  5638            RLADJR3  5639            RLADJR4  5640         
   RLADJR5  5641            RLADJR6  5642            RLADJR7  5643         
   RLADJR8  5644            RLADJR9  5645            RLADJR10  5646        
   RLADJR11  5647           RLADJR12  5648           RLADJR13  5649        
   RLADJR14  5650           RLADJR15  5651           RLADJR16  5652        
   RLADJR17  5653           RLADJR18  5654           RLADJR19  5655        
   RLADJR20  5656           RLADJR21  5657           RLADJR22  5658        
   RLADJR23  5659           RLADJR24  5660           RLADJR25  5661        
   RLADJR26  5662           RLADJR27  5663           RLADJR28  5664        
   RLADJR29  5665           RLADJR30  5666           RLADJR31  5667        
   RLADJR32  5668           RLADJR33  5669           RLADJR34  5670        
   RLADJR35  5671           RLADJR36  5672           RLADJR37  5673        
   RLADJR38  5674           RLADJR39  5675           RLADJR40  5676        
   RLADJR41  5677           RLADJR42  5678           RLADJRHI  5679        
   ROLADJ1  5680            ROLADJ2  5681            ROLADJ3  5682         
   ROLADJ4  5683            ROLADJ5  5684            ROLADJ6  5685         
   ROLADJ7  5686            ROLADJ8  5687            ROLADJ9  5688         
   ROLADJ10  5689           ROLADJ11  5690           ROLADJ12  5691        
   ROLADJ13  5692           ROLADJ14  5693           ROLADJ15  5694        
   ROLADJ16  5695           ROLADJ17  5696           ROLADJ18  5697        
   ROLADJ19  5698           ROLADJ20  5699           ROLADJ21  5700        
   ROLADJ22  5701           ROLADJ23  5702           ROLADJ24  5703        
   ROLADJ25  5704           ROLADJ26  5705           ROLADJ27  5706        
   ROLADJ28  5707           ROLADJ29  5708           ROLADJ30  5709        
   ROLADJ31  5710           ROLADJ32  5711           ROLADJ33  5712        
   ROLADJ34  5713           ROLADJ35  5714           ROLADJ36  5715        
   ROLADJ37  5716           ROLADJ38  5717           ROLADJ39  5718        
   ROLADJ40  5719           ROLADJ41  5720           ROLADJ42  5721        
   ROLADJHI  5722           RSTRVC1  5723            RSTRVC2  5724         
   RSTRVC3  5725            RSTRVC4  5726            RSTRVC5  5727         
   RSTRVC6  5728            RSTRVC7  5729            RSTRVC8  5730         
   RSTRVC9  5731            RSTRVC10  5732           RSTRVC11  5733        
   RSTRVC12  5734           RSTRVC13  5735           RSTRVC14  5736        
   RSTRVC15  5737           RSTRVC16  5738           RSTRVC17  5739        
   RSTRVC18  5740           RSTRVC19  5741           RSTRVC20  5742        
   RSTRVC21  5743           RSTRVC22  5744           RSTRVC23  5745        
   RSTRVC24  5746           RSTRVC25  5747           RSTRVC26  5748        
   RSTRVC27  5749           RSTRVC28  5750           RSTRVC29  5751        
   RSTRVC30  5752           RSTRVC31  5753           RSTRVC32  5754        
   RSTRVC33  5755           RSTRVC34  5756           RSTRVC35  5757        
   RSTRVC36  5758           RSTRVC37  5759           RSTRVC38  5760        
   RSTRVC39  5761           RSTRVC40  5762           RSTRVC41  5763        
   RSTRVC42  5764           RSTRVCHI  5765           RSTRVR1  5766         
   RSTRVR2  5767            RSTRVR3  5768            RSTRVR4  5769         
   RSTRVR5  5770            RSTRVR6  5771            RSTRVR7  5772         
   RSTRVR8  5773            RSTRVR9  5774            RSTRVR10  5775        
   RSTRVR11  5776           RSTRVR12  5777           RSTRVR13  5778        
   RSTRVR14  5779           RSTRVR15  5780           RSTRVR16  5781        
   RSTRVR17  5782           RSTRVR18  5783           RSTRVR19  5784        
   RSTRVR20  5785           RSTRVR21  5786           RSTRVR22  5787        
   RSTRVR23  5788           RSTRVR24  5789           RSTRVR25  5790        
   RSTRVR26  5791           RSTRVR27  5792           RSTRVR28  5793        
   RSTRVR29  5794           RSTRVR30  5795           RSTRVR31  5796        
   RSTRVR32  5797           RSTRVR33  5798           RSTRVR34  5799        
   RSTRVR35  5800           RSTRVR36  5801           RSTRVR37  5802        
   RSTRVR38  5803           RSTRVR39  5804           RSTRVR40  5805        
   RSTRVR41  5806           RSTRVR42  5807           RSTRVRHI  5808        
   TEROR1  5809-5810        TEROR2  5811-5812        TEROR3  5813          
   TEROR4  5814             TEROR5  5815             TEROR6  5816          
   TEROR7  5817             TEROR8  5818             TEROR9  5819          
   TEROR10  5820            TEROR11  5821            TEROR12  5822         
   TEROR13  5823            TEROR14  5824            TEROR15  5825         
   TEROR16  5826            TEROR17  5827            TEROR18  5828         
   TEROR19  5829            TEROR20  5830            TEROR21  5831         
   TEROR22  5832            TEROR23  5833            TEROR24  5834         
   TEROR25  5835            TEROR26  5836            TEROR27  5837         
   TEROR28  5838            TEROR29  5839            TEROR30  5840         
   TEROR31  5841            TEROR32  5842            TEROR33  5843         
   TEROR34  5844            TEROR35  5845            TEROR36  5846         
   TEROR37  5847            TEROR38  5848            TEROR39  5849         
   TEROR40  5850            TEROR41  5851            TEROR42  5852         
   TERORHI  5853-5854       TERORR1  5855-5856       TERORR2  5857         
   TERORR3  5858            TERORR4  5859            TERORR5  5860         
   TERORR6  5861            TERORR7  5862            TERORR8  5863         
   TERORR9  5864            TERORR10  5865           TERORR11  5866        
   TERORR12  5867           TERORR13  5868           TERORR14  5869        
   TERORR15  5870           TERORR16  5871           TERORR17  5872        
   TERORR18  5873           TERORR19  5874           TERORR20  5875        
   TERORR21  5876           TERORR22  5877           TERORR23  5878        
   TERORR24  5879           TERORR25  5880           TERORR26  5881        
   TERORR27  5882           TERORR28  5883           TERORR29  5884        
   TERORR30  5885           TERORR31  5886           TERORR32  5887        
   TERORR33  5888           TERORR34  5889           TERORR35  5890        
   TERORR36  5891           TERORR37  5892           TERORR38  5893        
   TERORR39  5894           TERORR40  5895           TERORR41  5896        
   TERORR42  5897           TERORRHI  5898-5899      USKID1  5900          
   USKID2  5901             USKID3  5902             USKID4  5903          
   USKID5  5904             USKID6  5905             USKID7  5906          
   USKID8  5907             USKID9  5908             USKID10  5909         
   USKID11  5910            USKID12  5911            USKID13  5912         
   USKID14  5913            USKID15  5914            USKID16  5915         
   USKID17  5916            USKID18  5917            USKID19  5918         
   USKID20  5919            USKID21  5920            USKID22  5921         
   USKID23  5922            USKID24  5923            USKID25  5924         
   USKID26  5925            USKID27  5926            USKID28  5927         
   USKID29  5928            USKID30  5929            USKID31  5930         
   USKID32  5931            USKID33  5932            USKID34  5933         
   USKID35  5934            USKID36  5935            USKID37  5936         
   USKID38  5937            USKID39  5938            USKID40  5939         
   USKID41  5940            USKID42  5941            USKIDHI  5942         
   USKIDR1  5943            USKIDR2  5944            USKIDR3  5945         
   USKIDR4  5946            USKIDR5  5947            USKIDR6  5948         
   USKIDR7  5949            USKIDR8  5950            USKIDR9  5951         
   USKIDR10  5952           USKIDR11  5953           USKIDR12  5954        
   USKIDR13  5955           USKIDR14  5956           USKIDR15  5957        
   USKIDR16  5958           USKIDR17  5959           USKIDR18  5960        
   USKIDR19  5961           USKIDR20  5962           USKIDR21  5963        
   USKIDR22  5964           USKIDR23  5965           USKIDR24  5966        
   USKIDR25  5967           USKIDR26  5968           USKIDR27  5969        
   USKIDR28  5970           USKIDR29  5971           USKIDR30  5972        
   USKIDR31  5973           USKIDR32  5974           USKIDR33  5975        
   USKIDR34  5976           USKIDR35  5977           USKIDR36  5978        
   USKIDR37  5979           USKIDR38  5980           USKIDR39  5981        
   USKIDR40  5982           USKIDR41  5983           USKIDR42  5984        
   USKIDRHI  5985           VCADJR1  5986            VCADJR2  5987         
   VCADJR3  5988            VCADJR4  5989            VCADJR5  5990         
   VCADJR6  5991            VCADJR7  5992            VCADJR8  5993         
   VCADJR9  5994            VCADJR10  5995           VCADJR11  5996        
   VCADJR12  5997           VCADJR13  5998           VCADJR14  5999        
   VCADJR15  6000           VCADJR16  6001           VCADJR17  6002        
   VCADJR18  6003           VCADJR19  6004           VCADJR20  6005        
   VCADJR21  6006           VCADJR22  6007           VCADJR23  6008        
   VCADJR24  6009           VCADJR25  6010           VCADJR26  6011        
   VCADJR27  6012           VCADJR28  6013           VCADJR29  6014        
   VCADJR30  6015           VCADJR31  6016           VCADJR32  6017        
   VCADJR33  6018           VCADJR34  6019           VCADJR35  6020        
   VCADJR36  6021           VCADJR37  6022           VCADJR38  6023        
   VCADJR39  6024           VCADJR40  6025           VCADJR41  6026        
   VCADJR42  6027           VCADJRHI  6028           VCTADJ1  6029         
   VCTADJ2  6030            VCTADJ3  6031            VCTADJ4  6032         
   VCTADJ5  6033            VCTADJ6  6034            VCTADJ7  6035         
   VCTADJ8  6036            VCTADJ9  6037            VCTADJ10  6038        
   VCTADJ11  6039           VCTADJ12  6040           VCTADJ13  6041        
   VCTADJ14  6042           VCTADJ15  6043           VCTADJ16  6044        
   VCTADJ17  6045           VCTADJ18  6046           VCTADJ19  6047        
   VCTADJ20  6048           VCTADJ21  6049           VCTADJ22  6050        
   VCTADJ23  6051           VCTADJ24  6052           VCTADJ25  6053        
   VCTADJ26  6054           VCTADJ27  6055           VCTADJ28  6056        
   VCTADJ29  6057           VCTADJ30  6058           VCTADJ31  6059        
   VCTADJ32  6060           VCTADJ33  6061           VCTADJ34  6062        
   VCTADJ35  6063           VCTADJ36  6064           VCTADJ37  6065        
   VCTADJ38  6066           VCTADJ39  6067           VCTADJ40  6068        
   VCTADJ41  6069           VCTADJ42  6070           VCTADJHI  6071        
   VULVCR1  6072            VULVCR2  6073            VULVCR3  6074         
   VULVCR4  6075            VULVCR5  6076            VULVCR6  6077         
   VULVCR7  6078            VULVCR8  6079            VULVCR9  6080         
   VULVCR10  6081           VULVCR11  6082           VULVCR12  6083        
   VULVCR13  6084           VULVCR14  6085           VULVCR15  6086        
   VULVCR16  6087           VULVCR17  6088           VULVCR18  6089        
   VULVCR19  6090           VULVCR20  6091           VULVCR21  6092        
   VULVCR22  6093           VULVCR23  6094           VULVCR24  6095        
   VULVCR25  6096           VULVCR26  6097           VULVCR27  6098        
   VULVCR28  6099           VULVCR29  6100           VULVCR30  6101        
   VULVCR31  6102           VULVCR32  6103           VULVCR33  6104        
   VULVCR34  6105           VULVCR35  6106           VULVCR36  6107        
   VULVCR37  6108           VULVCR38  6109           VULVCR39  6110        
   VULVCR40  6111           VULVCR41  6112           VULVCR42  6113        
   VULVCRHI  6114           VULVCT1  6115            VULVCT2  6116         
   VULVCT3  6117            VULVCT4  6118            VULVCT5  6119         
   VULVCT6  6120            VULVCT7  6121            VULVCT8  6122         
   VULVCT9  6123            VULVCT10  6124           VULVCT11  6125        
   VULVCT12  6126           VULVCT13  6127           VULVCT14  6128        
   VULVCT15  6129           VULVCT16  6130           VULVCT17  6131        
   VULVCT18  6132           VULVCT19  6133           VULVCT20  6134        
   VULVCT21  6135           VULVCT22  6136           VULVCT23  6137        
   VULVCT24  6138           VULVCT25  6139           VULVCT26  6140        
   VULVCT27  6141           VULVCT28  6142           VULVCT29  6143        
   VULVCT30  6144           VULVCT31  6145           VULVCT32  6146        
   VULVCT33  6147           VULVCT34  6148           VULVCT35  6149        
   VULVCT36  6150           VULVCT37  6151           VULVCT38  6152        
   VULVCT39  6153           VULVCT40  6154           VULVCT41  6155        
   VULVCT42  6156           VULVCTHI  6157           GDLINE1 $ 6158-6163   
   GDLINE2 $ 6164-6169      GDLINE3 $ 6170-6175      GDLINE4 $ 6176-6180   
   GDLINE5 $ 6181-6185      GDLINE6 $ 6186-6190      GDLINE7 $ 6191-6195   
   GDLINE8 $ 6196-6200      GDLINE9 $ 6201-6205      GDLINE10 $ 6206-6210  
   GDLINE11 $ 6211-6215     GDLINE12 $ 6216-6220     GDLINE13 $ 6221-6225  
   GDLINE14 $ 6226-6230     GDLINE15 $ 6231-6235     GDLINE16 $ 6236-6240  
   GDLINE17 $ 6241-6245     GDLINE18 $ 6246-6250     GDLINE19 $ 6251-6255  
   GDLINE20 $ 6256-6260     GDLINE21 $ 6261-6265     GDLINE22 $ 6266-6270  
   GDLINE23 $ 6271-6275     GDLINE24 $ 6276-6280     GDLINE25 $ 6281-6285  
   GDLINE26 $ 6286-6290     GDLINE27 $ 6291-6295     GDLINE28 $ 6296-6300  
   GDLINE29 $ 6301-6305     GDLINE30 $ 6306-6310     GDLINE31 $ 6311-6315  
   GDLINE32 $ 6316-6320     GDLINE33 $ 6321-6325     GDLINE34 $ 6326-6330  
   GDLINE35 $ 6331-6335     GDLINE36 $ 6336-6340     GDLINE37 $ 6341-6345  
   GDLINE38 $ 6346-6350     GDLINE39 $ 6351-6355     GDLINE40 $ 6356-6360  
   GDLINE41 $ 6361-6365     GDLINE42 $ 6366-6370     GDSTAT1 $ 6371-6376   
   GDSTAT2 $ 6377-6382      GDSTAT3 $ 6383-6387      GDSTAT4 $ 6388-6392   
   GDSTAT5 $ 6393-6397      GDSTAT6 $ 6398-6402      GDSTAT7 $ 6403-6407   
   GDSTAT8 $ 6408-6412      GDSTAT9 $ 6413-6417      GDSTAT10 $ 6418-6422  
   GDSTAT11 $ 6423-6427     GDSTAT12 $ 6428-6432     GDSTAT13 $ 6433-6437  
   GDSTAT14 $ 6438-6442     GDSTAT15 $ 6443-6447     GDSTAT16 $ 6448-6452  
   GDSTAT17 $ 6453-6457     GDSTAT18 $ 6458-6462     GDSTAT19 $ 6463-6467  
   GDSTAT20 $ 6468-6472     GDSTAT21 $ 6473-6477     GDSTAT22 $ 6478-6482  
   GDSTAT23 $ 6483-6487     GDSTAT24 $ 6488-6492     GDSTAT25 $ 6493-6497  
   GDSTAT26 $ 6498-6502     GDSTAT27 $ 6503-6507     GDSTAT28 $ 6508-6512  
   GDSTAT29 $ 6513-6517     GDSTAT30 $ 6518-6522     GDSTAT31 $ 6523-6527  
   GDSTAT32 $ 6528-6532     GDSTAT33 $ 6533-6537     GDSTAT34 $ 6538-6542  
   GDSTAT35 $ 6543-6547     GDSTAT36 $ 6548-6552     GDSTAT37 $ 6553-6557  
   GDSTAT38 $ 6558-6562     GDSTAT39 $ 6563-6567     GDSTAT40 $ 6568-6572  
   GDSTAT41 $ 6573-6577     GDSTAT42 $ 6578-6582     LOSS1  6583-6592      
   LOSS2  6593-6602         LOSS3  6603-6612         LOSS4  6613-6622      
   LOSS5  6623-6632         LOSS6  6633-6642         LOSS7  6643-6652      
   LOSS8  6653-6662         LOSS9  6663-6672         LOSS10  6673-6682     
   LOSS11  6683-6692        LOSS12  6693-6702        LOSS13  6703-6712     
   LOSS14  6713-6722        LOSS15  6723-6732        LOSS16  6733-6742     
   LOSS17  6743-6746        LOSS18  6747-6750        LOSS19  6751          
   LOSS20  6752             LOSS21  6753             LOSS22  6754          
   LOSS23  6755             LOSS24  6756             LOSS25  6757-6761     
   LOSS26  6762             LOSS27  6763             LOSS28  6764          
   LOSS29  6765             LOSS30  6766             LOSS31  6767          
   LOSS32  6768             LOSS33  6769             LOSS34  6770          
   LOSS35  6771             LOSS36  6772             LOSS37  6773          
   LOSS38  6774             LOSS39  6775             LOSS40  6776          
   LOSS41  6777-6782        LOSS42  6783             GDREF1 $ 6784-6789    
   GDREF2 $ 6790-6795       GDREF3 $ 6796-6801       GDREF4 $ 6802-6806    
   GDREF5 $ 6807-6811       GDREF6 $ 6812-6816       GDREF7 $ 6817-6821    
   GDREF8 $ 6822-6826       GDREF9 $ 6827-6831       GDREF10 $ 6832-6836   
   GDREF11 $ 6837-6841      GDREF12 $ 6842-6846      GDREF13 $ 6847-6851   
   GDREF14 $ 6852-6856      GDREF15 $ 6857-6861      GDREF16 $ 6862-6866   
   GDREF17 $ 6867-6871      GDREF18 $ 6872-6876      GDREF19 $ 6877-6881   
   GDREF20 $ 6882-6886      GDREF21 $ 6887-6891      GDREF22 $ 6892-6896   
   GDREF23 $ 6897-6901      GDREF24 $ 6902-6906      GDREF25 $ 6907-6911   
   GDREF26 $ 6912-6916      GDREF27 $ 6917-6921      GDREF28 $ 6922-6926   
   GDREF29 $ 6927-6931      GDREF30 $ 6932-6936      GDREF31 $ 6937-6941   
   GDREF32 $ 6942-6946      GDREF33 $ 6947-6951      GDREF34 $ 6952-6956   
   GDREF35 $ 6957-6961      GDREF36 $ 6962-6966      GDREF37 $ 6967-6971   
   GDREF38 $ 6972-6976      GDREF39 $ 6977-6981      GDREF40 $ 6982-6986   
   GDREF41 $ 6987-6991      GDREF42 $ 6992-6996      LOSSR1  6997-7006     
   LOSSR2  7007-7016        LOSSR3  7017-7026        LOSSR4  7027-7036     
   LOSSR5  7037-7046        LOSSR6  7047-7052        LOSSR7  7053          
   LOSSR8  7054             LOSSR9  7055-7064        LOSSR10  7065-7069    
   LOSSR11  7070-7075       LOSSR12  7076            LOSSR13  7077         
   LOSSR14  7078-7083       LOSSR15  7084-7088       LOSSR16  7089-7094    
   LOSSR17  7095            LOSSR18  7096            LOSSR19  7097         
   LOSSR20  7098            LOSSR21  7099            LOSSR22  7100         
   LOSSR23  7101            LOSSR24  7102            LOSSR25  7103         
   LOSSR26  7104            LOSSR27  7105            LOSSR28  7106         
   LOSSR29  7107            LOSSR30  7108            LOSSR31  7109         
   LOSSR32  7110            LOSSR33  7111            LOSSR34  7112         
   LOSSR35  7113            LOSSR36  7114            LOSSR37  7115         
   LOSSR38  7116            LOSSR39  7117            LOSSR40  7118         
   LOSSR41  7119            LOSSR42  7120            GDLINEHI $ 7121-7126  
   GDSTATHI $ 7127-7132     LOSSHI  7133-7142        GDREFHI $ 7143-7148   
   LOSSRHI  7149-7158       STA1_1 $ 7159-7171       STA1_2 $ 7172-7183    
   STA1_3 $ 7184-7195       STA1_4 $ 7196-7207       STA1_5 $ 7208-7219    
   STA1_6 $ 7220-7230       STA1_7 $ 7231-7241       STA1_8 $ 7242-7252    
   STA1_9 $ 7253-7264       STA1_10 $ 7265-7275      STA1_11 $ 7276-7286   
   STA1_12 $ 7287-7298      STA1_13 $ 7299-7309      STA1_14 $ 7310-7320   
   STA1_15 $ 7321-7331      STA1_16 $ 7332-7342      STA1_17 $ 7343-7353   
   STA1_18 $ 7354-7364      STA1_19 $ 7365-7375      STA1_20 $ 7376-7386   
   STA1_21 $ 7387-7397      STA1_22 $ 7398-7408      STA1_23 $ 7409-7420   
   STA1_24 $ 7421-7432      STA1_25 $ 7433-7444      STA1_26 $ 7445-7456   
   STA1_27 $ 7457-7468      STA1_28 $ 7469-7480      STA1_29 $ 7481-7492   
   STA1_30 $ 7493-7504      STA1_31 $ 7505-7516      STA1_32 $ 7517-7528   
   STA1_33 $ 7529-7540      STA1_34 $ 7541-7552      STA1_35 $ 7553-7564   
   STA1_36 $ 7565-7576      STA1_37 $ 7577-7588      STA1_38 $ 7589-7600   
   STA1_39 $ 7601-7612      STA1_40 $ 7613-7622      STA1_41 $ 7623-7633   
   STA1_42 $ 7634-7644      STA1_43 $ 7645-7655      STA1_44 $ 7656-7666   
   STA1_45 $ 7667-7677      STA1_46 $ 7678-7688      STA1_47 $ 7689-7699   
   STA1_48 $ 7700-7710      STA1_49 $ 7711-7721      STA1_50 $ 7722-7732   
   STA1_51 $ 7733-7743      STA1_52 $ 7744-7754      STA1_53 $ 7755-7765   
   STA1_54 $ 7766-7776      STA1_55 $ 7777-7787      STA1_56 $ 7788-7798   
   STA1_57 $ 7799-7809      STA1_58 $ 7810-7820      STA1_59 $ 7821-7831   
   STA1_60 $ 7832-7842      STA1_61 $ 7843-7853      STA1_62 $ 7854-7864   
   STA1_63 $ 7865-7875      STA1_64 $ 7876-7886      STA1_65 $ 7887-7897   
   STA1_66 $ 7898-7908      STA1_67 $ 7909-7919      STA1_68 $ 7920-7929   
   STA1_69 $ 7930-7939      STA1_70 $ 7940-7949      STA1_71 $ 7950-7959   
   STA1_72 $ 7960-7969      STA1_73 $ 7970-7979      STA1_74 $ 7980-7989   
   STA1_75 $ 7990-7999      STA1_76 $ 8000-8009      STA1_77 $ 8010-8019   
   STA1_78 $ 8020-8029      STA1_79 $ 8030-8039      STA1_80 $ 8040-8049   
   STA1_81 $ 8050-8059      STA1_82 $ 8060-8069      STA1_83 $ 8070-8079   
   STA1_84 $ 8080-8089      STA1_85 $ 8090-8099      STA1_86 $ 8100-8109   
   STA1_87 $ 8110-8119      STA1_88 $ 8120-8129      STA1_89 $ 8130-8139   
   STA1_90 $ 8140-8149      STA1_91 $ 8150-8159      STA1_92 $ 8160-8169   
   STA1_93 $ 8170-8179      STA1_94 $ 8180-8189      STA1_95 $ 8190-8198   
   STA1_96 $ 8199-8208      STA1_97 $ 8209-8218      STA1_98 $ 8219-8228   
   STA1_99 $ 8229-8238      STA1_100 $ 8239-8248     STA1_101 $ 8249-8257  
   STA1_102 $ 8258-8263     STA1_103 $ 8264-8269     STA1_104 $ 8270-8275  
   STA1_105 $ 8276-8281     STA1_106 $ 8282-8287     STA1_107 $ 8288-8293  
   STA1_108 $ 8294-8299     STA1_109 $ 8300-8305     STA1_110 $ 8306-8311  
   STA1_111 $ 8312-8317     STA1_112 $ 8318-8323     STA1_113 $ 8324-8329  
   STA1_114 $ 8330-8335     STA1_115 $ 8336-8341     STA1_116 $ 8342-8347  
   STA1_117 $ 8348-8353     STA1_118 $ 8354-8359     STA1_119 $ 8360-8365  
   STA1_120 $ 8366-8371     STA1_121 $ 8372-8377     STA1_122 $ 8378-8383  
   STA1_123 $ 8384-8389     STA1_124 $ 8390-8395     STA1_125 $ 8396-8401  
   STA1_126 $ 8402-8407     STA1_127 $ 8408-8413     STA1_128 $ 8414-8416  
   STA1_129 $ 8417-8419     STA1_130 $ 8420-8422     STA1_131 $ 8423-8425  
   STA1_132 $ 8426-8428     STA1_133 $ 8429-8438     STA1_134 $ 8439-8441  
   STA1_135 $ 8442-8444     STA1_136 $ 8445-8447     STA1_137 $ 8448-8450  
   STA1_138 $ 8451-8453     STA1_139 $ 8454-8456     STA1_140 $ 8457-8459  
   STA1_141 $ 8460-8462     STA1_142 $ 8463-8465     STA1_143 $ 8466-8468  
   STA1_144 $ 8469-8471     STA1_145 $ 8472-8474     STA1_146 $ 8475-8477  
   STA1_147 $ 8478-8480     STA1_148 $ 8481-8483     STA1_149 $ 8484-8486  
   STA1_150 $ 8487-8489     STA1_151 $ 8490-8492     STA1_152 $ 8493-8495  
   STA1_153 $ 8496-8498     STA1_154 $ 8499-8501     STA1_155 $ 8502-8504  
   STA1_156 $ 8505-8507     STA1_157 $ 8508-8510     STA1_158 $ 8511-8513  
   STA1_159 $ 8514-8516     STA1_160 $ 8517-8519     STA1_161 $ 8520-8522  
   STA1_162 $ 8523-8525     STA1_163 $ 8526-8528     STA1_164 $ 8529-8531  
   STA1_165 $ 8532-8534     STA1_166 $ 8535-8537     STA1_167 $ 8538-8540  
   STA1_168 $ 8541-8543     STA1_169 $ 8544-8546     STA1_170 $ 8547-8549  
   STA1_171 $ 8550-8552     STA1_172 $ 8553-8555     STA1_173 $ 8556-8558  
   STA1_174 $ 8559-8561     STA1_175 $ 8562-8564     STA1_176 $ 8565-8567  
   STA1_177 $ 8568-8570     STA1_178 $ 8571-8573     STA1_179 $ 8574-8576  
   STA1_180 $ 8577-8579     STA1_181 $ 8580-8582     STA1_182 $ 8583-8585  
   STA1_183 $ 8586-8588     STA1_184 $ 8589-8591     STA1_185 $ 8592-8594  
   STA1_186 $ 8595-8597     STA1_187 $ 8598-8600     STA1_188 $ 8601-8603  
   STA1_189 $ 8604-8606     STA1_190 $ 8607-8609     STA1_191 $ 8610-8612  
   STA1_192 $ 8613-8615     STA1_193 $ 8616-8618     STA1_194 $ 8619-8621  
   STA1_195 $ 8622-8624     STA1_196 $ 8625-8627     STA1_197 $ 8628-8630  
   STA1_198 $ 8631-8633     STA1_199 $ 8634-8636     STA1_200 $ 8637-8639  
   STA1_201 $ 8640-8642     STA1_202 $ 8643-8645     STA1_203 $ 8646-8648  
   STA1_204 $ 8649-8651     STA1_205 $ 8652-8654     STA1_206 $ 8655-8657  
   STA1_207 $ 8658-8660     STA1_208 $ 8661-8663     STA1_209 $ 8664-8666  
   STA1_210 $ 8667-8669     STA1_211 $ 8670-8672     STA1_212 $ 8673-8675  
   STA1_213 $ 8676-8678     STA1_214 $ 8679-8681     STA1_215 $ 8682-8684  
   STA1_216 $ 8685-8687     STA1_217 $ 8688-8690     STA1_218 $ 8691-8693  
   STA1_219 $ 8694-8696     STA1_220 $ 8697-8699     STA1_221 $ 8700-8702  
   STA1_222 $ 8703-8705     STA1_223 $ 8706-8708     STA1_224 $ 8709-8711  
   STA1_225 $ 8712-8714     STA1_226 $ 8715-8717     STA1_227 $ 8718-8720  
   STA1_228 $ 8721-8723     STA1_229 $ 8724-8726     STA1_230 $ 8727-8729  
   STA1_231 $ 8730-8732     STA1_232 $ 8733-8735     STA1_233 $ 8736-8738  
   STA1_234 $ 8739-8741     STA1_235 $ 8742-8744     STA1_236 $ 8745-8747  
   STA1_237 $ 8748-8750     STA1_238 $ 8751-8753     STA1_239 $ 8754-8756  
   STA1_240 $ 8757-8759     STA1_241 $ 8760-8762     STA1_242 $ 8763-8765  
   STA1_243 $ 8766-8768     STA1_244 $ 8769-8771     STA1_245 $ 8772-8774  
   STA1_246 $ 8775-8784     STA1_247 $ 8785-8787     STA1_248 $ 8788-8790  
   STA1_249 $ 8791-8793     STA1_250 $ 8794-8796     STA1_251 $ 8797-8799  
   STA1_252 $ 8800-8802     STA1_253 $ 8803-8805     STA1_254 $ 8806-8808  
   STA1_255 $ 8809-8811     STA1_256 $ 8812-8814     STA1_257 $ 8815-8817  
   STA1_258 $ 8818-8820     STA1_259 $ 8821-8823     STA1_260 $ 8824-8826  
   STA1_261 $ 8827-8829     STA1_262 $ 8830-8832     STA1_263 $ 8833-8835  
   STA1_264 $ 8836-8838     STA1_265 $ 8839-8841     STA1_266 $ 8842-8844  
   STA1_267 $ 8845-8847     STA1_268 $ 8848-8850     STA1_269 $ 8851-8853  
   STA1_270 $ 8854-8856     STA1_271 $ 8857-8859     STA1_272 $ 8860-8862  
   STA1_273 $ 8863-8865     STA1_274 $ 8866-8868     STA1_275 $ 8869-8871  
   STA1_276 $ 8872-8874     STA1_277 $ 8875-8877     STA1_278 $ 8878-8880  
   STA1_279 $ 8881-8883     STA1_280 $ 8884-8886     STA1_281 $ 8887-8889  
   STA1_282 $ 8890-8892     STA1_283 $ 8893-8895     STA1_284 $ 8896-8898  
   STA1_285 $ 8899-8901     STA1_286 $ 8902-8904     STA1_287 $ 8905-8907  
   STA1_288 $ 8908-8910     STA1_289 $ 8911-8913     STA1_290 $ 8914-8916  
   STA1_291 $ 8917-8919     STA1_292 $ 8920-8922     STA1_293 $ 8923-8925  
   STA1_294 $ 8926-8928     STA1_295 $ 8929-8931     STA1_296 $ 8932-8934  
   STA1_297 $ 8935-8937     STA1_298 $ 8938-8940     STA1_299 $ 8941-8943  
   STA1_300 $ 8944-8946     STA1_301 $ 8947-8949     STA1_302 $ 8950-8952  
   STA1_303 $ 8953-8955     STA1_304 $ 8956-8958     STA1_305 $ 8959-8961  
   STA1_306 $ 8962-8964     STA1_307 $ 8965-8967     STA1_308 $ 8968-8970  
   STA1_309 $ 8971-8973     STA1_310 $ 8974-8976     STA1_311 $ 8977-8979  
   STA1_312 $ 8980-8982     STA1_313 $ 8983-8985     STA1_314 $ 8986-8988  
   STA1_315 $ 8989-8991     STA1_316 $ 8992-8994     STA1_317 $ 8995-8997  
   STA1_318 $ 8998-9000     STA1_319 $ 9001-9003     STA1_320 $ 9004-9006  
   STA1_321 $ 9007-9009     STA1_322 $ 9010-9012     STA1_323 $ 9013-9015  
   STA1_324 $ 9016-9018     STA1_325 $ 9019-9021     STA1_326 $ 9022-9024  
   STA1_327 $ 9025-9027     STA1_328 $ 9028-9030     STA1_329 $ 9031-9033  
   STA1_330 $ 9034-9036     STA1_331 $ 9037-9039     STA1_332 $ 9040-9042  
   STA1_333 $ 9043-9045     STA1_334 $ 9046-9048     STA1_335 $ 9049-9051  
   STA1_336 $ 9052-9054     STA1_337 $ 9055-9057     STA1_338 $ 9058-9060  
   STA1_339 $ 9061-9063     STA1_340 $ 9064-9066     STA1_341 $ 9067-9069  
   STA1_342 $ 9070-9079     STA1_343 $ 9080-9082     STA1_344 $ 9083-9085  
   STA1_345 $ 9086-9088     STA1_346 $ 9089-9091     STA1_347 $ 9092-9094  
   STA1_348 $ 9095-9097     STA1_349 $ 9098-9100     STA1_350 $ 9101-9103  
   STA1_351 $ 9104-9106     STA1_352 $ 9107-9109     STA1_353 $ 9110-9112  
   STA1_354 $ 9113-9115     STA1_355 $ 9116-9118     STA1_356 $ 9119-9121  
   STA1_357 $ 9122-9124     STA1_358 $ 9125-9127     STA1_359 $ 9128-9130  
   STA1_360 $ 9131-9133     STA1_361 $ 9134-9136     STA1_362 $ 9137-9139  
   STA1_363 $ 9140-9142     STA1_364 $ 9143-9145     STA1_365 $ 9146-9148  
   STA1_366 $ 9149-9151     STA1_367 $ 9152-9154     STA1_368 $ 9155-9157  
   STA1_369 $ 9158-9160     STA1_370 $ 9161-9163     STA1_371 $ 9164-9166  
   STA1_372 $ 9167-9169     STA1_373 $ 9170-9172     STA1_374 $ 9173-9175  
   STA1_375 $ 9176-9178     STA1_376 $ 9179-9181     STA1_377 $ 9182-9184  
   STA1_378 $ 9185-9187     STA1_379 $ 9188-9190     STA1_380 $ 9191-9193  
   STA1_381 $ 9194-9196     STA1_382 $ 9197-9199     STA1_383 $ 9200-9202  
   STA1_384 $ 9203-9205     STA1_385 $ 9206-9208     STA1_386 $ 9209-9211  
   STA1_387 $ 9212-9214     STA1_388 $ 9215-9217     STA1_389 $ 9218-9220  
   STA1_390 $ 9221-9223     STA1_391 $ 9224-9226     STA1_392 $ 9227-9229  
   STA1_393 $ 9230-9232     STA1_394 $ 9233-9235     STA1_395 $ 9236-9238  
   STA1_396 $ 9239-9241     STA1_397 $ 9242-9244     STA1_398 $ 9245-9247  
   STA1_399 $ 9248-9250     STA1_400 $ 9251-9253     STA1_401 $ 9254-9256  
   STA1_402 $ 9257-9259     STA1_403 $ 9260-9262     STA1_404 $ 9263-9265  
   STA1_405 $ 9266-9268     STA1_406 $ 9269-9271     STA1_407 $ 9272-9274  
   STA1_408 $ 9275-9277     STA1_409 $ 9278-9280     STA1_410 $ 9281-9283  
   STA1_411 $ 9284-9286     STA1_412 $ 9287-9289     STA1_413 $ 9290-9292  
   STA1_414 $ 9293-9295     STA1_415 $ 9296-9298     STA1_416 $ 9299-9301  
   STA1_417 $ 9302-9304     STA1_418 $ 9305-9307     STA1_419 $ 9308-9310  
   STA1_420 $ 9311-9313     STA1_421 $ 9314-9316     STA1_422 $ 9317-9319  
   STA1_423 $ 9320-9322     STA1_424 $ 9323-9325     STA1_425 $ 9326-9328  
   STA1_426 $ 9329-9331     STA1_427 $ 9332-9334     STA1_428 $ 9335-9337  
   STA1_429 $ 9338-9340     STA1_430 $ 9341-9343     STA1_431 $ 9344-9346  
   STA1_432 $ 9347-9349     STA1_433 $ 9350-9352     STA1_434 $ 9353-9355  
   STA1_435 $ 9356-9358     STA1_436 $ 9359-9361     STA1_437 $ 9362-9371  
   STA1_438 $ 9372-9374     STA1_439 $ 9375-9377     STA1_440 $ 9378-9380  
   STA1_441 $ 9381-9383     STA1_442 $ 9384-9386     STA1_443 $ 9387-9389  
   STA1_444 $ 9390-9392     STA1_445 $ 9393-9395     STA1_446 $ 9396-9405  
   STA1_447 $ 9406-9408     STA1_448 $ 9409-9411     STA1_449 $ 9412-9414  
   STA1_450 $ 9415-9417     STA1_451 $ 9418-9420     STA1_452 $ 9421-9423  
   STA1_453 $ 9424-9426     STA1_454 $ 9427-9429     STA1_455 $ 9430-9432  
   STA1_456 $ 9433-9435     STA1_457 $ 9436-9438     STA1_458 $ 9439-9441  
   STA1_459 $ 9442-9444     STA1_460 $ 9445-9447     STA1_461 $ 9448-9450  
   STA1_462 $ 9451-9460     STA1_463 $ 9461-9463     STA1_464 $ 9464-9466  
   STA1_465 $ 9467-9469     STA1_466 $ 9470-9472     STA1_467 $ 9473-9475  
   STA1_468 $ 9476-9478     STA1_469 $ 9479-9481     STA1_470 $ 9482-9484  
   STA1_471 $ 9485-9487     STA1_472 $ 9488-9490     STA1_473 $ 9491-9493  
   STA1_474 $ 9494-9496     STA1_475 $ 9497-9499     STA1_476 $ 9500-9502  
   STA1_477 $ 9503-9505     STA1_478 $ 9506-9508     STA1_479 $ 9509-9511  
   STA1_480 $ 9512-9514     STA1_481 $ 9515-9517     STA1_482 $ 9518-9520  
   STA1_483 $ 9521-9523     STA1_484 $ 9524-9526     STA1_485 $ 9527-9529  
   STA1_486 $ 9530-9532     STA1_487 $ 9533-9535     STA1_488 $ 9536-9538  
   STA1_489 $ 9539-9541     STA1_490 $ 9542-9544     STA1_491 $ 9545-9547  
   STA1_492 $ 9548-9550     STA1_493 $ 9551-9553     STA1_494 $ 9554-9556  
   STA1_495 $ 9557-9559     STA2_1 $ 9560-9572       STA2_2 $ 9573-9584    
   STA2_3 $ 9585-9596       STA2_4 $ 9597-9608       STA2_5 $ 9609-9620    
   STA2_6 $ 9621-9631       STA2_7 $ 9632-9642       STA2_8 $ 9643-9653    
   STA2_9 $ 9654-9664       STA2_10 $ 9665-9675      STA2_11 $ 9676-9686   
   STA2_12 $ 9687-9697      STA2_13 $ 9698-9708      STA2_14 $ 9709-9719   
   STA2_15 $ 9720-9730      STA2_16 $ 9731-9741      STA2_17 $ 9742-9752   
   STA2_18 $ 9753-9763      STA2_19 $ 9764-9774      STA2_20 $ 9775-9785   
   STA2_21 $ 9786-9796      STA2_22 $ 9797-9807      STA2_23 $ 9808-9818   
   STA2_24 $ 9819-9829      STA2_25 $ 9830-9840      STA2_26 $ 9841-9851   
   STA2_27 $ 9852-9862      STA2_28 $ 9863-9873      STA2_29 $ 9874-9884   
   STA2_30 $ 9885-9895      STA2_31 $ 9896-9906      STA2_32 $ 9907-9917   
   STA2_33 $ 9918-9928      STA2_34 $ 9929-9939      STA2_35 $ 9940-9950   
   STA2_36 $ 9951-9961      STA2_37 $ 9962-9972      STA2_38 $ 9973-9983   
   STA2_39 $ 9984-9994      STA2_40 $ 9995-10005     STA2_41 $ 10006-10016 
   STA2_42 $ 10017-10027    STA2_43 $ 10028-10038    STA2_44 $ 10039-10049 
   STA2_45 $ 10050-10060    STA2_46 $ 10061-10071    STA2_47 $ 10072-10082 
   STA2_48 $ 10083-10093    STA2_49 $ 10094-10104    STA2_50 $ 10105-10115 
   STA2_51 $ 10116-10126    STA2_52 $ 10127-10137    STA2_53 $ 10138-10148 
   STA2_54 $ 10149-10159    STA2_55 $ 10160-10170    STA2_56 $ 10171-10181 
   STA2_57 $ 10182-10191    STA2_58 $ 10192-10201    STA2_59 $ 10202-10211 
   STA2_60 $ 10212-10221    STA2_61 $ 10222-10231    STA2_62 $ 10232-10241 
   STA2_63 $ 10242-10251    STA2_64 $ 10252-10261    STA2_65 $ 10262-10271 
   STA2_66 $ 10272-10281    STA2_67 $ 10282-10291    STA2_68 $ 10292-10301 
   STA2_69 $ 10302-10311    STA2_70 $ 10312-10321    STA2_71 $ 10322-10331 
   STA2_72 $ 10332-10341    STA2_73 $ 10342-10351    STA2_74 $ 10352-10361 
   STA2_75 $ 10362-10371    STA2_76 $ 10372-10381    STA2_77 $ 10382-10391 
   STA2_78 $ 10392-10401    STA2_79 $ 10402-10411    STA2_80 $ 10412-10421 
   STA2_81 $ 10422-10431    STA2_82 $ 10432-10441    STA2_83 $ 10442-10451 
   STA2_84 $ 10452-10461    STA2_85 $ 10462-10471    STA2_86 $ 10472-10481 
   STA2_87 $ 10482-10491    STA2_88 $ 10492-10501    STA2_89 $ 10502-10511 
   STA2_90 $ 10512-10521    STA2_91 $ 10522-10531    STA2_92 $ 10532-10541 
   STA2_93 $ 10542-10551    STA2_94 $ 10552-10561    STA2_95 $ 10562-10571 
   STA2_96 $ 10572-10581    STA2_97 $ 10582-10591    STA2_98 $ 10592-10601 
   STA2_99 $ 10602-10611    STA2_100 $ 10612-10621   STA2_101 $ 10622-10631
   STA2_102 $ 10632-10641   STA2_103 $ 10642-10651   STA2_104 $ 10652-10661
   STA2_105 $ 10662-10671   STA2_106 $ 10672-10681   STA2_107 $ 10682-10691
   STA2_108 $ 10692-10701   STA2_109 $ 10702-10711   STA2_110 $ 10712-10721
   STA2_111 $ 10722-10731   STA2_112 $ 10732-10741   STA2_113 $ 10742-10751
   STA2_114 $ 10752-10761   STA2_115 $ 10762-10771   STA2_116 $ 10772-10781
   STA2_117 $ 10782-10791   STA2_118 $ 10792-10801   STA2_119 $ 10802-10811
   STA2_120 $ 10812-10821   STA2_121 $ 10822-10831   STA2_122 $ 10832-10841
   STA2_123 $ 10842-10851   STA2_124 $ 10852-10861   STA2_125 $ 10862-10871
   STA2_126 $ 10872-10881   STA2_127 $ 10882-10891   STA2_128 $ 10892-10901
   STA2_129 $ 10902-10911   STA2_130 $ 10912-10921   STA2_131 $ 10922-10931
   STA2_132 $ 10932-10941   STA2_133 $ 10942         STA2_134 $ 10943-10952
   STA2_135 $ 10953-10962   STA2_136 $ 10963-10972   STA2_137 $ 10973-10982
   STA2_138 $ 10983-10992   STA2_139 $ 10993-11002   STA2_140 $ 11003-11012
   STA2_141 $ 11013-11022   STA2_142 $ 11023-11032   STA2_143 $ 11033-11042
   STA2_144 $ 11043-11052   STA2_145 $ 11053-11062   STA2_146 $ 11063-11072
   STA2_147 $ 11073-11082   STA2_148 $ 11083-11092   STA2_149 $ 11093-11102
   STA2_150 $ 11103-11112   STA2_151 $ 11113-11122   STA2_152 $ 11123-11130
   STA2_153 $ 11131-11140   STA2_154 $ 11141-11150   STA2_155 $ 11151-11160
   STA2_156 $ 11161-11170   STA2_157 $ 11171-11180   STA2_158 $ 11181-11190
   STA2_159 $ 11191-11200   STA2_160 $ 11201-11210   STA2_161 $ 11211-11220
   STA2_162 $ 11221-11230   STA2_163 $ 11231-11240   STA2_164 $ 11241-11250
   STA2_165 $ 11251-11260   STA2_166 $ 11261-11270   STA2_167 $ 11271-11280
   STA2_168 $ 11281-11290   STA2_169 $ 11291-11300   STA2_170 $ 11301-11310
   STA2_171 $ 11311-11320   STA2_172 $ 11321-11330   STA2_173 $ 11331-11340
   STA2_174 $ 11341-11350   STA2_175 $ 11351-11360   STA2_176 $ 11361-11370
   STA2_177 $ 11371-11380   STA2_178 $ 11381-11390   STA2_179 $ 11391-11400
   STA2_180 $ 11401-11410   STA2_181 $ 11411-11420   STA2_182 $ 11421-11430
   STA2_183 $ 11431-11440   STA2_184 $ 11441-11450   STA2_185 $ 11451-11460
   STA2_186 $ 11461-11470   STA2_187 $ 11471-11480   STA2_188 $ 11481-11490
   STA2_189 $ 11491-11500   STA2_190 $ 11501-11510   STA2_191 $ 11511-11520
   STA2_192 $ 11521-11530   STA2_193 $ 11531-11540   STA2_194 $ 11541-11550
   STA2_195 $ 11551-11560   STA2_196 $ 11561-11570   STA2_197 $ 11571-11580
   STA2_198 $ 11581-11590   STA2_199 $ 11591-11600   STA2_200 $ 11601-11610
   STA2_201 $ 11611-11620   STA2_202 $ 11621-11630   STA2_203 $ 11631-11640
   STA2_204 $ 11641-11650   STA2_205 $ 11651-11660   STA2_206 $ 11661-11670
   STA2_207 $ 11671-11680   STA2_208 $ 11681-11690   STA2_209 $ 11691-11700
   STA2_210 $ 11701-11710   STA2_211 $ 11711-11718   STA2_212 $ 11719-11728
   STA2_213 $ 11729-11738   STA2_214 $ 11739-11748   STA2_215 $ 11749-11758
   STA2_216 $ 11759-11768   STA2_217 $ 11769-11778   STA2_218 $ 11779-11788
   STA2_219 $ 11789-11798   STA2_220 $ 11799-11808   STA2_221 $ 11809-11818
   STA2_222 $ 11819-11828   STA2_223 $ 11829-11838   STA2_224 $ 11839-11848
   STA2_225 $ 11849-11858   STA2_226 $ 11859-11868   STA2_227 $ 11869-11878
   STA2_228 $ 11879-11888   STA2_229 $ 11889-11898   STA2_230 $ 11899-11908
   STA2_231 $ 11909-11918   STA2_232 $ 11919-11928   STA2_233 $ 11929-11938
   STA2_234 $ 11939-11948   STA2_235 $ 11949-11958   STA2_236 $ 11959-11968
   STA2_237 $ 11969-11978   STA2_238 $ 11979-11988   STA2_239 $ 11989-11998
   STA2_240 $ 11999-12008   STA2_241 $ 12009-12018   STA2_242 $ 12019-12028
   STA2_243 $ 12029-12038   STA2_244 $ 12039-12048   STA2_245 $ 12049-12058
   STA2_246 $ 12059         STA2_247 $ 12060-12069   STA2_248 $ 12070-12079
   STA2_249 $ 12080-12089   STA2_250 $ 12090-12099   STA2_251 $ 12100-12109
   STA2_252 $ 12110-12119   STA2_253 $ 12120-12129   STA2_254 $ 12130-12139
   STA2_255 $ 12140-12149   STA2_256 $ 12150-12159   STA2_257 $ 12160-12169
   STA2_258 $ 12170-12179   STA2_259 $ 12180-12189   STA2_260 $ 12190-12199
   STA2_261 $ 12200-12209   STA2_262 $ 12210-12219   STA2_263 $ 12220-12229
   STA2_264 $ 12230-12239   STA2_265 $ 12240-12249   STA2_266 $ 12250-12259
   STA2_267 $ 12260-12269   STA2_268 $ 12270-12279   STA2_269 $ 12280-12289
   STA2_270 $ 12290-12299   STA2_271 $ 12300-12309   STA2_272 $ 12310-12319
   STA2_273 $ 12320-12329   STA2_274 $ 12330-12339   STA2_275 $ 12340-12349
   STA2_276 $ 12350-12359   STA2_277 $ 12360-12369   STA2_278 $ 12370-12379
   STA2_279 $ 12380-12389   STA2_280 $ 12390-12399   STA2_281 $ 12400-12409
   STA2_282 $ 12410-12419   STA2_283 $ 12420-12429   STA2_284 $ 12430-12439
   STA2_285 $ 12440-12449   STA2_286 $ 12450-12459   STA2_287 $ 12460-12469
   STA2_288 $ 12470-12479   STA2_289 $ 12480-12489   STA2_290 $ 12490-12499
   STA2_291 $ 12500-12509   STA2_292 $ 12510-12519   STA2_293 $ 12520-12529
   STA2_294 $ 12530-12539   STA2_295 $ 12540-12549   STA2_296 $ 12550-12559
   STA2_297 $ 12560-12569   STA2_298 $ 12570-12579   STA2_299 $ 12580-12589
   STA2_300 $ 12590-12599   STA2_301 $ 12600-12609   STA2_302 $ 12610-12619
   STA2_303 $ 12620-12629   STA2_304 $ 12630-12639   STA2_305 $ 12640-12649
   STA2_306 $ 12650-12659   STA2_307 $ 12660-12669   STA2_308 $ 12670-12679
   STA2_309 $ 12680-12689   STA2_310 $ 12690-12699   STA2_311 $ 12700-12709
   STA2_312 $ 12710-12719   STA2_313 $ 12720-12729   STA2_314 $ 12730-12739
   STA2_315 $ 12740-12749   STA2_316 $ 12750-12759   STA2_317 $ 12760-12769
   STA2_318 $ 12770-12779   STA2_319 $ 12780-12789   STA2_320 $ 12790-12799
   STA2_321 $ 12800-12809   STA2_322 $ 12810-12819   STA2_323 $ 12820-12829
   STA2_324 $ 12830-12839   STA2_325 $ 12840-12849   STA2_326 $ 12850-12859
   STA2_327 $ 12860-12869   STA2_328 $ 12870-12879   STA2_329 $ 12880-12889
   STA2_330 $ 12890-12899   STA2_331 $ 12900-12909   STA2_332 $ 12910-12919
   STA2_333 $ 12920-12929   STA2_334 $ 12930-12939   STA2_335 $ 12940-12949
   STA2_336 $ 12950-12959   STA2_337 $ 12960-12969   STA2_338 $ 12970-12979
   STA2_339 $ 12980-12989   STA2_340 $ 12990-12999   STA2_341 $ 13000-13009
   STA2_342 $ 13010         STA2_343 $ 13011-13020   STA2_344 $ 13021-13030
   STA2_345 $ 13031-13040   STA2_346 $ 13041-13050   STA2_347 $ 13051-13060
   STA2_348 $ 13061-13070   STA2_349 $ 13071-13080   STA2_350 $ 13081-13090
   STA2_351 $ 13091-13100   STA2_352 $ 13101-13110   STA2_353 $ 13111-13120
   STA2_354 $ 13121-13130   STA2_355 $ 13131-13140   STA2_356 $ 13141-13150
   STA2_357 $ 13151-13160   STA2_358 $ 13161-13170   STA2_359 $ 13171-13180
   STA2_360 $ 13181-13190   STA2_361 $ 13191-13200   STA2_362 $ 13201-13210
   STA2_363 $ 13211-13220   STA2_364 $ 13221-13230   STA2_365 $ 13231-13240
   STA2_366 $ 13241-13250   STA2_367 $ 13251-13260   STA2_368 $ 13261-13270
   STA2_369 $ 13271-13280   STA2_370 $ 13281-13290   STA2_371 $ 13291-13300
   STA2_372 $ 13301-13310   STA2_373 $ 13311-13320   STA2_374 $ 13321-13330
   STA2_375 $ 13331-13340   STA2_376 $ 13341-13350   STA2_377 $ 13351-13360
   STA2_378 $ 13361-13370   STA2_379 $ 13371-13380   STA2_380 $ 13381-13390
   STA2_381 $ 13391-13400   STA2_382 $ 13401-13410   STA2_383 $ 13411-13420
   STA2_384 $ 13421-13430   STA2_385 $ 13431-13440   STA2_386 $ 13441-13450
   STA2_387 $ 13451-13460   STA2_388 $ 13461-13470   STA2_389 $ 13471-13480
   STA2_390 $ 13481-13490   STA2_391 $ 13491-13500   STA2_392 $ 13501-13510
   STA2_393 $ 13511-13520   STA2_394 $ 13521-13530   STA2_395 $ 13531-13540
   STA2_396 $ 13541-13550   STA2_397 $ 13551-13560   STA2_398 $ 13561-13570
   STA2_399 $ 13571-13580   STA2_400 $ 13581-13590   STA2_401 $ 13591-13600
   STA2_402 $ 13601-13610   STA2_403 $ 13611-13620   STA2_404 $ 13621-13630
   STA2_405 $ 13631-13640   STA2_406 $ 13641-13650   STA2_407 $ 13651-13660
   STA2_408 $ 13661-13670   STA2_409 $ 13671-13680   STA2_410 $ 13681-13690
   STA2_411 $ 13691-13700   STA2_412 $ 13701-13710   STA2_413 $ 13711-13720
   STA2_414 $ 13721-13730   STA2_415 $ 13731-13740   STA2_416 $ 13741-13750
   STA2_417 $ 13751-13760   STA2_418 $ 13761-13770   STA2_419 $ 13771-13780
   STA2_420 $ 13781-13790   STA2_421 $ 13791-13800   STA2_422 $ 13801-13810
   STA2_423 $ 13811-13820   STA2_424 $ 13821-13830   STA2_425 $ 13831-13840
   STA2_426 $ 13841-13850   STA2_427 $ 13851-13860   STA2_428 $ 13861-13870
   STA2_429 $ 13871-13880   STA2_430 $ 13881-13890   STA2_431 $ 13891-13900
   STA2_432 $ 13901-13910   STA2_433 $ 13911-13920   STA2_434 $ 13921-13930
   STA2_435 $ 13931-13940   STA2_436 $ 13941-13950   STA2_437 $ 13951      
   STA2_438 $ 13952-13961   STA2_439 $ 13962-13971   STA2_440 $ 13972-13981
   STA2_441 $ 13982-13991   STA2_442 $ 13992-14001   STA2_443 $ 14002-14011
   STA2_444 $ 14012-14021   STA2_445 $ 14022-14031   STA2_446 $ 14032      
   STA2_447 $ 14033-14042   STA2_448 $ 14043-14052   STA2_449 $ 14053-14062
   STA2_450 $ 14063-14072   STA2_451 $ 14073-14082   STA2_452 $ 14083-14092
   STA2_453 $ 14093-14102   STA2_454 $ 14103-14112   STA2_455 $ 14113-14122
   STA2_456 $ 14123-14132   STA2_457 $ 14133-14142   STA2_458 $ 14143-14152
   STA2_459 $ 14153-14162   STA2_460 $ 14163-14172   STA2_461 $ 14173-14182
   STA2_462 $ 14183         STA2_463 $ 14184-14193   STA2_464 $ 14194-14203
   STA2_465 $ 14204-14213   STA2_466 $ 14214-14223   STA2_467 $ 14224-14233
   STA2_468 $ 14234-14243   STA2_469 $ 14244-14253   STA2_470 $ 14254-14263
   STA2_471 $ 14264-14273   STA2_472 $ 14274-14283   STA2_473 $ 14284-14293
   STA2_474 $ 14294-14303   STA2_475 $ 14304-14313   STA2_476 $ 14314-14323
   STA2_477 $ 14324-14333   STA2_478 $ 14334-14343   STA2_479 $ 14344-14353
   STA2_480 $ 14354-14363   STA2_481 $ 14364-14373   STA2_482 $ 14374-14383
   STA2_483 $ 14384-14393   STA2_484 $ 14394-14403   STA2_485 $ 14404-14413
   STA2_486 $ 14414-14423   STA2_487 $ 14424-14433   STA2_488 $ 14434-14443
   STA2_489 $ 14444-14453   STA2_490 $ 14454-14463   STA2_491 $ 14464-14473
   STA2_492 $ 14474-14483   STA2_493 $ 14484-14493   STA2_494 $ 14494-14503
   STA2_495 $ 14504-14513   STA3_1 $ 14514-14526     STA3_2 $ 14527-14538  
   STA3_3 $ 14539-14550     STA3_4 $ 14551-14562     STA3_5 $ 14563-14574  
   STA3_6 $ 14575-14585     STA3_7 $ 14586-14596     STA3_8 $ 14597-14607  
   STA3_9 $ 14608-14617     STA3_10 $ 14618-14627    STA3_11 $ 14628-14636 
   STA3_12 $ 14637-14646    STA3_13 $ 14647-14655    STA3_14 $ 14656-14665 
   STA3_15 $ 14666-14674    STA3_16 $ 14675-14682    STA3_17 $ 14683-14690 
   STA3_18 $ 14691-14698    STA3_19 $ 14699-14706    STA3_20 $ 14707-14714 
   STA3_21 $ 14715-14722    STA3_22 $ 14723-14730    STA3_23 $ 14731-14738 
   STA3_24 $ 14739-14746    STA3_25 $ 14747-14754    STA3_26 $ 14755-14762 
   STA3_27 $ 14763-14770    STA3_28 $ 14771-14778    STA3_29 $ 14779-14786 
   STA3_30 $ 14787-14794    STA3_31 $ 14795-14802    STA3_32 $ 14803-14810 
   STA3_33 $ 14811-14818    STA3_34 $ 14819-14826    STA3_35 $ 14827-14834 
   STA3_36 $ 14835-14842    STA3_37 $ 14843-14850    STA3_38 $ 14851-14858 
   STA3_39 $ 14859-14866    STA3_40 $ 14867-14874    STA3_41 $ 14875-14882 
   STA3_42 $ 14883          STA3_43 $ 14884          STA3_44 $ 14885       
   STA3_45 $ 14886          STA3_46 $ 14887          STA3_47 $ 14888       
   STA3_48 $ 14889-14893    STA3_49 $ 14894          STA3_50 $ 14895       
   STA3_51 $ 14896          STA3_52 $ 14897          STA3_53 $ 14898       
   STA3_54 $ 14899          STA3_55 $ 14900          STA3_56 $ 14901       
   STA3_57 $ 14902          STA3_58 $ 14903          STA3_59 $ 14904       
   STA3_60 $ 14905          STA3_61 $ 14906          STA3_62 $ 14907       
   STA3_63 $ 14908          STA3_64 $ 14909          STA3_65 $ 14910       
   STA3_66 $ 14911          STA3_67 $ 14912          STA3_68 $ 14913       
   STA3_69 $ 14914          STA3_70 $ 14915          STA3_71 $ 14916       
   STA3_72 $ 14917          STA3_73 $ 14918          STA3_74 $ 14919       
   STA3_75 $ 14920          STA3_76 $ 14921          STA3_77 $ 14922       
   STA3_78 $ 14923          STA3_79 $ 14924          STA3_80 $ 14925       
   STA3_81 $ 14926          STA3_82 $ 14927          STA3_83 $ 14928       
   STA3_84 $ 14929          STA3_85 $ 14930          STA3_86 $ 14931       
   STA3_87 $ 14932          STA3_88 $ 14933          STA3_89 $ 14934       
   STA3_90 $ 14935          STA3_91 $ 14936          STA3_92 $ 14937       
   STA3_93 $ 14938          STA3_94 $ 14939          STA3_95 $ 14940       
   STA3_96 $ 14941          STA3_97 $ 14942          STA3_98 $ 14943       
   STA3_99 $ 14944          STA3_100 $ 14945         STA3_101 $ 14946      
   STA3_102 $ 14947         STA3_103 $ 14948         STA3_104 $ 14949      
   STA3_105 $ 14950         STA3_106 $ 14951         STA3_107 $ 14952      
   STA3_108 $ 14953         STA3_109 $ 14954         STA3_110 $ 14955      
   STA3_111 $ 14956         STA3_112 $ 14957         STA3_113 $ 14958      
   STA3_114 $ 14959         STA3_115 $ 14960         STA3_116 $ 14961      
   STA3_117 $ 14962         STA3_118 $ 14963         STA3_119 $ 14964      
   STA3_120 $ 14965         STA3_121 $ 14966         STA3_122 $ 14967      
   STA3_123 $ 14968         STA3_124 $ 14969         STA3_125 $ 14970      
   STA3_126 $ 14971         STA3_127 $ 14972         STA3_128 $ 14973      
   STA3_129 $ 14974         STA3_130 $ 14975         STA3_131 $ 14976      
   STA3_132 $ 14977         STA3_133 $ 14978         STA3_134 $ 14979      
   STA3_135 $ 14980         STA3_136 $ 14981         STA3_137 $ 14982      
   STA3_138 $ 14983         STA3_139 $ 14984         STA3_140 $ 14985      
   STA3_141 $ 14986         STA3_142 $ 14987         STA3_143 $ 14988      
   STA3_144 $ 14989         STA3_145 $ 14990         STA3_146 $ 14991      
   STA3_147 $ 14992         STA3_148 $ 14993         STA3_149 $ 14994      
   STA3_150 $ 14995         STA3_151 $ 14996         STA3_152 $ 14997      
   STA3_153 $ 14998         STA3_154 $ 14999         STA3_155 $ 15000      
   STA3_156 $ 15001         STA3_157 $ 15002         STA3_158 $ 15003      
   STA3_159 $ 15004         STA3_160 $ 15005         STA3_161 $ 15006      
   STA3_162 $ 15007         STA3_163 $ 15008         STA3_164 $ 15009      
   STA3_165 $ 15010         STA3_166 $ 15011         STA3_167 $ 15012      
   STA3_168 $ 15013         STA3_169 $ 15014         STA3_170 $ 15015      
   STA3_171 $ 15016         STA3_172 $ 15017         STA3_173 $ 15018      
   STA3_174 $ 15019         STA3_175 $ 15020         STA3_176 $ 15021      
   STA3_177 $ 15022         STA3_178 $ 15023         STA3_179 $ 15024      
   STA3_180 $ 15025         STA3_181 $ 15026         STA3_182 $ 15027      
   STA3_183 $ 15028         STA3_184 $ 15029         STA3_185 $ 15030      
   STA3_186 $ 15031         STA3_187 $ 15032         STA3_188 $ 15033      
   STA3_189 $ 15034         STA3_190 $ 15035         STA3_191 $ 15036      
   STA3_192 $ 15037         STA3_193 $ 15038         STA3_194 $ 15039      
   STA3_195 $ 15040         STA3_196 $ 15041         STA3_197 $ 15042      
   STA3_198 $ 15043         STA3_199 $ 15044         STA3_200 $ 15045      
   STA3_201 $ 15046         STA3_202 $ 15047         STA3_203 $ 15048      
   STA3_204 $ 15049         STA3_205 $ 15050         STA3_206 $ 15051      
   STA3_207 $ 15052         STA3_208 $ 15053         STA3_209 $ 15054      
   STA3_210 $ 15055         STA3_211 $ 15056         STA3_212 $ 15057      
   STA3_213 $ 15058         STA3_214 $ 15059         STA3_215 $ 15060      
   STA3_216 $ 15061         STA3_217 $ 15062         STA3_218 $ 15063      
   STA3_219 $ 15064         STA3_220 $ 15065         STA3_221 $ 15066      
   STA3_222 $ 15067         STA3_223 $ 15068         STA3_224 $ 15069      
   STA3_225 $ 15070         STA3_226 $ 15071         STA3_227 $ 15072      
   STA3_228 $ 15073         STA3_229 $ 15074         STA3_230 $ 15075      
   STA3_231 $ 15076         STA3_232 $ 15077         STA3_233 $ 15078      
   STA3_234 $ 15079         STA3_235 $ 15080         STA3_236 $ 15081      
   STA3_237 $ 15082         STA3_238 $ 15083         STA3_239 $ 15084      
   STA3_240 $ 15085         STA3_241 $ 15086         STA3_242 $ 15087      
   STA3_243 $ 15088         STA3_244 $ 15089         STA3_245 $ 15090      
   STA3_246 $ 15091         STA3_247 $ 15092         STA3_248 $ 15093      
   STA3_249 $ 15094         STA3_250 $ 15095         STA3_251 $ 15096      
   STA3_252 $ 15097         STA3_253 $ 15098         STA3_254 $ 15099      
   STA3_255 $ 15100         STA3_256 $ 15101         STA3_257 $ 15102      
   STA3_258 $ 15103         STA3_259 $ 15104         STA3_260 $ 15105      
   STA3_261 $ 15106         STA3_262 $ 15107         STA3_263 $ 15108      
   STA3_264 $ 15109         STA3_265 $ 15110         STA3_266 $ 15111      
   STA3_267 $ 15112         STA3_268 $ 15113         STA3_269 $ 15114      
   STA3_270 $ 15115         STA3_271 $ 15116         STA3_272 $ 15117      
   STA3_273 $ 15118         STA3_274 $ 15119         STA3_275 $ 15120      
   STA3_276 $ 15121         STA3_277 $ 15122         STA3_278 $ 15123      
   STA3_279 $ 15124         STA3_280 $ 15125         STA3_281 $ 15126      
   STA3_282 $ 15127         STA3_283 $ 15128         STA3_284 $ 15129      
   STA3_285 $ 15130         STA3_286 $ 15131         STA3_287 $ 15132      
   STA3_288 $ 15133         STA3_289 $ 15134         STA3_290 $ 15135      
   STA3_291 $ 15136         STA3_292 $ 15137         STA3_293 $ 15138      
   STA3_294 $ 15139         STA3_295 $ 15140         STA3_296 $ 15141      
   STA3_297 $ 15142         STA3_298 $ 15143         STA3_299 $ 15144      
   STA3_300 $ 15145         STA3_301 $ 15146         STA3_302 $ 15147      
   STA3_303 $ 15148         STA3_304 $ 15149         STA3_305 $ 15150      
   STA3_306 $ 15151         STA3_307 $ 15152         STA3_308 $ 15153      
   STA3_309 $ 15154         STA3_310 $ 15155         STA3_311 $ 15156      
   STA3_312 $ 15157         STA3_313 $ 15158         STA3_314 $ 15159      
   STA3_315 $ 15160         STA3_316 $ 15161         STA3_317 $ 15162      
   STA3_318 $ 15163         STA3_319 $ 15164         STA3_320 $ 15165      
   STA3_321 $ 15166         STA3_322 $ 15167         STA3_323 $ 15168      
   STA3_324 $ 15169         STA3_325 $ 15170         STA3_326 $ 15171      
   STA3_327 $ 15172         STA3_328 $ 15173         STA3_329 $ 15174      
   STA3_330 $ 15175         STA3_331 $ 15176         STA3_332 $ 15177      
   STA3_333 $ 15178         STA3_334 $ 15179         STA3_335 $ 15180      
   STA3_336 $ 15181         STA3_337 $ 15182         STA3_338 $ 15183      
   STA3_339 $ 15184         STA3_340 $ 15185         STA3_341 $ 15186      
   STA3_342 $ 15187         STA3_343 $ 15188         STA3_344 $ 15189      
   STA3_345 $ 15190         STA3_346 $ 15191         STA3_347 $ 15192      
   STA3_348 $ 15193         STA3_349 $ 15194         STA3_350 $ 15195      
   STA3_351 $ 15196         STA3_352 $ 15197         STA3_353 $ 15198      
   STA3_354 $ 15199         STA3_355 $ 15200         STA3_356 $ 15201      
   STA3_357 $ 15202         STA3_358 $ 15203         STA3_359 $ 15204      
   STA3_360 $ 15205         STA3_361 $ 15206         STA3_362 $ 15207      
   STA3_363 $ 15208         STA3_364 $ 15209         STA3_365 $ 15210      
   STA3_366 $ 15211         STA3_367 $ 15212         STA3_368 $ 15213      
   STA3_369 $ 15214         STA3_370 $ 15215         STA3_371 $ 15216      
   STA3_372 $ 15217         STA3_373 $ 15218         STA3_374 $ 15219      
   STA3_375 $ 15220         STA3_376 $ 15221         STA3_377 $ 15222      
   STA3_378 $ 15223         STA3_379 $ 15224         STA3_380 $ 15225      
   STA3_381 $ 15226         STA3_382 $ 15227         STA3_383 $ 15228      
   STA3_384 $ 15229         STA3_385 $ 15230         STA3_386 $ 15231      
   STA3_387 $ 15232         STA3_388 $ 15233         STA3_389 $ 15234      
   STA3_390 $ 15235         STA3_391 $ 15236         STA3_392 $ 15237      
   STA3_393 $ 15238         STA3_394 $ 15239         STA3_395 $ 15240      
   STA3_396 $ 15241         STA3_397 $ 15242         STA3_398 $ 15243      
   STA3_399 $ 15244         STA3_400 $ 15245         STA3_401 $ 15246      
   STA3_402 $ 15247         STA3_403 $ 15248         STA3_404 $ 15249      
   STA3_405 $ 15250         STA3_406 $ 15251         STA3_407 $ 15252      
   STA3_408 $ 15253         STA3_409 $ 15254         STA3_410 $ 15255      
   STA3_411 $ 15256         STA3_412 $ 15257         STA3_413 $ 15258      
   STA3_414 $ 15259         STA3_415 $ 15260         STA3_416 $ 15261      
   STA3_417 $ 15262         STA3_418 $ 15263         STA3_419 $ 15264      
   STA3_420 $ 15265         STA3_421 $ 15266         STA3_422 $ 15267      
   STA3_423 $ 15268         STA3_424 $ 15269         STA3_425 $ 15270      
   STA3_426 $ 15271         STA3_427 $ 15272         STA3_428 $ 15273      
   STA3_429 $ 15274         STA3_430 $ 15275         STA3_431 $ 15276      
   STA3_432 $ 15277         STA3_433 $ 15278         STA3_434 $ 15279      
   STA3_435 $ 15280         STA3_436 $ 15281         STA3_437 $ 15282      
   STA3_438 $ 15283         STA3_439 $ 15284         STA3_440 $ 15285      
   STA3_441 $ 15286         STA3_442 $ 15287         STA3_443 $ 15288      
   STA3_444 $ 15289         STA3_445 $ 15290         STA3_446 $ 15291      
   STA3_447 $ 15292         STA3_448 $ 15293         STA3_449 $ 15294      
   STA3_450 $ 15295         STA3_451 $ 15296         STA3_452 $ 15297      
   STA3_453 $ 15298         STA3_454 $ 15299         STA3_455 $ 15300      
   STA3_456 $ 15301         STA3_457 $ 15302         STA3_458 $ 15303      
   STA3_459 $ 15304         STA3_460 $ 15305         STA3_461 $ 15306      
   STA3_462 $ 15307         STA3_463 $ 15308         STA3_464 $ 15309      
   STA3_465 $ 15310         STA3_466 $ 15311         STA3_467 $ 15312      
   STA3_468 $ 15313         STA3_469 $ 15314         STA3_470 $ 15315      
   STA3_471 $ 15316         STA3_472 $ 15317         STA3_473 $ 15318      
   STA3_474 $ 15319         STA3_475 $ 15320         STA3_476 $ 15321      
   STA3_477 $ 15322         STA3_478 $ 15323         STA3_479 $ 15324      
   STA3_480 $ 15325         STA3_481 $ 15326         STA3_482 $ 15327      
   STA3_483 $ 15328         STA3_484 $ 15329         STA3_485 $ 15330      
   STA3_486 $ 15331         STA3_487 $ 15332         STA3_488 $ 15333      
   STA3_489 $ 15334         STA3_490 $ 15335         STA3_491 $ 15336      
   STA3_492 $ 15337         STA3_493 $ 15338         STA3_494 $ 15339      
   STA3_495 $ 15340         NWSTAT1 $ 15341-15353    NWSTAT2 $ 15354-15366 
   NWSTAT3 $ 15367-15378    NWSTAT4 $ 15379-15390    NWSTAT5 $ 15391-15403 
   NWSTAT6 $ 15404-15415    NWSTAT7 $ 15416-15427    NWSTAT8 $ 15428-15438 
   NWSTAT9 $ 15439-15450    NWSTAT10 $ 15451-15461   NWSTAT11 $ 15462-15471
   NWSTAT12 $ 15472-15481   NWSTAT13 $ 15482-15492   NWSTAT14 $ 15493-15500
   OFBEG1 DATE11.           OFBEG2 DATE11.           OFBEG3 DATE11.        
   OFBEG4 DATE11.           OFBEG5 DATE11.           OFBEG6 DATE11.        
   OFBEG7 DATE11.           OFBEG8 DATE11.           OFBEG9 DATE11.        
   OFBEG10 DATE11.          OFBEG11 DATE11.          OFBEG12 DATE11.       
   OFBEG13 DATE11.          OFBEG14 DATE11.          OFBEG15 DATE11.       
   OFBEG16 DATE11.          OFBEG17 DATE11.          OFBEG18 DATE11.       
   OFBEG19 DATE11.          OFBEG20 DATE11.          OFBEG21 DATE11.       
   OFBEG22 DATE11.          OFBEG23 DATE11.          OFBEG24 DATE11.       
   OFBEG25 DATE11.          OFBEG26 DATE11.          OFBEG27 DATE11.       
   OFBEG28 DATE11.          OFBEG29 DATE11.          OFBEG30 DATE11.       
   OFBEG31 DATE11.          OFBEG32 DATE11.          OFBEG33 DATE11.       
   OFBEG34 DATE11.          OFBEG35 DATE11.          OFBEG36 DATE11.       
   OFBEG37 DATE11.          OFBEG38 DATE11.          OFBEG39 DATE11.       
   OFBEG40 DATE11.          OFBEG41 DATE11.          OFBEG42 DATE11.       
   OFBEG43 DATE11.          OFBEG44 DATE11.          OFBEG45 DATE11.       
   OFBEG46 DATE11.          OFBEG47 DATE11.          OFBEG48 DATE11.       
   OFBEG49 DATE11.          OFBEG50 DATE11.          OFBEG51 DATE11.       
   OFBEG52 DATE11.          OFBEG53 DATE11.          OFBEG54 DATE11.       
   OFBEG55 DATE11.          OFBEG56 DATE11.          OFBEG57 DATE11.       
   OFBEG58 DATE11.          OFBEG59 DATE11.          OFBEG60 DATE11.       
   OFBEG61 DATE11.          OFBEG62 DATE11.          OFBEG63 DATE11.       
   OFBEG64 DATE11.          OFBEG65 DATE11.          OFBEG66 DATE11.       
   OFBEG67 DATE11.          OFBEG68 DATE11.          OFBEG69 DATE11.       
   OFBEG70 DATE11.          OFBEG71 DATE11.          OFBEG72 DATE11.       
   OFBEG73 DATE11.          OFBEG74 DATE11.          OFBEG75 DATE11.       
   OFBEG76 DATE11.          OFBEG77 DATE11.          OFBEG78 DATE11.       
   OFBEG79 DATE11.          OFBEG80 DATE11.          OFBEG81 DATE11.       
   OFBEG82 DATE11.          OFBEG83 DATE11.          OFBEG84 DATE11.       
   OFBEG85 DATE11.          OFBEG86 DATE11.          OFBEG87 DATE11.       
   OFBEG88 DATE11.          OFBEG89 DATE11.          OFBEG90 DATE11.       
   OFBEG91 DATE11.          OFBEG92 DATE11.          OFBEG93 DATE11.       
   OFBEG94 DATE11.          OFBEG95 DATE11.          OFBEG96 DATE11.       
   OFBEG97 DATE11.          OFBEG98 DATE11.          OFBEG99 DATE11.       
   OFBEG100 DATE11.         OFBEG101 DATE11.         OFBEG102 DATE11.      
   OFBEG103 DATE11.         OFBEG104 DATE11.         OFBEG105 DATE11.      
   OFBEG106 DATE11.         OFBEG107 DATE11.         OFBEG108 DATE11.      
   OFBEG109 DATE11.         OFBEG110 DATE11.         OFBEG111 DATE11.      
   OFBEG112 DATE11.         OFBEG113 DATE11.         OFBEG114 DATE11.      
   OFBEG115 DATE11.         OFBEG116 DATE11.         OFBEG117 DATE11.      
   OFBEG118 DATE11.         OFBEG119 DATE11.         OFBEG120 DATE11.      
   OFBEG121 DATE11.         OFBEG122 DATE11.         OFBEG123 DATE11.      
   OFBEG124 DATE11.         OFBEG125 DATE11.         OFBEG126 DATE11.      
   OFBEG127 DATE11.         OFBEG128 DATE11.         OFBEG129 DATE11.      
   OFBEG130 DATE11.         OFBEG131 DATE11.         OFBEG132 DATE11.      
   OFBEG133 DATE11.         OFBEG134 DATE11.         OFBEG135 DATE11.      
   OFBEG136 DATE11.         OFBEG137 DATE11.         OFBEG138 DATE11.      
   OFBEG139 DATE11.         OFBEG140 DATE11.         OFBEG141 DATE11.      
   OFBEG142 DATE11.         OFBEG143 DATE11.         OFBEG144 DATE11.      
   OFBEG145 DATE11.         OFBEG146 DATE11.         OFBEG147 DATE11.      
   OFBEG148 DATE11.         OFBEG149 DATE11.         OFBEG150 DATE11.      
   OFBEG151 DATE11.         OFBEG152 DATE11.         OFBEG153 DATE11.      
   OFBEG154 DATE11.         OFBEG155 DATE11.         OFBEG156 DATE11.      
   OFBEG157 DATE11.         OFBEG158 DATE11.         OFBEG159 DATE11.      
   OFBEG160 DATE11.         OFBEG161 DATE11.         OFBEG162 DATE11.      
   OFBEG163 DATE11.         OFBEG164 DATE11.         OFBEG165 DATE11.      
   OFBEG166 DATE11.         OFBEG167 DATE11.         OFBEG168 DATE11.      
   OFBEG169 DATE11.         OFBEG170 DATE11.         OFBEG171 DATE11.      
   OFBEG172 DATE11.         OFBEG173 DATE11.         OFBEG174 DATE11.      
   OFBEG175 DATE11.         OFBEG176 DATE11.         OFBEG177 DATE11.      
   OFBEG178 DATE11.         OFBEG179 DATE11.         OFBEG180 DATE11.      
   OFBEG181 DATE11.         OFBEG182 DATE11.         OFBEG183 DATE11.      
   OFBEG184 DATE11.         OFBEG185 DATE11.         OFBEG186 DATE11.      
   OFBEG187 DATE11.         OFBEG188 DATE11.         OFBEG189 DATE11.      
   OFBEG190 DATE11.         OFBEG191 DATE11.         OFBEG192 DATE11.      
   OFBEG193 DATE11.         OFBEG194 DATE11.         OFBEG195 DATE11.      
   OFBEG196 DATE11.         OFBEG197 DATE11.         OFBEG198 DATE11.      
   OFBEG199 DATE11.         OFBEG200 DATE11.         OFBEG201 DATE11.      
   OFBEG202 DATE11.         OFBEG203 DATE11.         OFBEG204 DATE11.      
   OFBEG205 DATE11.         OFBEG206 DATE11.         OFBEG207 DATE11.      
   OFBEG208 DATE11.         OFBEG209 DATE11.         OFBEG210 DATE11.      
   OFBEG211 DATE11.         OFBEG212 DATE11.         OFBEG213 DATE11.      
   OFBEG214 DATE11.         OFBEG215 DATE11.         OFBEG216 DATE11.      
   OFBEG217 DATE11.         OFBEG218 DATE11.         OFBEG219 DATE11.      
   OFBEG220 DATE11.         OFBEG221 DATE11.         OFBEG222 DATE11.      
   OFBEG223 DATE11.         OFBEG224 DATE11.         OFBEG225 DATE11.      
   OFBEG226 DATE11.         OFBEG227 DATE11.         OFBEG228 DATE11.      
   OFBEG229 DATE11.         OFBEG230 DATE11.         OFBEG231 DATE11.      
   OFBEG232 DATE11.         OFBEG233 DATE11.         OFBEG234 DATE11.      
   OFBEG235 DATE11.         OFBEG236 DATE11.         OFBEG237 DATE11.      
   OFBEG238 DATE11.         OFBEG239 DATE11.         OFBEG240 DATE11.      
   OFBEG241 DATE11.         OFBEG242 DATE11.         OFBEG243 DATE11.      
   OFBEG244 DATE11.         OFBEG245 DATE11.         OFBEG246 DATE11.      
   OFBEG247 DATE11.         OFBEG248 DATE11.         OFBEG249 DATE11.      
   OFBEG250 DATE11.         OFBEG251 DATE11.         OFBEG252 DATE11.      
   OFBEG253 DATE11.         OFBEG254 DATE11.         OFBEG255 DATE11.      
   OFBEG256 DATE11.         OFBEG257 DATE11.         OFBEG258 DATE11.      
   OFBEG259 DATE11.         OFBEG260 DATE11.         OFBEG261 DATE11.      
   OFBEG262 DATE11.         OFBEG263 DATE11.         OFBEG264 DATE11.      
   OFBEG265 DATE11.         OFBEG266 DATE11.         OFBEG267 DATE11.      
   OFBEG268 DATE11.         OFBEG269 DATE11.         OFBEG270 DATE11.      
   OFBEG271 DATE11.         OFBEG272 DATE11.         OFBEG273 DATE11.      
   OFBEG274 DATE11.         OFBEG275 DATE11.         OFBEG276 DATE11.      
   OFBEG277 DATE11.         OFBEG278 DATE11.         OFBEG279 DATE11.      
   OFBEG280 DATE11.         OFBEG281 DATE11.         OFBEG282 DATE11.      
   OFBEG283 DATE11.         OFBEG284 DATE11.         OFBEG285 DATE11.      
   OFBEG286 DATE11.         OFBEG287 DATE11.         OFBEG288 DATE11.      
   OFBEG289 DATE11.         OFBEG290 DATE11.         OFBEG291 DATE11.      
   OFBEG292 DATE11.         OFBEG293 DATE11.         OFBEG294 DATE11.      
   OFBEG295 DATE11.         OFBEG296 DATE11.         OFBEG297 DATE11.      
   OFBEG298 DATE11.         OFBEG299 DATE11.         OFBEG300 DATE11.      
   OFBEG301 DATE11.         OFBEG302 DATE11.         OFBEG303 DATE11.      
   OFBEG304 DATE11.         OFBEG305 DATE11.         OFBEG306 DATE11.      
   OFBEG307 DATE11.         OFBEG308 DATE11.         OFBEG309 DATE11.      
   OFBEG310 DATE11.         OFBEG311 DATE11.         OFBEG312 DATE11.      
   OFBEG313 DATE11.         OFBEG314 DATE11.         OFBEG315 DATE11.      
   OFBEG316 DATE11.         OFBEG317 DATE11.         OFBEG318 DATE11.      
   OFBEG319 DATE11.         OFBEG320 DATE11.         OFBEG321 DATE11.      
   OFBEG322 DATE11.         OFBEG323 DATE11.         OFBEG324 DATE11.      
   OFBEG325 DATE11.         OFBEG326 DATE11.         OFBEG327 DATE11.      
   OFBEG328 DATE11.         OFBEG329 DATE11.         OFBEG330 DATE11.      
   OFBEG331 DATE11.         OFBEG332 DATE11.         OFBEG333 DATE11.      
   OFBEG334 DATE11.         OFBEG335 DATE11.         OFBEG336 DATE11.      
   OFBEG337 DATE11.         OFBEG338 DATE11.         OFBEG339 DATE11.      
   OFBEG340 DATE11.         OFBEG341 DATE11.         OFBEG342 DATE11.      
   OFBEG343 DATE11.         OFBEG344 DATE11.         OFBEG345 DATE11.      
   OFBEG346 DATE11.         OFBEG347 DATE11.         OFBEG348 DATE11.      
   OFBEG349 DATE11.         OFBEG350 DATE11.         OFBEG351 DATE11.      
   OFBEG352 DATE11.         OFBEG353 DATE11.         OFBEG354 DATE11.      
   OFBEG355 DATE11.         OFBEG356 DATE11.         OFBEG357 DATE11.      
   OFBEG358 DATE11.         OFBEG359 DATE11.         OFBEG360 DATE11.      
   OFBEG361 DATE11.         OFBEG362 DATE11.         OFBEG363 DATE11.      
   OFBEG364 DATE11.         OFBEG365 DATE11.         OFBEG366 DATE11.      
   OFBEG367 DATE11.         OFBEG368 DATE11.         OFBEG369 DATE11.      
   OFBEG370 DATE11.         OFBEG371 DATE11.         OFBEG372 DATE11.      
   OFBEG373 DATE11.         OFBEG374 DATE11.         OFBEG375 DATE11.      
   OFBEG376 DATE11.         OFBEG377 DATE11.         OFBEG378 DATE11.      
   OFBEG379 DATE11.         OFBEG380 DATE11.         OFBEG381 DATE11.      
   OFBEG382 DATE11.         OFBEG383 DATE11.         OFBEG384 DATE11.      
   OFBEG385 DATE11.         OFBEG386 DATE11.         OFBEG387 DATE11.      
   OFBEG388 DATE11.         OFBEG389 DATE11.         OFBEG390 DATE11.      
   OFBEG391 DATE11.         OFBEG392 DATE11.         OFBEG393 DATE11.      
   OFBEG394 DATE11.         OFBEG395 DATE11.         OFBEG396 DATE11.      
   OFBEG397 DATE11.         OFBEG398 DATE11.         OFBEG399 DATE11.      
   OFBEG400 DATE11.         OFBEG401 DATE11.         OFBEG402 DATE11.      
   OFBEG403 DATE11.         OFBEG404 DATE11.         OFBEG405 DATE11.      
   OFBEG406 DATE11.         OFBEG407 DATE11.         OFBEG408 DATE11.      
   OFBEG409 DATE11.         OFBEG410 DATE11.         OFBEG411 DATE11.      
   OFBEG412 DATE11.         OFBEG413 DATE11.         OFBEG414 DATE11.      
   OFBEG415 DATE11.         OFBEG416 DATE11.         OFBEG417 DATE11.      
   OFBEG418 DATE11.         OFBEG419 DATE11.         OFBEG420 DATE11.      
   OFBEG421 DATE11.         OFBEG422 DATE11.         OFBEG423 DATE11.      
   OFBEG424 DATE11.         OFBEG425 DATE11.         OFBEG426 DATE11.      
   OFBEG427 DATE11.         OFBEG428 DATE11.         OFBEG429 DATE11.      
   OFBEG430 DATE11.         OFBEG431 DATE11.         OFBEG432 DATE11.      
   OFBEG433 DATE11.         OFBEG434 DATE11.         OFBEG435 DATE11.      
   OFBEG436 DATE11.         OFBEG437 DATE11.         OFBEG438 DATE11.      
   OFBEG439 DATE11.         OFBEG440 DATE11.         OFBEG441 DATE11.      
   OFBEG442 DATE11.         OFBEG443 DATE11.         OFBEG444 DATE11.      
   OFBEG445 DATE11.         OFBEG446 DATE11.         OFBEG447 DATE11.      
   OFBEG448 DATE11.         OFBEG449 DATE11.         OFBEG450 DATE11.      
   OFBEG451 DATE11.         OFBEG452 DATE11.         OFBEG453 DATE11.      
   OFBEG454 DATE11.         OFBEG455 DATE11.         OFBEG456 DATE11.      
   OFBEG457 DATE11.         OFBEG458 DATE11.         OFBEG459 DATE11.      
   OFBEG460 DATE11.         OFBEG461 DATE11.         OFBEG462 DATE11.      
   OFBEG463 DATE11.         OFBEG464 DATE11.         OFBEG465 DATE11.      
   OFBEG466 DATE11.         OFBEG467 DATE11.         OFBEG468 DATE11.      
   OFBEG469 DATE11.         OFBEG470 DATE11.         OFBEG471 DATE11.      
   OFBEG472 DATE11.         OFBEG473 DATE11.         OFBEG474 DATE11.      
   OFBEG475 DATE11.         OFBEG476 DATE11.         OFBEG477 DATE11.      
   OFBEG478 DATE11.         OFBEG479 DATE11.         OFBEG480 DATE11.      
   OFBEG481 DATE11.         OFBEG482 DATE11.         OFBEG483 DATE11.      
   OFBEG484 DATE11.         OFBEG485 DATE11.         OFBEG486 DATE11.      
   OFBEG487 DATE11.         OFBEG488 DATE11.         OFBEG489 DATE11.      
   OFBEG490 DATE11.         OFBEG491 DATE11.         OFBEG492 DATE11.      
   OFBEG493 DATE11.         OFBEG494 DATE11.         OFBEG495 DATE11.      
   OFEND1 DATE11.           OFEND2 DATE11.           OFEND3 DATE11.        
   OFEND4 DATE11.           OFEND5 DATE11.           OFEND6 DATE11.        
   OFEND7 DATE11.           OFEND8 DATE11.           OFEND9 DATE11.        
   OFEND10 DATE11.          OFEND11 DATE11.          OFEND12 DATE11.       
   OFEND13 DATE11.          OFEND14 DATE11.          OFEND15 DATE11.       
   OFEND16 DATE11.          OFEND17 DATE11.          OFEND18 DATE11.       
   OFEND19 DATE11.          OFEND20 DATE11.          OFEND21 DATE11.       
   OFEND22 DATE11.          OFEND23 DATE11.          OFEND24 DATE11.       
   OFEND25 DATE11.          OFEND26 DATE11.          OFEND27 DATE11.       
   OFEND28 DATE11.          OFEND29 DATE11.          OFEND30 DATE11.       
   OFEND31 DATE11.          OFEND32 DATE11.          OFEND33 DATE11.       
   OFEND34 DATE11.          OFEND35 DATE11.          OFEND36 DATE11.       
   OFEND37 DATE11.          OFEND38 DATE11.          OFEND39 DATE11.       
   OFEND40 DATE11.          OFEND41 DATE11.          OFEND42 DATE11.       
   OFEND43 DATE11.          OFEND44 DATE11.          OFEND45 DATE11.       
   OFEND46 DATE11.          OFEND47 DATE11.          OFEND48 DATE11.       
   OFEND49 DATE11.          OFEND50 DATE11.          OFEND51 DATE11.       
   OFEND52 DATE11.          OFEND53 DATE11.          OFEND54 DATE11.       
   OFEND55 DATE11.          OFEND56 DATE11.          OFEND57 DATE11.       
   OFEND58 DATE11.          OFEND59 DATE11.          OFEND60 DATE11.       
   OFEND61 DATE11.          OFEND62 DATE11.          OFEND63 DATE11.       
   OFEND64 DATE11.          OFEND65 DATE11.          OFEND66 DATE11.       
   OFEND67 DATE11.          OFEND68 DATE11.          OFEND69 DATE11.       
   OFEND70 DATE11.          OFEND71 DATE11.          OFEND72 DATE11.       
   OFEND73 DATE11.          OFEND74 DATE11.          OFEND75 DATE11.       
   OFEND76 DATE11.          OFEND77 DATE11.          OFEND78 DATE11.       
   OFEND79 DATE11.          OFEND80 DATE11.          OFEND81 DATE11.       
   OFEND82 DATE11.          OFEND83 DATE11.          OFEND84 DATE11.       
   OFEND85 DATE11.          OFEND86 DATE11.          OFEND87 DATE11.       
   OFEND88 DATE11.          OFEND89 DATE11.          OFEND90 DATE11.       
   OFEND91 DATE11.          OFEND92 DATE11.          OFEND93 DATE11.       
   OFEND94 DATE11.          OFEND95 DATE11.          OFEND96 DATE11.       
   OFEND97 DATE11.          OFEND98 DATE11.          OFEND99 DATE11.       
   OFEND100 DATE11.         OFEND101 DATE11.         OFEND102 DATE11.      
   OFEND103 DATE11.         OFEND104 DATE11.         OFEND105 DATE11.      
   OFEND106 DATE11.         OFEND107 DATE11.         OFEND108 DATE11.      
   OFEND109 DATE11.         OFEND110 DATE11.         OFEND111 DATE11.      
   OFEND112 DATE11.         OFEND113 DATE11.         OFEND114 DATE11.      
   OFEND115 DATE11.         OFEND116 DATE11.         OFEND117 DATE11.      
   OFEND118 DATE11.         OFEND119 DATE11.         OFEND120 DATE11.      
   OFEND121 DATE11.         OFEND122 DATE11.         OFEND123 DATE11.      
   OFEND124 DATE11.         OFEND125 DATE11.         OFEND126 DATE11.      
   OFEND127 DATE11.         OFEND128 DATE11.         OFEND129 DATE11.      
   OFEND130 DATE11.         OFEND131 DATE11.         OFEND132 DATE11.      
   OFEND133 DATE11.         OFEND134 DATE11.         OFEND135 DATE11.      
   OFEND136 DATE11.         OFEND137 DATE11.         OFEND138 DATE11.      
   OFEND139 DATE11.         OFEND140 DATE11.         OFEND141 DATE11.      
   OFEND142 DATE11.         OFEND143 DATE11.         OFEND144 DATE11.      
   OFEND145 DATE11.         OFEND146 DATE11.         OFEND147 DATE11.      
   OFEND148 DATE11.         OFEND149 DATE11.         OFEND150 DATE11.      
   OFEND151 DATE11.         OFEND152 DATE11.         OFEND153 DATE11.      
   OFEND154 DATE11.         OFEND155 DATE11.         OFEND156 DATE11.      
   OFEND157 DATE11.         OFEND158 DATE11.         OFEND159 DATE11.      
   OFEND160 DATE11.         OFEND161 DATE11.         OFEND162 DATE11.      
   OFEND163 DATE11.         OFEND164 DATE11.         OFEND165 DATE11.      
   OFEND166 DATE11.         OFEND167 DATE11.         OFEND168 DATE11.      
   OFEND169 DATE11.         OFEND170 DATE11.         OFEND171 DATE11.      
   OFEND172 DATE11.         OFEND173 DATE11.         OFEND174 DATE11.      
   OFEND175 DATE11.         OFEND176 DATE11.         OFEND177 DATE11.      
   OFEND178 DATE11.         OFEND179 DATE11.         OFEND180 DATE11.      
   OFEND181 DATE11.         OFEND182 DATE11.         OFEND183 DATE11.      
   OFEND184 DATE11.         OFEND185 DATE11.         OFEND186 DATE11.      
   OFEND187 DATE11.         OFEND188 DATE11.         OFEND189 DATE11.      
   OFEND190 DATE11.         OFEND191 DATE11.         OFEND192 DATE11.      
   OFEND193 DATE11.         OFEND194 DATE11.         OFEND195 DATE11.      
   OFEND196 DATE11.         OFEND197 DATE11.         OFEND198 DATE11.      
   OFEND199 DATE11.         OFEND200 DATE11.         OFEND201 DATE11.      
   OFEND202 DATE11.         OFEND203 DATE11.         OFEND204 DATE11.      
   OFEND205 DATE11.         OFEND206 DATE11.         OFEND207 DATE11.      
   OFEND208 DATE11.         OFEND209 DATE11.         OFEND210 DATE11.      
   OFEND211 DATE11.         OFEND212 DATE11.         OFEND213 DATE11.      
   OFEND214 DATE11.         OFEND215 DATE11.         OFEND216 DATE11.      
   OFEND217 DATE11.         OFEND218 DATE11.         OFEND219 DATE11.      
   OFEND220 DATE11.         OFEND221 DATE11.         OFEND222 DATE11.      
   OFEND223 DATE11.         OFEND224 DATE11.         OFEND225 DATE11.      
   OFEND226 DATE11.         OFEND227 DATE11.         OFEND228 DATE11.      
   OFEND229 DATE11.         OFEND230 DATE11.         OFEND231 DATE11.      
   OFEND232 DATE11.         OFEND233 DATE11.         OFEND234 DATE11.      
   OFEND235 DATE11.         OFEND236 DATE11.         OFEND237 DATE11.      
   OFEND238 DATE11.         OFEND239 DATE11.         OFEND240 DATE11.      
   OFEND241 DATE11.         OFEND242 DATE11.         OFEND243 DATE11.      
   OFEND244 DATE11.         OFEND245 DATE11.         OFEND246 DATE11.      
   OFEND247 DATE11.         OFEND248 DATE11.         OFEND249 DATE11.      
   OFEND250 DATE11.         OFEND251 DATE11.         OFEND252 DATE11.      
   OFEND253 DATE11.         OFEND254 DATE11.         OFEND255 DATE11.      
   OFEND256 DATE11.         OFEND257 DATE11.         OFEND258 DATE11.      
   OFEND259 DATE11.         OFEND260 DATE11.         OFEND261 DATE11.      
   OFEND262 DATE11.         OFEND263 DATE11.         OFEND264 DATE11.      
   OFEND265 DATE11.         OFEND266 DATE11.         OFEND267 DATE11.      
   OFEND268 DATE11.         OFEND269 DATE11.         OFEND270 DATE11.      
   OFEND271 DATE11.         OFEND272 DATE11.         OFEND273 DATE11.      
   OFEND274 DATE11.         OFEND275 DATE11.         OFEND276 DATE11.      
   OFEND277 DATE11.         OFEND278 DATE11.         OFEND279 DATE11.      
   OFEND280 DATE11.         OFEND281 DATE11.         OFEND282 DATE11.      
   OFEND283 DATE11.         OFEND284 DATE11.         OFEND285 DATE11.      
   OFEND286 DATE11.         OFEND287 DATE11.         OFEND288 DATE11.      
   OFEND289 DATE11.         OFEND290 DATE11.         OFEND291 DATE11.      
   OFEND292 DATE11.         OFEND293 DATE11.         OFEND294 DATE11.      
   OFEND295 DATE11.         OFEND296 DATE11.         OFEND297 DATE11.      
   OFEND298 DATE11.         OFEND299 DATE11.         OFEND300 DATE11.      
   OFEND301 DATE11.         OFEND302 DATE11.         OFEND303 DATE11.      
   OFEND304 DATE11.         OFEND305 DATE11.         OFEND306 DATE11.      
   OFEND307 DATE11.         OFEND308 DATE11.         OFEND309 DATE11.      
   OFEND310 DATE11.         OFEND311 DATE11.         OFEND312 DATE11.      
   OFEND313 DATE11.         OFEND314 DATE11.         OFEND315 DATE11.      
   OFEND316 DATE11.         OFEND317 DATE11.         OFEND318 DATE11.      
   OFEND319 DATE11.         OFEND320 DATE11.         OFEND321 DATE11.      
   OFEND322 DATE11.         OFEND323 DATE11.         OFEND324 DATE11.      
   OFEND325 DATE11.         OFEND326 DATE11.         OFEND327 DATE11.      
   OFEND328 DATE11.         OFEND329 DATE11.         OFEND330 DATE11.      
   OFEND331 DATE11.         OFEND332 DATE11.         OFEND333 DATE11.      
   OFEND334 DATE11.         OFEND335 DATE11.         OFEND336 DATE11.      
   OFEND337 DATE11.         OFEND338 DATE11.         OFEND339 DATE11.      
   OFEND340 DATE11.         OFEND341 DATE11.         OFEND342 DATE11.      
   OFEND343 DATE11.         OFEND344 DATE11.         OFEND345 DATE11.      
   OFEND346 DATE11.         OFEND347 DATE11.         OFEND348 DATE11.      
   OFEND349 DATE11.         OFEND350 DATE11.         OFEND351 DATE11.      
   OFEND352 DATE11.         OFEND353 DATE11.         OFEND354 DATE11.      
   OFEND355 DATE11.         OFEND356 DATE11.         OFEND357 DATE11.      
   OFEND358 DATE11.         OFEND359 DATE11.         OFEND360 DATE11.      
   OFEND361 DATE11.         OFEND362 DATE11.         OFEND363 DATE11.      
   OFEND364 DATE11.         OFEND365 DATE11.         OFEND366 DATE11.      
   OFEND367 DATE11.         OFEND368 DATE11.         OFEND369 DATE11.      
   OFEND370 DATE11.         OFEND371 DATE11.         OFEND372 DATE11.      
   OFEND373 DATE11.         OFEND374 DATE11.         OFEND375 DATE11.      
   OFEND376 DATE11.         OFEND377 DATE11.         OFEND378 DATE11.      
   OFEND379 DATE11.         OFEND380 DATE11.         OFEND381 DATE11.      
   OFEND382 DATE11.         OFEND383 DATE11.         OFEND384 DATE11.      
   OFEND385 DATE11.         OFEND386 DATE11.         OFEND387 DATE11.      
   OFEND388 DATE11.         OFEND389 DATE11.         OFEND390 DATE11.      
   OFEND391 DATE11.         OFEND392 DATE11.         OFEND393 DATE11.      
   OFEND394 DATE11.         OFEND395 DATE11.         OFEND396 DATE11.      
   OFEND397 DATE11.         OFEND398 DATE11.         OFEND399 DATE11.      
   OFEND400 DATE11.         OFEND401 DATE11.         OFEND402 DATE11.      
   OFEND403 DATE11.         OFEND404 DATE11.         OFEND405 DATE11.      
   OFEND406 DATE11.         OFEND407 DATE11.         OFEND408 DATE11.      
   OFEND409 DATE11.         OFEND410 DATE11.         OFEND411 DATE11.      
   OFEND412 DATE11.         OFEND413 DATE11.         OFEND414 DATE11.      
   OFEND415 DATE11.         OFEND416 DATE11.         OFEND417 DATE11.      
   OFEND418 DATE11.         OFEND419 DATE11.         OFEND420 DATE11.      
   OFEND421 DATE11.         OFEND422 DATE11.         OFEND423 DATE11.      
   OFEND424 DATE11.         OFEND425 DATE11.         OFEND426 DATE11.      
   OFEND427 DATE11.         OFEND428 DATE11.         OFEND429 DATE11.      
   OFEND430 DATE11.         OFEND431 DATE11.         OFEND432 DATE11.      
   OFEND433 DATE11.         OFEND434 DATE11.         OFEND435 DATE11.      
   OFEND436 DATE11.         OFEND437 DATE11.         OFEND438 DATE11.      
   OFEND439 DATE11.         OFEND440 DATE11.         OFEND441 DATE11.      
   OFEND442 DATE11.         OFEND443 DATE11.         OFEND444 DATE11.      
   OFEND445 DATE11.         OFEND446 DATE11.         OFEND447 DATE11.      
   OFEND448 DATE11.         OFEND449 DATE11.         OFEND450 DATE11.      
   OFEND451 DATE11.         OFEND452 DATE11.         OFEND453 DATE11.      
   OFEND454 DATE11.         OFEND455 DATE11.         OFEND456 DATE11.      
   OFEND457 DATE11.         OFEND458 DATE11.         OFEND459 DATE11.      
   OFEND460 DATE11.         OFEND461 DATE11.         OFEND462 DATE11.      
   OFEND463 DATE11.         OFEND464 DATE11.         OFEND465 DATE11.      
   OFEND466 DATE11.         OFEND467 DATE11.         OFEND468 DATE11.      
   OFEND469 DATE11.         OFEND470 DATE11.         OFEND471 DATE11.      
   OFEND472 DATE11.         OFEND473 DATE11.         OFEND474 DATE11.      
   OFEND475 DATE11.         OFEND476 DATE11.         OFEND477 DATE11.      
   OFEND478 DATE11.         OFEND479 DATE11.         OFEND480 DATE11.      
   OFEND481 DATE11.         OFEND482 DATE11.         OFEND483 DATE11.      
   OFEND484 DATE11.         OFEND485 DATE11.         OFEND486 DATE11.      
   OFEND487 DATE11.         OFEND488 DATE11.         OFEND489 DATE11.      
   OFEND490 DATE11.         OFEND491 DATE11.         OFEND492 DATE11.      
   OFEND493 DATE11.         OFEND494 DATE11.         OFEND495 DATE11.      
   CRPTS  26391             MWGT1  26392-26410       MWGT2  26411-26428    
   MWGT3  26429-26446       MWGT4  26447-26464       MWGT5  26465-26471    
   WGT1  26472-26490        WGT2  26491-26509        WGT3  26510-26527     
   WGT4  26528-26545        WGT5  26546-26552        DRGAM1  26553-26561   
   DRGAM2  26562-26569      DRGAM3  26570-26577      DRGAM4  26578-26585   
   DRGAM5  26586-26592      DATO1  26593-26599       DATO2  26600-26606    
   DATO3  26607-26612       DATO4  26613             DATO5  26614          
   DAFROM1  26615-26621     DAFROM2  26622-26628     DAFROM3  26629-26633  
   DAFROM4  26634-26637     DAFROM5  26638           MWEIGHT  26639-26657  
   CH5G13YN  26658          DEPART_S  26659          DEPART_D  26660       
 ;                       

FORMAT
   SENTDATE DATE9.          DOB DATE9.               OFBEG1 DATE9.         
   OFBEG2 DATE9.            OFBEG3 DATE9.            OFBEG4 DATE9.         
   OFBEG5 DATE9.            OFBEG6 DATE9.            OFBEG7 DATE9.         
   OFBEG8 DATE9.            OFBEG9 DATE9.            OFBEG10 DATE9.        
   OFBEG11 DATE9.           OFBEG12 DATE9.           OFBEG13 DATE9.        
   OFBEG14 DATE9.           OFBEG15 DATE9.           OFBEG16 DATE9.        
   OFBEG17 DATE9.           OFBEG18 DATE9.           OFBEG19 DATE9.        
   OFBEG20 DATE9.           OFBEG21 DATE9.           OFBEG22 DATE9.        
   OFBEG23 DATE9.           OFBEG24 DATE9.           OFBEG25 DATE9.        
   OFBEG26 DATE9.           OFBEG27 DATE9.           OFBEG28 DATE9.        
   OFBEG29 DATE9.           OFBEG30 DATE9.           OFBEG31 DATE9.        
   OFBEG32 DATE9.           OFBEG33 DATE9.           OFBEG34 DATE9.        
   OFBEG35 DATE9.           OFBEG36 DATE9.           OFBEG37 DATE9.        
   OFBEG38 DATE9.           OFBEG39 DATE9.           OFBEG40 DATE9.        
   OFBEG41 DATE9.           OFBEG42 DATE9.           OFBEG43 DATE9.        
   OFBEG44 DATE9.           OFBEG45 DATE9.           OFBEG46 DATE9.        
   OFBEG47 DATE9.           OFBEG48 DATE9.           OFBEG49 DATE9.        
   OFBEG50 DATE9.           OFBEG51 DATE9.           OFBEG52 DATE9.        
   OFBEG53 DATE9.           OFBEG54 DATE9.           OFBEG55 DATE9.        
   OFBEG56 DATE9.           OFBEG57 DATE9.           OFBEG58 DATE9.        
   OFBEG59 DATE9.           OFBEG60 DATE9.           OFBEG61 DATE9.        
   OFBEG62 DATE9.           OFBEG63 DATE9.           OFBEG64 DATE9.        
   OFBEG65 DATE9.           OFBEG66 DATE9.           OFBEG67 DATE9.        
   OFBEG68 DATE9.           OFBEG69 DATE9.           OFBEG70 DATE9.        
   OFBEG71 DATE9.           OFBEG72 DATE9.           OFBEG73 DATE9.        
   OFBEG74 DATE9.           OFBEG75 DATE9.           OFBEG76 DATE9.        
   OFBEG77 DATE9.           OFBEG78 DATE9.           OFBEG79 DATE9.        
   OFBEG80 DATE9.           OFBEG81 DATE9.           OFBEG82 DATE9.        
   OFBEG83 DATE9.           OFBEG84 DATE9.           OFBEG85 DATE9.        
   OFBEG86 DATE9.           OFBEG87 DATE9.           OFBEG88 DATE9.        
   OFBEG89 DATE9.           OFBEG90 DATE9.           OFBEG91 DATE9.        
   OFBEG92 DATE9.           OFBEG93 DATE9.           OFBEG94 DATE9.        
   OFBEG95 DATE9.           OFBEG96 DATE9.           OFBEG97 DATE9.        
   OFBEG98 DATE9.           OFBEG99 DATE9.           OFBEG100 DATE9.       
   OFBEG101 DATE9.          OFBEG102 DATE9.          OFBEG103 DATE9.       
   OFBEG104 DATE9.          OFBEG105 DATE9.          OFBEG106 DATE9.       
   OFBEG107 DATE9.          OFBEG108 DATE9.          OFBEG109 DATE9.       
   OFBEG110 DATE9.          OFBEG111 DATE9.          OFBEG112 DATE9.       
   OFBEG113 DATE9.          OFBEG114 DATE9.          OFBEG115 DATE9.       
   OFBEG116 DATE9.          OFBEG117 DATE9.          OFBEG118 DATE9.       
   OFBEG119 DATE9.          OFBEG120 DATE9.          OFBEG121 DATE9.       
   OFBEG122 DATE9.          OFBEG123 DATE9.          OFBEG124 DATE9.       
   OFBEG125 DATE9.          OFBEG126 DATE9.          OFBEG127 DATE9.       
   OFBEG128 DATE9.          OFBEG129 DATE9.          OFBEG130 DATE9.       
   OFBEG131 DATE9.          OFBEG132 DATE9.          OFBEG133 DATE9.       
   OFBEG134 DATE9.          OFBEG135 DATE9.          OFBEG136 DATE9.       
   OFBEG137 DATE9.          OFBEG138 DATE9.          OFBEG139 DATE9.       
   OFBEG140 DATE9.          OFBEG141 DATE9.          OFBEG142 DATE9.       
   OFBEG143 DATE9.          OFBEG144 DATE9.          OFBEG145 DATE9.       
   OFBEG146 DATE9.          OFBEG147 DATE9.          OFBEG148 DATE9.       
   OFBEG149 DATE9.          OFBEG150 DATE9.          OFBEG151 DATE9.       
   OFBEG152 DATE9.          OFBEG153 DATE9.          OFBEG154 DATE9.       
   OFBEG155 DATE9.          OFBEG156 DATE9.          OFBEG157 DATE9.       
   OFBEG158 DATE9.          OFBEG159 DATE9.          OFBEG160 DATE9.       
   OFBEG161 DATE9.          OFBEG162 DATE9.          OFBEG163 DATE9.       
   OFBEG164 DATE9.          OFBEG165 DATE9.          OFBEG166 DATE9.       
   OFBEG167 DATE9.          OFBEG168 DATE9.          OFBEG169 DATE9.       
   OFBEG170 DATE9.          OFBEG171 DATE9.          OFBEG172 DATE9.       
   OFBEG173 DATE9.          OFBEG174 DATE9.          OFBEG175 DATE9.       
   OFBEG176 DATE9.          OFBEG177 DATE9.          OFBEG178 DATE9.       
   OFBEG179 DATE9.          OFBEG180 DATE9.          OFBEG181 DATE9.       
   OFBEG182 DATE9.          OFBEG183 DATE9.          OFBEG184 DATE9.       
   OFBEG185 DATE9.          OFBEG186 DATE9.          OFBEG187 DATE9.       
   OFBEG188 DATE9.          OFBEG189 DATE9.          OFBEG190 DATE9.       
   OFBEG191 DATE9.          OFBEG192 DATE9.          OFBEG193 DATE9.       
   OFBEG194 DATE9.          OFBEG195 DATE9.          OFBEG196 DATE9.       
   OFBEG197 DATE9.          OFBEG198 DATE9.          OFBEG199 DATE9.       
   OFBEG200 DATE9.          OFBEG201 DATE9.          OFBEG202 DATE9.       
   OFBEG203 DATE9.          OFBEG204 DATE9.          OFBEG205 DATE9.       
   OFBEG206 DATE9.          OFBEG207 DATE9.          OFBEG208 DATE9.       
   OFBEG209 DATE9.          OFBEG210 DATE9.          OFBEG211 DATE9.       
   OFBEG212 DATE9.          OFBEG213 DATE9.          OFBEG214 DATE9.       
   OFBEG215 DATE9.          OFBEG216 DATE9.          OFBEG217 DATE9.       
   OFBEG218 DATE9.          OFBEG219 DATE9.          OFBEG220 DATE9.       
   OFBEG221 DATE9.          OFBEG222 DATE9.          OFBEG223 DATE9.       
   OFBEG224 DATE9.          OFBEG225 DATE9.          OFBEG226 DATE9.       
   OFBEG227 DATE9.          OFBEG228 DATE9.          OFBEG229 DATE9.       
   OFBEG230 DATE9.          OFBEG231 DATE9.          OFBEG232 DATE9.       
   OFBEG233 DATE9.          OFBEG234 DATE9.          OFBEG235 DATE9.       
   OFBEG236 DATE9.          OFBEG237 DATE9.          OFBEG238 DATE9.       
   OFBEG239 DATE9.          OFBEG240 DATE9.          OFBEG241 DATE9.       
   OFBEG242 DATE9.          OFBEG243 DATE9.          OFBEG244 DATE9.       
   OFBEG245 DATE9.          OFBEG246 DATE9.          OFBEG247 DATE9.       
   OFBEG248 DATE9.          OFBEG249 DATE9.          OFBEG250 DATE9.       
   OFBEG251 DATE9.          OFBEG252 DATE9.          OFBEG253 DATE9.       
   OFBEG254 DATE9.          OFBEG255 DATE9.          OFBEG256 DATE9.       
   OFBEG257 DATE9.          OFBEG258 DATE9.          OFBEG259 DATE9.       
   OFBEG260 DATE9.          OFBEG261 DATE9.          OFBEG262 DATE9.       
   OFBEG263 DATE9.          OFBEG264 DATE9.          OFBEG265 DATE9.       
   OFBEG266 DATE9.          OFBEG267 DATE9.          OFBEG268 DATE9.       
   OFBEG269 DATE9.          OFBEG270 DATE9.          OFBEG271 DATE9.       
   OFBEG272 DATE9.          OFBEG273 DATE9.          OFBEG274 DATE9.       
   OFBEG275 DATE9.          OFBEG276 DATE9.          OFBEG277 DATE9.       
   OFBEG278 DATE9.          OFBEG279 DATE9.          OFBEG280 DATE9.       
   OFBEG281 DATE9.          OFBEG282 DATE9.          OFBEG283 DATE9.       
   OFBEG284 DATE9.          OFBEG285 DATE9.          OFBEG286 DATE9.       
   OFBEG287 DATE9.          OFBEG288 DATE9.          OFBEG289 DATE9.       
   OFBEG290 DATE9.          OFBEG291 DATE9.          OFBEG292 DATE9.       
   OFBEG293 DATE9.          OFBEG294 DATE9.          OFBEG295 DATE9.       
   OFBEG296 DATE9.          OFBEG297 DATE9.          OFBEG298 DATE9.       
   OFBEG299 DATE9.          OFBEG300 DATE9.          OFBEG301 DATE9.       
   OFBEG302 DATE9.          OFBEG303 DATE9.          OFBEG304 DATE9.       
   OFBEG305 DATE9.          OFBEG306 DATE9.          OFBEG307 DATE9.       
   OFBEG308 DATE9.          OFBEG309 DATE9.          OFBEG310 DATE9.       
   OFBEG311 DATE9.          OFBEG312 DATE9.          OFBEG313 DATE9.       
   OFBEG314 DATE9.          OFBEG315 DATE9.          OFBEG316 DATE9.       
   OFBEG317 DATE9.          OFBEG318 DATE9.          OFBEG319 DATE9.       
   OFBEG320 DATE9.          OFBEG321 DATE9.          OFBEG322 DATE9.       
   OFBEG323 DATE9.          OFBEG324 DATE9.          OFBEG325 DATE9.       
   OFBEG326 DATE9.          OFBEG327 DATE9.          OFBEG328 DATE9.       
   OFBEG329 DATE9.          OFBEG330 DATE9.          OFBEG331 DATE9.       
   OFBEG332 DATE9.          OFBEG333 DATE9.          OFBEG334 DATE9.       
   OFBEG335 DATE9.          OFBEG336 DATE9.          OFBEG337 DATE9.       
   OFBEG338 DATE9.          OFBEG339 DATE9.          OFBEG340 DATE9.       
   OFBEG341 DATE9.          OFBEG342 DATE9.          OFBEG343 DATE9.       
   OFBEG344 DATE9.          OFBEG345 DATE9.          OFBEG346 DATE9.       
   OFBEG347 DATE9.          OFBEG348 DATE9.          OFBEG349 DATE9.       
   OFBEG350 DATE9.          OFBEG351 DATE9.          OFBEG352 DATE9.       
   OFBEG353 DATE9.          OFBEG354 DATE9.          OFBEG355 DATE9.       
   OFBEG356 DATE9.          OFBEG357 DATE9.          OFBEG358 DATE9.       
   OFBEG359 DATE9.          OFBEG360 DATE9.          OFBEG361 DATE9.       
   OFBEG362 DATE9.          OFBEG363 DATE9.          OFBEG364 DATE9.       
   OFBEG365 DATE9.          OFBEG366 DATE9.          OFBEG367 DATE9.       
   OFBEG368 DATE9.          OFBEG369 DATE9.          OFBEG370 DATE9.       
   OFBEG371 DATE9.          OFBEG372 DATE9.          OFBEG373 DATE9.       
   OFBEG374 DATE9.          OFBEG375 DATE9.          OFBEG376 DATE9.       
   OFBEG377 DATE9.          OFBEG378 DATE9.          OFBEG379 DATE9.       
   OFBEG380 DATE9.          OFBEG381 DATE9.          OFBEG382 DATE9.       
   OFBEG383 DATE9.          OFBEG384 DATE9.          OFBEG385 DATE9.       
   OFBEG386 DATE9.          OFBEG387 DATE9.          OFBEG388 DATE9.       
   OFBEG389 DATE9.          OFBEG390 DATE9.          OFBEG391 DATE9.       
   OFBEG392 DATE9.          OFBEG393 DATE9.          OFBEG394 DATE9.       
   OFBEG395 DATE9.          OFBEG396 DATE9.          OFBEG397 DATE9.       
   OFBEG398 DATE9.          OFBEG399 DATE9.          OFBEG400 DATE9.       
   OFBEG401 DATE9.          OFBEG402 DATE9.          OFBEG403 DATE9.       
   OFBEG404 DATE9.          OFBEG405 DATE9.          OFBEG406 DATE9.       
   OFBEG407 DATE9.          OFBEG408 DATE9.          OFBEG409 DATE9.       
   OFBEG410 DATE9.          OFBEG411 DATE9.          OFBEG412 DATE9.       
   OFBEG413 DATE9.          OFBEG414 DATE9.          OFBEG415 DATE9.       
   OFBEG416 DATE9.          OFBEG417 DATE9.          OFBEG418 DATE9.       
   OFBEG419 DATE9.          OFBEG420 DATE9.          OFBEG421 DATE9.       
   OFBEG422 DATE9.          OFBEG423 DATE9.          OFBEG424 DATE9.       
   OFBEG425 DATE9.          OFBEG426 DATE9.          OFBEG427 DATE9.       
   OFBEG428 DATE9.          OFBEG429 DATE9.          OFBEG430 DATE9.       
   OFBEG431 DATE9.          OFBEG432 DATE9.          OFBEG433 DATE9.       
   OFBEG434 DATE9.          OFBEG435 DATE9.          OFBEG436 DATE9.       
   OFBEG437 DATE9.          OFBEG438 DATE9.          OFBEG439 DATE9.       
   OFBEG440 DATE9.          OFBEG441 DATE9.          OFBEG442 DATE9.       
   OFBEG443 DATE9.          OFBEG444 DATE9.          OFBEG445 DATE9.       
   OFBEG446 DATE9.          OFBEG447 DATE9.          OFBEG448 DATE9.       
   OFBEG449 DATE9.          OFBEG450 DATE9.          OFBEG451 DATE9.       
   OFBEG452 DATE9.          OFBEG453 DATE9.          OFBEG454 DATE9.       
   OFBEG455 DATE9.          OFBEG456 DATE9.          OFBEG457 DATE9.       
   OFBEG458 DATE9.          OFBEG459 DATE9.          OFBEG460 DATE9.       
   OFBEG461 DATE9.          OFBEG462 DATE9.          OFBEG463 DATE9.       
   OFBEG464 DATE9.          OFBEG465 DATE9.          OFBEG466 DATE9.       
   OFBEG467 DATE9.          OFBEG468 DATE9.          OFBEG469 DATE9.       
   OFBEG470 DATE9.          OFBEG471 DATE9.          OFBEG472 DATE9.       
   OFBEG473 DATE9.          OFBEG474 DATE9.          OFBEG475 DATE9.       
   OFBEG476 DATE9.          OFBEG477 DATE9.          OFBEG478 DATE9.       
   OFBEG479 DATE9.          OFBEG480 DATE9.          OFBEG481 DATE9.       
   OFBEG482 DATE9.          OFBEG483 DATE9.          OFBEG484 DATE9.       
   OFBEG485 DATE9.          OFBEG486 DATE9.          OFBEG487 DATE9.       
   OFBEG488 DATE9.          OFBEG489 DATE9.          OFBEG490 DATE9.       
   OFBEG491 DATE9.          OFBEG492 DATE9.          OFBEG493 DATE9.       
   OFBEG494 DATE9.          OFBEG495 DATE9.          OFEND1 DATE9.         
   OFEND2 DATE9.            OFEND3 DATE9.            OFEND4 DATE9.         
   OFEND5 DATE9.            OFEND6 DATE9.            OFEND7 DATE9.         
   OFEND8 DATE9.            OFEND9 DATE9.            OFEND10 DATE9.        
   OFEND11 DATE9.           OFEND12 DATE9.           OFEND13 DATE9.        
   OFEND14 DATE9.           OFEND15 DATE9.           OFEND16 DATE9.        
   OFEND17 DATE9.           OFEND18 DATE9.           OFEND19 DATE9.        
   OFEND20 DATE9.           OFEND21 DATE9.           OFEND22 DATE9.        
   OFEND23 DATE9.           OFEND24 DATE9.           OFEND25 DATE9.        
   OFEND26 DATE9.           OFEND27 DATE9.           OFEND28 DATE9.        
   OFEND29 DATE9.           OFEND30 DATE9.           OFEND31 DATE9.        
   OFEND32 DATE9.           OFEND33 DATE9.           OFEND34 DATE9.        
   OFEND35 DATE9.           OFEND36 DATE9.           OFEND37 DATE9.        
   OFEND38 DATE9.           OFEND39 DATE9.           OFEND40 DATE9.        
   OFEND41 DATE9.           OFEND42 DATE9.           OFEND43 DATE9.        
   OFEND44 DATE9.           OFEND45 DATE9.           OFEND46 DATE9.        
   OFEND47 DATE9.           OFEND48 DATE9.           OFEND49 DATE9.        
   OFEND50 DATE9.           OFEND51 DATE9.           OFEND52 DATE9.        
   OFEND53 DATE9.           OFEND54 DATE9.           OFEND55 DATE9.        
   OFEND56 DATE9.           OFEND57 DATE9.           OFEND58 DATE9.        
   OFEND59 DATE9.           OFEND60 DATE9.           OFEND61 DATE9.        
   OFEND62 DATE9.           OFEND63 DATE9.           OFEND64 DATE9.        
   OFEND65 DATE9.           OFEND66 DATE9.           OFEND67 DATE9.        
   OFEND68 DATE9.           OFEND69 DATE9.           OFEND70 DATE9.        
   OFEND71 DATE9.           OFEND72 DATE9.           OFEND73 DATE9.        
   OFEND74 DATE9.           OFEND75 DATE9.           OFEND76 DATE9.        
   OFEND77 DATE9.           OFEND78 DATE9.           OFEND79 DATE9.        
   OFEND80 DATE9.           OFEND81 DATE9.           OFEND82 DATE9.        
   OFEND83 DATE9.           OFEND84 DATE9.           OFEND85 DATE9.        
   OFEND86 DATE9.           OFEND87 DATE9.           OFEND88 DATE9.        
   OFEND89 DATE9.           OFEND90 DATE9.           OFEND91 DATE9.        
   OFEND92 DATE9.           OFEND93 DATE9.           OFEND94 DATE9.        
   OFEND95 DATE9.           OFEND96 DATE9.           OFEND97 DATE9.        
   OFEND98 DATE9.           OFEND99 DATE9.           OFEND100 DATE9.       
   OFEND101 DATE9.          OFEND102 DATE9.          OFEND103 DATE9.       
   OFEND104 DATE9.          OFEND105 DATE9.          OFEND106 DATE9.       
   OFEND107 DATE9.          OFEND108 DATE9.          OFEND109 DATE9.       
   OFEND110 DATE9.          OFEND111 DATE9.          OFEND112 DATE9.       
   OFEND113 DATE9.          OFEND114 DATE9.          OFEND115 DATE9.       
   OFEND116 DATE9.          OFEND117 DATE9.          OFEND118 DATE9.       
   OFEND119 DATE9.          OFEND120 DATE9.          OFEND121 DATE9.       
   OFEND122 DATE9.          OFEND123 DATE9.          OFEND124 DATE9.       
   OFEND125 DATE9.          OFEND126 DATE9.          OFEND127 DATE9.       
   OFEND128 DATE9.          OFEND129 DATE9.          OFEND130 DATE9.       
   OFEND131 DATE9.          OFEND132 DATE9.          OFEND133 DATE9.       
   OFEND134 DATE9.          OFEND135 DATE9.          OFEND136 DATE9.       
   OFEND137 DATE9.          OFEND138 DATE9.          OFEND139 DATE9.       
   OFEND140 DATE9.          OFEND141 DATE9.          OFEND142 DATE9.       
   OFEND143 DATE9.          OFEND144 DATE9.          OFEND145 DATE9.       
   OFEND146 DATE9.          OFEND147 DATE9.          OFEND148 DATE9.       
   OFEND149 DATE9.          OFEND150 DATE9.          OFEND151 DATE9.       
   OFEND152 DATE9.          OFEND153 DATE9.          OFEND154 DATE9.       
   OFEND155 DATE9.          OFEND156 DATE9.          OFEND157 DATE9.       
   OFEND158 DATE9.          OFEND159 DATE9.          OFEND160 DATE9.       
   OFEND161 DATE9.          OFEND162 DATE9.          OFEND163 DATE9.       
   OFEND164 DATE9.          OFEND165 DATE9.          OFEND166 DATE9.       
   OFEND167 DATE9.          OFEND168 DATE9.          OFEND169 DATE9.       
   OFEND170 DATE9.          OFEND171 DATE9.          OFEND172 DATE9.       
   OFEND173 DATE9.          OFEND174 DATE9.          OFEND175 DATE9.       
   OFEND176 DATE9.          OFEND177 DATE9.          OFEND178 DATE9.       
   OFEND179 DATE9.          OFEND180 DATE9.          OFEND181 DATE9.       
   OFEND182 DATE9.          OFEND183 DATE9.          OFEND184 DATE9.       
   OFEND185 DATE9.          OFEND186 DATE9.          OFEND187 DATE9.       
   OFEND188 DATE9.          OFEND189 DATE9.          OFEND190 DATE9.       
   OFEND191 DATE9.          OFEND192 DATE9.          OFEND193 DATE9.       
   OFEND194 DATE9.          OFEND195 DATE9.          OFEND196 DATE9.       
   OFEND197 DATE9.          OFEND198 DATE9.          OFEND199 DATE9.       
   OFEND200 DATE9.          OFEND201 DATE9.          OFEND202 DATE9.       
   OFEND203 DATE9.          OFEND204 DATE9.          OFEND205 DATE9.       
   OFEND206 DATE9.          OFEND207 DATE9.          OFEND208 DATE9.       
   OFEND209 DATE9.          OFEND210 DATE9.          OFEND211 DATE9.       
   OFEND212 DATE9.          OFEND213 DATE9.          OFEND214 DATE9.       
   OFEND215 DATE9.          OFEND216 DATE9.          OFEND217 DATE9.       
   OFEND218 DATE9.          OFEND219 DATE9.          OFEND220 DATE9.       
   OFEND221 DATE9.          OFEND222 DATE9.          OFEND223 DATE9.       
   OFEND224 DATE9.          OFEND225 DATE9.          OFEND226 DATE9.       
   OFEND227 DATE9.          OFEND228 DATE9.          OFEND229 DATE9.       
   OFEND230 DATE9.          OFEND231 DATE9.          OFEND232 DATE9.       
   OFEND233 DATE9.          OFEND234 DATE9.          OFEND235 DATE9.       
   OFEND236 DATE9.          OFEND237 DATE9.          OFEND238 DATE9.       
   OFEND239 DATE9.          OFEND240 DATE9.          OFEND241 DATE9.       
   OFEND242 DATE9.          OFEND243 DATE9.          OFEND244 DATE9.       
   OFEND245 DATE9.          OFEND246 DATE9.          OFEND247 DATE9.       
   OFEND248 DATE9.          OFEND249 DATE9.          OFEND250 DATE9.       
   OFEND251 DATE9.          OFEND252 DATE9.          OFEND253 DATE9.       
   OFEND254 DATE9.          OFEND255 DATE9.          OFEND256 DATE9.       
   OFEND257 DATE9.          OFEND258 DATE9.          OFEND259 DATE9.       
   OFEND260 DATE9.          OFEND261 DATE9.          OFEND262 DATE9.       
   OFEND263 DATE9.          OFEND264 DATE9.          OFEND265 DATE9.       
   OFEND266 DATE9.          OFEND267 DATE9.          OFEND268 DATE9.       
   OFEND269 DATE9.          OFEND270 DATE9.          OFEND271 DATE9.       
   OFEND272 DATE9.          OFEND273 DATE9.          OFEND274 DATE9.       
   OFEND275 DATE9.          OFEND276 DATE9.          OFEND277 DATE9.       
   OFEND278 DATE9.          OFEND279 DATE9.          OFEND280 DATE9.       
   OFEND281 DATE9.          OFEND282 DATE9.          OFEND283 DATE9.       
   OFEND284 DATE9.          OFEND285 DATE9.          OFEND286 DATE9.       
   OFEND287 DATE9.          OFEND288 DATE9.          OFEND289 DATE9.       
   OFEND290 DATE9.          OFEND291 DATE9.          OFEND292 DATE9.       
   OFEND293 DATE9.          OFEND294 DATE9.          OFEND295 DATE9.       
   OFEND296 DATE9.          OFEND297 DATE9.          OFEND298 DATE9.       
   OFEND299 DATE9.          OFEND300 DATE9.          OFEND301 DATE9.       
   OFEND302 DATE9.          OFEND303 DATE9.          OFEND304 DATE9.       
   OFEND305 DATE9.          OFEND306 DATE9.          OFEND307 DATE9.       
   OFEND308 DATE9.          OFEND309 DATE9.          OFEND310 DATE9.       
   OFEND311 DATE9.          OFEND312 DATE9.          OFEND313 DATE9.       
   OFEND314 DATE9.          OFEND315 DATE9.          OFEND316 DATE9.       
   OFEND317 DATE9.          OFEND318 DATE9.          OFEND319 DATE9.       
   OFEND320 DATE9.          OFEND321 DATE9.          OFEND322 DATE9.       
   OFEND323 DATE9.          OFEND324 DATE9.          OFEND325 DATE9.       
   OFEND326 DATE9.          OFEND327 DATE9.          OFEND328 DATE9.       
   OFEND329 DATE9.          OFEND330 DATE9.          OFEND331 DATE9.       
   OFEND332 DATE9.          OFEND333 DATE9.          OFEND334 DATE9.       
   OFEND335 DATE9.          OFEND336 DATE9.          OFEND337 DATE9.       
   OFEND338 DATE9.          OFEND339 DATE9.          OFEND340 DATE9.       
   OFEND341 DATE9.          OFEND342 DATE9.          OFEND343 DATE9.       
   OFEND344 DATE9.          OFEND345 DATE9.          OFEND346 DATE9.       
   OFEND347 DATE9.          OFEND348 DATE9.          OFEND349 DATE9.       
   OFEND350 DATE9.          OFEND351 DATE9.          OFEND352 DATE9.       
   OFEND353 DATE9.          OFEND354 DATE9.          OFEND355 DATE9.       
   OFEND356 DATE9.          OFEND357 DATE9.          OFEND358 DATE9.       
   OFEND359 DATE9.          OFEND360 DATE9.          OFEND361 DATE9.       
   OFEND362 DATE9.          OFEND363 DATE9.          OFEND364 DATE9.       
   OFEND365 DATE9.          OFEND366 DATE9.          OFEND367 DATE9.       
   OFEND368 DATE9.          OFEND369 DATE9.          OFEND370 DATE9.       
   OFEND371 DATE9.          OFEND372 DATE9.          OFEND373 DATE9.       
   OFEND374 DATE9.          OFEND375 DATE9.          OFEND376 DATE9.       
   OFEND377 DATE9.          OFEND378 DATE9.          OFEND379 DATE9.       
   OFEND380 DATE9.          OFEND381 DATE9.          OFEND382 DATE9.       
   OFEND383 DATE9.          OFEND384 DATE9.          OFEND385 DATE9.       
   OFEND386 DATE9.          OFEND387 DATE9.          OFEND388 DATE9.       
   OFEND389 DATE9.          OFEND390 DATE9.          OFEND391 DATE9.       
   OFEND392 DATE9.          OFEND393 DATE9.          OFEND394 DATE9.       
   OFEND395 DATE9.          OFEND396 DATE9.          OFEND397 DATE9.       
   OFEND398 DATE9.          OFEND399 DATE9.          OFEND400 DATE9.       
   OFEND401 DATE9.          OFEND402 DATE9.          OFEND403 DATE9.       
   OFEND404 DATE9.          OFEND405 DATE9.          OFEND406 DATE9.       
   OFEND407 DATE9.          OFEND408 DATE9.          OFEND409 DATE9.       
   OFEND410 DATE9.          OFEND411 DATE9.          OFEND412 DATE9.       
   OFEND413 DATE9.          OFEND414 DATE9.          OFEND415 DATE9.       
   OFEND416 DATE9.          OFEND417 DATE9.          OFEND418 DATE9.       
   OFEND419 DATE9.          OFEND420 DATE9.          OFEND421 DATE9.       
   OFEND422 DATE9.          OFEND423 DATE9.          OFEND424 DATE9.       
   OFEND425 DATE9.          OFEND426 DATE9.          OFEND427 DATE9.       
   OFEND428 DATE9.          OFEND429 DATE9.          OFEND430 DATE9.       
   OFEND431 DATE9.          OFEND432 DATE9.          OFEND433 DATE9.       
   OFEND434 DATE9.          OFEND435 DATE9.          OFEND436 DATE9.       
   OFEND437 DATE9.          OFEND438 DATE9.          OFEND439 DATE9.       
   OFEND440 DATE9.          OFEND441 DATE9.          OFEND442 DATE9.       
   OFEND443 DATE9.          OFEND444 DATE9.          OFEND445 DATE9.       
   OFEND446 DATE9.          OFEND447 DATE9.          OFEND448 DATE9.       
   OFEND449 DATE9.          OFEND450 DATE9.          OFEND451 DATE9.       
   OFEND452 DATE9.          OFEND453 DATE9.          OFEND454 DATE9.       
   OFEND455 DATE9.          OFEND456 DATE9.          OFEND457 DATE9.       
   OFEND458 DATE9.          OFEND459 DATE9.          OFEND460 DATE9.       
   OFEND461 DATE9.          OFEND462 DATE9.          OFEND463 DATE9.       
   OFEND464 DATE9.          OFEND465 DATE9.          OFEND466 DATE9.       
   OFEND467 DATE9.          OFEND468 DATE9.          OFEND469 DATE9.       
   OFEND470 DATE9.          OFEND471 DATE9.          OFEND472 DATE9.       
   OFEND473 DATE9.          OFEND474 DATE9.          OFEND475 DATE9.       
   OFEND476 DATE9.          OFEND477 DATE9.          OFEND478 DATE9.       
   OFEND479 DATE9.          OFEND480 DATE9.          OFEND481 DATE9.       
   OFEND482 DATE9.          OFEND483 DATE9.          OFEND484 DATE9.       
   OFEND485 DATE9.          OFEND486 DATE9.          OFEND487 DATE9.       
   OFEND488 DATE9.          OFEND489 DATE9.          OFEND490 DATE9.       
   OFEND491 DATE9.          OFEND492 DATE9.          OFEND493 DATE9.       
   OFEND494 DATE9.          OFEND495 DATE9.        ;
                     

LENGTH
   AMTFINEC 6               COSTSUP 6                FINE 6                
   USSCIDN 6                ACCAP 3                  ACCCAT 3              
   ACCGDLN 3                ACCOFFLV 3               ACCTRESP 3            
   CAROFFAP 3               AGE 4                    ALTDUM 3              
   ALTMO 3                  AMENDYR 4                ARMCRIM 3             
   CAROFFEN 3               CAROFFLV 3               CHAP2 3               
   CIRCDIST 3               CITIZEN 3                CITWHERE 4            
   COADJLEV 3               COMBDRG2 3               COMDUM 3              
   COSTSDUM 3               CRIMHIST 3               CRIMLIV 3             
   CRIMPTS 4                DAYSDUM 3                DEFCONSL 3            
   DEPART 3                 DISPOSIT 3               DISTRICT 3            
   DRUGTYP1 4               DRUGTYP2 4               DRUGTYP3 4            
   DRUGTYP4 4               DRUGTYP5 4               DSIND 3               
   DSJANDC 3                DSPLEA 3                 DSPSR 3               
   DSSOR 3                  DUFROM1 3                DUFROM2 3             
   DUFROM3 3                DUFROM4 3                DUFROM5 3             
   DUTO1 3                  DUTO2 3                  DUTO3 3               
   DUTO4 3                  DUTO5 3                  ECONDUM 3             
   EDUCATN 3                ENCRYPT1 3               ENCRYPT2 3            
   FINECDUM 3               FINEWAIV 3               HISPORIG 3            
   HOMDUM 3                 HRCOMSRV 4               INOUT 3               
   INTDUM 3                 IS924C 3                 MARRIED 3             
   MOCOMCON 3               MOHOMDET 3               MOINTCON 3            
   MONACCEP 3               MONCIRC 3                MONRACE 3             
   MONSEX 3                 NEWCIT 3                 NEWCNVTN 3            
   NEWEDUC 3                NEWRACE 3                NOCOMP 3              
   NOCOUNTS 4               NOUSTAT 3                NUMDEPEN 3            
   OFFTYPE2 3               POINT1 3                 POINT3 3              
   PRESENT 3                PRISDUM 3                PROBATN 4             
   PROBDUM 3                RANGEPT 3                REASON1 4             
   REASON2 4                REASON3 4                REL2PTS 3             
   RESNTDOC 3               RESTDUM 3                SAFE 3                
   SENTIMP 3                SENTPTS 3                SEXOFFNA 3            
   SEXOFFNB 3               SOURCES 3                SUPRDUM 3             
   SUPREL 4                 TOTCHPTS 3               SEXACCA 3             
   SEXACCB 3                TOTDAYS 3                TYPEMONY 3            
   TYPEOTHS 3               UNIT1 3                  UNIT2 3               
   UNIT3 3                  UNIT4 3                  UNIT5 3               
   VIOL1PTS 3               WEAPON 3                 WEAPSOC 3             
   XCRHISSR 3               XFOLSOR 3                YEARS 3               
   DRUGMIN 4                GLMIN 4                  GLMAX 4               
   GUNMIN1 4                GUNMIN2 4                STATMAX 4             
   STATMIN 4                TOTPRISN 4               XMAXSOR 4             
   XMINSOR 4                SMIN1 4                  SMIN2 4               
   SMIN3 4                  SMIN4 4                  SMIN5 4               
   SMIN6 4                  SMIN7 4                  SMIN8 4               
   SMIN9 4                  SMIN10 4                 SMIN11 4              
   SMIN12 4                 SMIN13 4                 SMIN14 4              
   SMIN15 4                 SMIN16 4                 SMIN17 4              
   SMIN18 4                 SMIN19 4                 SMIN20 4              
   SMIN21 4                 SMIN22 4                 SMIN23 4              
   SMIN24 4                 SMIN25 4                 SMIN26 4              
   SMIN27 3                 SMIN28 3                 SMIN29 3              
   SMIN30 3                 SMIN31 4                 SMIN32 3              
   SMIN33 3                 SMIN34 3                 SMIN35 4              
   SMIN36 4                 SMIN37 4                 SMIN38 4              
   SMIN39 4                 SMIN40 4                 SMIN41 4              
   SMIN42 3                 SMIN43 3                 SMIN44 3              
   SMIN45 3                 SMIN46 3                 SMIN47 3              
   SMIN48 3                 SMIN49 3                 SMIN50 3              
   SMIN51 3                 SMIN52 3                 SMIN53 3              
   SMIN54 3                 SMIN55 3                 SMIN56 3              
   SMIN57 3                 SMIN58 3                 SMIN59 3              
   SMIN60 3                 SMIN61 3                 SMIN62 3              
   SMIN63 3                 SMIN64 3                 SMIN65 3              
   SMIN66 3                 SMIN67 3                 SMIN68 3              
   SMIN69 3                 SMIN70 3                 SMIN71 3              
   SMIN72 3                 SMIN73 3                 SMIN74 3              
   SMIN75 3                 SMIN76 3                 SMIN77 3              
   SMIN78 3                 SMIN79 3                 SMIN80 3              
   SMIN81 3                 SMIN82 3                 SMIN83 3              
   SMIN84 3                 SMIN85 3                 SMIN86 3              
   SMIN87 3                 SMIN88 3                 SMIN89 3              
   SMIN90 3                 SMIN91 3                 SMIN92 3              
   SMIN93 3                 SMIN94 3                 SMIN95 3              
   SMIN96 3                 SMIN97 3                 SMIN98 3              
   SMIN99 3                 SMIN100 3                SMIN101 3             
   SMIN102 3                SMIN103 3                SMIN104 3             
   SMIN105 3                SMIN106 3                SMIN107 3             
   SMIN108 3                SMIN109 3                SMIN110 3             
   SMIN111 3                SMIN112 3                SMIN113 3             
   SMIN114 3                SMIN115 3                SMIN116 3             
   SMIN117 3                SMIN118 3                SMIN119 3             
   SMIN120 3                SMIN121 3                SMIN122 3             
   SMIN123 3                SMIN124 3                SMIN125 3             
   SMIN126 3                SMIN127 3                SMIN128 3             
   SMIN129 3                SMIN130 3                SMIN131 3             
   SMIN132 3                SMIN133 3                SMIN134 3             
   SMIN135 3                SMIN136 3                SMIN137 3             
   SMIN138 3                SMIN139 3                SMIN140 3             
   SMIN141 3                SMIN142 3                SMIN143 3             
   SMIN144 3                SMIN145 3                SMIN146 3             
   SMIN147 3                SMIN148 3                SMIN149 3             
   SMIN150 3                SMIN151 3                SMIN152 3             
   SMIN153 3                SMIN154 3                SMIN155 3             
   SMIN156 3                SMIN157 3                SMIN158 3             
   SMIN159 3                SMIN160 3                SMIN161 3             
   SMIN162 3                SMIN163 3                SMIN164 3             
   SMIN165 3                SMIN166 3                SMIN167 3             
   SMIN168 3                SMIN169 3                SMIN170 3             
   SMIN171 3                SMIN172 3                SMIN173 3             
   SMIN174 3                SMIN175 3                SMIN176 3             
   SMIN177 3                SMIN178 3                SMIN179 3             
   SMIN180 3                SMIN181 3                SMIN182 3             
   SMIN183 3                SMIN184 3                SMIN185 3             
   SMIN186 3                SMIN187 3                SMIN188 3             
   SMIN189 3                SMIN190 3                SMIN191 3             
   SMIN192 3                SMIN193 3                SMIN194 3             
   SMIN195 3                SMIN196 3                SMIN197 3             
   SMIN198 3                SMIN199 3                SMIN200 3             
   SMIN201 3                SMIN202 3                SMIN203 3             
   SMIN204 3                SMIN205 3                SMIN206 3             
   SMIN207 3                SMIN208 3                SMIN209 3             
   SMIN210 3                SMIN211 3                SMIN212 3             
   SMIN213 3                SMIN214 3                SMIN215 3             
   SMIN216 3                SMIN217 3                SMIN218 3             
   SMIN219 3                SMIN220 3                SMIN221 3             
   SMIN222 3                SMIN223 3                SMIN224 3             
   SMIN225 3                SMIN226 3                SMIN227 3             
   SMIN228 3                SMIN229 3                SMIN230 3             
   SMIN231 3                SMIN232 3                SMIN233 3             
   SMIN234 3                SMIN235 3                SMIN236 3             
   SMIN237 3                SMIN238 3                SMIN239 3             
   SMIN240 3                SMIN241 3                SMIN242 3             
   SMIN243 3                SMIN244 3                SMIN245 3             
   SMIN246 3                SMIN247 3                SMIN248 3             
   SMIN249 3                SMIN250 3                SMIN251 3             
   SMIN252 3                SMIN253 3                SMIN254 3             
   SMIN255 3                SMIN256 3                SMIN257 3             
   SMIN258 3                SMIN259 3                SMIN260 3             
   SMIN261 3                SMIN262 3                SMIN263 3             
   SMIN264 3                SMIN265 3                SMIN266 3             
   SMIN267 3                SMIN268 3                SMIN269 3             
   SMIN270 3                SMIN271 3                SMIN272 3             
   SMIN273 3                SMIN274 3                SMIN275 3             
   SMIN276 3                SMIN277 3                SMIN278 3             
   SMIN279 3                SMIN280 3                SMIN281 3             
   SMIN282 3                SMIN283 3                SMIN284 3             
   SMIN285 3                SMIN286 3                SMIN287 3             
   SMIN288 3                SMIN289 3                SMIN290 3             
   SMIN291 3                SMIN292 3                SMIN293 3             
   SMIN294 3                SMIN295 3                SMIN296 3             
   SMIN297 3                SMIN298 3                SMIN299 3             
   SMIN300 3                SMIN301 3                SMIN302 3             
   SMIN303 3                SMIN304 3                SMIN305 3             
   SMIN306 3                SMIN307 3                SMIN308 3             
   SMIN309 3                SMIN310 3                SMIN311 3             
   SMIN312 3                SMIN313 3                SMIN314 3             
   SMIN315 3                SMIN316 3                SMIN317 3             
   SMIN318 3                SMIN319 3                SMIN320 3             
   SMIN321 3                SMIN322 3                SMIN323 3             
   SMIN324 3                SMIN325 3                SMIN326 3             
   SMIN327 3                SMIN328 3                SMIN329 3             
   SMIN330 3                SMIN331 3                SMIN332 3             
   SMIN333 3                SMIN334 3                SMIN335 3             
   SMIN336 3                SMIN337 3                SMIN338 3             
   SMIN339 3                SMIN340 3                SMIN341 3             
   SMIN342 3                SMIN343 3                SMIN344 3             
   SMIN345 3                SMIN346 3                SMIN347 3             
   SMIN348 3                SMIN349 3                SMIN350 3             
   SMIN351 3                SMIN352 3                SMIN353 3             
   SMIN354 3                SMIN355 3                SMIN356 3             
   SMIN357 3                SMIN358 3                SMIN359 3             
   SMIN360 3                SMIN361 3                SMIN362 3             
   SMIN363 3                SMIN364 3                SMIN365 3             
   SMIN366 3                SMIN367 3                SMIN368 3             
   SMIN369 3                SMIN370 3                SMIN371 3             
   SMIN372 3                SMIN373 3                SMIN374 3             
   SMIN375 3                SMIN376 3                SMIN377 3             
   SMIN378 3                SMIN379 3                SMIN380 3             
   SMIN381 3                SMIN382 3                SMIN383 3             
   SMIN384 3                SMIN385 3                SMIN386 3             
   SMIN387 3                SMIN388 3                SMIN389 3             
   SMIN390 3                SMIN391 3                SMIN392 3             
   SMIN393 3                SMIN394 3                SMIN395 3             
   SMIN396 3                SMIN397 3                SMIN398 3             
   SMIN399 3                SMIN400 3                SMIN401 3             
   SMIN402 3                SMIN403 3                SMIN404 3             
   SMIN405 3                SMIN406 3                SMIN407 3             
   SMIN408 3                SMIN409 3                SMIN410 3             
   SMIN411 3                SMIN412 3                SMIN413 3             
   SMIN414 3                SMIN415 3                SMIN416 3             
   SMIN417 3                SMIN418 3                SMIN419 3             
   SMIN420 3                SMIN421 3                SMIN422 3             
   SMIN423 3                SMIN424 3                SMIN425 3             
   SMIN426 3                SMIN427 3                SMIN428 3             
   SMIN429 3                SMIN430 3                SMIN431 3             
   SMIN432 3                SMIN433 3                SMIN434 3             
   SMIN435 3                SMIN436 3                SMIN437 3             
   SMIN438 3                SMIN439 3                SMIN440 3             
   SMIN441 3                SMIN442 3                SMIN443 3             
   SMIN444 3                SMIN445 3                SMIN446 3             
   SMIN447 3                SMIN448 3                SMIN449 3             
   SMIN450 3                SMIN451 3                SMIN452 3             
   SMIN453 3                SMIN454 3                SMIN455 3             
   SMIN456 3                SMIN457 3                SMIN458 3             
   SMIN459 3                SMIN460 3                SMIN461 3             
   SMIN462 3                SMIN463 3                SMIN464 3             
   SMIN465 3                SMIN466 3                SMIN467 3             
   SMIN468 3                SMIN469 3                SMIN470 3             
   SMIN471 3                SMIN472 3                SMIN473 3             
   SMIN474 3                SMIN475 3                SMIN476 3             
   SMIN477 3                SMIN478 3                SMIN479 3             
   SMIN480 3                SMIN481 3                SMIN482 3             
   SMIN483 3                SMIN484 3                SMIN485 3             
   SMIN486 3                SMIN487 3                SMIN488 3             
   SMIN489 3                SMIN490 3                SMIN491 3             
   SMIN492 3                SMIN493 3                SMIN494 3             
   SMIN495 3                SMAX1 4                  SMAX2 4               
   SMAX3 4                  SMAX4 4                  SMAX5 4               
   SMAX6 4                  SMAX7 4                  SMAX8 4               
   SMAX9 4                  SMAX10 4                 SMAX11 4              
   SMAX12 4                 SMAX13 4                 SMAX14 4              
   SMAX15 4                 SMAX16 4                 SMAX17 4              
   SMAX18 4                 SMAX19 4                 SMAX20 4              
   SMAX21 4                 SMAX22 4                 SMAX23 4              
   SMAX24 4                 SMAX25 4                 SMAX26 4              
   SMAX27 4                 SMAX28 4                 SMAX29 4              
   SMAX30 4                 SMAX31 4                 SMAX32 4              
   SMAX33 4                 SMAX34 4                 SMAX35 4              
   SMAX36 4                 SMAX37 4                 SMAX38 4              
   SMAX39 4                 SMAX40 4                 SMAX41 4              
   SMAX42 4                 SMAX43 4                 SMAX44 4              
   SMAX45 4                 SMAX46 4                 SMAX47 4              
   SMAX48 4                 SMAX49 4                 SMAX50 4              
   SMAX51 4                 SMAX52 4                 SMAX53 4              
   SMAX54 4                 SMAX55 4                 SMAX56 4              
   SMAX57 4                 SMAX58 4                 SMAX59 4              
   SMAX60 4                 SMAX61 4                 SMAX62 4              
   SMAX63 4                 SMAX64 4                 SMAX65 4              
   SMAX66 4                 SMAX67 4                 SMAX68 4              
   SMAX69 4                 SMAX70 4                 SMAX71 4              
   SMAX72 4                 SMAX73 4                 SMAX74 4              
   SMAX75 4                 SMAX76 4                 SMAX77 4              
   SMAX78 4                 SMAX79 4                 SMAX80 4              
   SMAX81 4                 SMAX82 4                 SMAX83 4              
   SMAX84 4                 SMAX85 4                 SMAX86 4              
   SMAX87 4                 SMAX88 4                 SMAX89 4              
   SMAX90 4                 SMAX91 4                 SMAX92 4              
   SMAX93 4                 SMAX94 4                 SMAX95 4              
   SMAX96 4                 SMAX97 4                 SMAX98 4              
   SMAX99 4                 SMAX100 4                SMAX101 4             
   SMAX102 4                SMAX103 4                SMAX104 4             
   SMAX105 4                SMAX106 4                SMAX107 4             
   SMAX108 4                SMAX109 4                SMAX110 4             
   SMAX111 4                SMAX112 4                SMAX113 4             
   SMAX114 4                SMAX115 4                SMAX116 4             
   SMAX117 4                SMAX118 4                SMAX119 4             
   SMAX120 4                SMAX121 4                SMAX122 4             
   SMAX123 4                SMAX124 4                SMAX125 4             
   SMAX126 4                SMAX127 4                SMAX128 4             
   SMAX129 4                SMAX130 4                SMAX131 4             
   SMAX132 4                SMAX133 4                SMAX134 4             
   SMAX135 4                SMAX136 4                SMAX137 4             
   SMAX138 4                SMAX139 4                SMAX140 4             
   SMAX141 4                SMAX142 4                SMAX143 4             
   SMAX144 4                SMAX145 4                SMAX146 4             
   SMAX147 4                SMAX148 4                SMAX149 4             
   SMAX150 4                SMAX151 4                SMAX152 4             
   SMAX153 4                SMAX154 4                SMAX155 4             
   SMAX156 4                SMAX157 4                SMAX158 4             
   SMAX159 4                SMAX160 4                SMAX161 4             
   SMAX162 4                SMAX163 4                SMAX164 4             
   SMAX165 4                SMAX166 4                SMAX167 4             
   SMAX168 4                SMAX169 4                SMAX170 4             
   SMAX171 4                SMAX172 4                SMAX173 4             
   SMAX174 4                SMAX175 4                SMAX176 4             
   SMAX177 4                SMAX178 4                SMAX179 4             
   SMAX180 4                SMAX181 4                SMAX182 4             
   SMAX183 4                SMAX184 4                SMAX185 4             
   SMAX186 4                SMAX187 4                SMAX188 4             
   SMAX189 4                SMAX190 4                SMAX191 4             
   SMAX192 4                SMAX193 4                SMAX194 4             
   SMAX195 4                SMAX196 4                SMAX197 4             
   SMAX198 4                SMAX199 4                SMAX200 4             
   SMAX201 4                SMAX202 4                SMAX203 4             
   SMAX204 4                SMAX205 4                SMAX206 4             
   SMAX207 4                SMAX208 4                SMAX209 4             
   SMAX210 4                SMAX211 4                SMAX212 4             
   SMAX213 4                SMAX214 4                SMAX215 4             
   SMAX216 4                SMAX217 4                SMAX218 4             
   SMAX219 4                SMAX220 4                SMAX221 4             
   SMAX222 4                SMAX223 4                SMAX224 4             
   SMAX225 4                SMAX226 4                SMAX227 4             
   SMAX228 4                SMAX229 4                SMAX230 4             
   SMAX231 4                SMAX232 4                SMAX233 4             
   SMAX234 4                SMAX235 4                SMAX236 4             
   SMAX237 4                SMAX238 4                SMAX239 4             
   SMAX240 4                SMAX241 4                SMAX242 4             
   SMAX243 4                SMAX244 4                SMAX245 4             
   SMAX246 4                SMAX247 4                SMAX248 4             
   SMAX249 4                SMAX250 4                SMAX251 4             
   SMAX252 4                SMAX253 4                SMAX254 4             
   SMAX255 4                SMAX256 4                SMAX257 4             
   SMAX258 4                SMAX259 4                SMAX260 4             
   SMAX261 4                SMAX262 4                SMAX263 4             
   SMAX264 4                SMAX265 4                SMAX266 4             
   SMAX267 4                SMAX268 4                SMAX269 4             
   SMAX270 4                SMAX271 4                SMAX272 4             
   SMAX273 4                SMAX274 4                SMAX275 4             
   SMAX276 4                SMAX277 4                SMAX278 4             
   SMAX279 4                SMAX280 4                SMAX281 4             
   SMAX282 4                SMAX283 4                SMAX284 4             
   SMAX285 4                SMAX286 4                SMAX287 4             
   SMAX288 4                SMAX289 4                SMAX290 4             
   SMAX291 4                SMAX292 4                SMAX293 4             
   SMAX294 4                SMAX295 4                SMAX296 4             
   SMAX297 4                SMAX298 4                SMAX299 4             
   SMAX300 4                SMAX301 4                SMAX302 4             
   SMAX303 4                SMAX304 4                SMAX305 4             
   SMAX306 4                SMAX307 4                SMAX308 4             
   SMAX309 4                SMAX310 4                SMAX311 4             
   SMAX312 4                SMAX313 4                SMAX314 4             
   SMAX315 4                SMAX316 4                SMAX317 4             
   SMAX318 4                SMAX319 4                SMAX320 4             
   SMAX321 4                SMAX322 4                SMAX323 4             
   SMAX324 4                SMAX325 4                SMAX326 4             
   SMAX327 4                SMAX328 4                SMAX329 4             
   SMAX330 4                SMAX331 4                SMAX332 4             
   SMAX333 4                SMAX334 4                SMAX335 4             
   SMAX336 4                SMAX337 4                SMAX338 4             
   SMAX339 4                SMAX340 4                SMAX341 4             
   SMAX342 4                SMAX343 4                SMAX344 4             
   SMAX345 4                SMAX346 4                SMAX347 4             
   SMAX348 4                SMAX349 4                SMAX350 4             
   SMAX351 4                SMAX352 4                SMAX353 4             
   SMAX354 4                SMAX355 4                SMAX356 4             
   SMAX357 4                SMAX358 4                SMAX359 4             
   SMAX360 4                SMAX361 4                SMAX362 4             
   SMAX363 4                SMAX364 4                SMAX365 4             
   SMAX366 4                SMAX367 4                SMAX368 4             
   SMAX369 4                SMAX370 4                SMAX371 4             
   SMAX372 4                SMAX373 4                SMAX374 4             
   SMAX375 4                SMAX376 4                SMAX377 4             
   SMAX378 4                SMAX379 4                SMAX380 4             
   SMAX381 4                SMAX382 4                SMAX383 4             
   SMAX384 4                SMAX385 4                SMAX386 4             
   SMAX387 4                SMAX388 4                SMAX389 4             
   SMAX390 4                SMAX391 4                SMAX392 4             
   SMAX393 4                SMAX394 4                SMAX395 4             
   SMAX396 4                SMAX397 4                SMAX398 4             
   SMAX399 4                SMAX400 4                SMAX401 4             
   SMAX402 4                SMAX403 4                SMAX404 4             
   SMAX405 4                SMAX406 4                SMAX407 4             
   SMAX408 4                SMAX409 4                SMAX410 4             
   SMAX411 4                SMAX412 4                SMAX413 4             
   SMAX414 4                SMAX415 4                SMAX416 4             
   SMAX417 4                SMAX418 4                SMAX419 4             
   SMAX420 4                SMAX421 4                SMAX422 4             
   SMAX423 4                SMAX424 4                SMAX425 4             
   SMAX426 4                SMAX427 4                SMAX428 4             
   SMAX429 4                SMAX430 4                SMAX431 4             
   SMAX432 4                SMAX433 4                SMAX434 4             
   SMAX435 4                SMAX436 4                SMAX437 4             
   SMAX438 4                SMAX439 4                SMAX440 4             
   SMAX441 4                SMAX442 4                SMAX443 4             
   SMAX444 4                SMAX445 4                SMAX446 4             
   SMAX447 4                SMAX448 4                SMAX449 4             
   SMAX450 4                SMAX451 4                SMAX452 4             
   SMAX453 4                SMAX454 4                SMAX455 4             
   SMAX456 4                SMAX457 4                SMAX458 4             
   SMAX459 4                SMAX460 4                SMAX461 4             
   SMAX462 4                SMAX463 4                SMAX464 4             
   SMAX465 4                SMAX466 4                SMAX467 4             
   SMAX468 4                SMAX469 4                SMAX470 4             
   SMAX471 4                SMAX472 4                SMAX473 4             
   SMAX474 4                SMAX475 4                SMAX476 4             
   SMAX477 4                SMAX478 4                SMAX479 4             
   SMAX480 4                SMAX481 4                SMAX482 4             
   SMAX483 4                SMAX484 4                SMAX485 4             
   SMAX486 4                SMAX487 4                SMAX488 4             
   SMAX489 4                SMAX490 4                SMAX491 4             
   SMAX492 4                SMAX493 4                SMAX494 4             
   SMAX495 4                CH5G13ST 3               TIMSERVD 4            
   TIMSERVM 4               SPECASSM 6               CHMAM3 3              
   CHMAM4 3                 CHMAM5 3                 CUNIT1 3              
   CUNIT2 3                 CUNIT3 3                 CUNIT4 3              
   CUNIT5 3                 CHEMTYP1 3               CHEMTYP2 3            
   CHEMTYP3 3               CHEMTYP4 3               CHEMTYP5 3            
   CAFROM2 3                CAFROM3 3                CAFROM4 3             
   CAFROM5 3                CATO2 3                  CATO3 3               
   CATO4 3                  CATO5 3                  REASON4 4             
   REASON5 4                REASON6 3                ABUS1 3               
   ABUS2 3                  ABUS3 3                  ABUS4 3               
   ABUS5 3                  ABUS6 3                  ABUS7 3               
   ABUS8 3                  ABUS9 3                  ABUS10 3              
   ABUS11 3                 ABUS12 3                 ABUS13 3              
   ABUS14 3                 ABUS15 3                 ABUS16 3              
   ABUS17 3                 ABUS18 3                 ABUS19 3              
   ABUS20 3                 ABUS21 3                 ABUS22 3              
   ABUS23 3                 ABUS24 3                 ABUS25 3              
   ABUS26 3                 ABUS27 3                 ABUS28 3              
   ABUS29 3                 ABUS30 3                 ABUS31 3              
   ABUS32 3                 ABUS33 3                 ABUS34 3              
   ABUS35 3                 ABUS36 3                 ABUS37 3              
   ABUS38 3                 ABUS39 3                 ABUS40 3              
   ABUS41 3                 ABUS42 3                 ABUSHI 3              
   ABUSR1 3                 ABUSR2 3                 ABUSR3 3              
   ABUSR4 3                 ABUSR5 3                 ABUSR6 3              
   ABUSR7 3                 ABUSR8 3                 ABUSR9 3              
   ABUSR10 3                ABUSR11 3                ABUSR12 3             
   ABUSR13 3                ABUSR14 3                ABUSR15 3             
   ABUSR16 3                ABUSR17 3                ABUSR18 3             
   ABUSR19 3                ABUSR20 3                ABUSR21 3             
   ABUSR22 3                ABUSR23 3                ABUSR24 3             
   ABUSR25 3                ABUSR26 3                ABUSR27 3             
   ABUSR28 3                ABUSR29 3                ABUSR30 3             
   ABUSR31 3                ABUSR32 3                ABUSR33 3             
   ABUSR34 3                ABUSR35 3                ABUSR36 3             
   ABUSR37 3                ABUSR38 3                ABUSR39 3             
   ABUSR40 3                ABUSR41 3                ABUSR42 3             
   ABUSRHI 3                ADJOFL1 3                ADJOFL2 3             
   ADJOFL3 3                ADJOFL4 3                ADJOFL5 3             
   ADJOFL6 3                ADJOFL7 3                ADJOFL8 3             
   ADJOFL9 3                ADJOFL10 3               ADJOFL11 3            
   ADJOFL12 3               ADJOFL13 3               ADJOFL14 3            
   ADJOFL15 3               ADJOFL16 3               ADJOFL17 3            
   ADJOFL18 3               ADJOFL19 3               ADJOFL20 3            
   ADJOFL21 3               ADJOFL22 3               ADJOFL23 3            
   ADJOFL24 3               ADJOFL25 3               ADJOFL26 3            
   ADJOFL27 3               ADJOFL28 3               ADJOFL29 3            
   ADJOFL30 3               ADJOFL31 3               ADJOFL32 3            
   ADJOFL33 3               ADJOFL34 3               ADJOFL35 3            
   ADJOFL36 3               ADJOFL37 3               ADJOFL38 3            
   ADJOFL39 3               ADJOFL40 3               ADJOFL41 3            
   ADJOFL42 3               ADJOFLHI 3               ADJOFR1 3             
   ADJOFR2 3                ADJOFR3 3                ADJOFR4 3             
   ADJOFR5 3                ADJOFR6 3                ADJOFR7 3             
   ADJOFR8 3                ADJOFR9 3                ADJOFR10 3            
   ADJOFR11 3               ADJOFR12 3               ADJOFR13 3            
   ADJOFR14 3               ADJOFR15 3               ADJOFR16 3            
   ADJOFR17 3               ADJOFR18 3               ADJOFR19 3            
   ADJOFR20 3               ADJOFR21 3               ADJOFR22 3            
   ADJOFR23 3               ADJOFR24 3               ADJOFR25 3            
   ADJOFR26 3               ADJOFR27 3               ADJOFR28 3            
   ADJOFR29 3               ADJOFR30 3               ADJOFR31 3            
   ADJOFR32 3               ADJOFR33 3               ADJOFR34 3            
   ADJOFR35 3               ADJOFR36 3               ADJOFR37 3            
   ADJOFR38 3               ADJOFR39 3               ADJOFR40 3            
   ADJOFR41 3               ADJOFR42 3               ADJOFRHI 3            
   ADJR_B1 3                ADJR_B2 3                ADJR_B3 3             
   ADJR_B4 3                ADJR_B5 3                ADJR_B6 3             
   ADJR_B7 3                ADJR_B8 3                ADJR_B9 3             
   ADJR_B10 3               ADJR_B11 3               ADJR_B12 3            
   ADJR_B13 3               ADJR_B14 3               ADJR_B15 3            
   ADJR_B16 3               ADJR_B17 3               ADJR_B18 3            
   ADJR_B19 3               ADJR_B20 3               ADJR_B21 3            
   ADJR_B22 3               ADJR_B23 3               ADJR_B24 3            
   ADJR_B25 3               ADJR_B26 3               ADJR_B27 3            
   ADJR_B28 3               ADJR_B29 3               ADJR_B30 3            
   ADJR_B31 3               ADJR_B32 3               ADJR_B33 3            
   ADJR_B34 3               ADJR_B35 3               ADJR_B36 3            
   ADJR_B37 3               ADJR_B38 3               ADJR_B39 3            
   ADJR_B40 3               ADJR_B41 3               ADJR_B42 3            
   ADJR_BHI 3               ADJR_C1 3                ADJR_C2 3             
   ADJR_C3 3                ADJR_C4 3                ADJR_C5 3             
   ADJR_C6 3                ADJR_C7 3                ADJR_C8 3             
   ADJR_C9 3                ADJR_C10 3               ADJR_C11 3            
   ADJR_C12 3               ADJR_C13 3               ADJR_C14 3            
   ADJR_C15 3               ADJR_C16 3               ADJR_C17 3            
   ADJR_C18 3               ADJR_C19 3               ADJR_C20 3            
   ADJR_C21 3               ADJR_C22 3               ADJR_C23 3            
   ADJR_C24 3               ADJR_C25 3               ADJR_C26 3            
   ADJR_C27 3               ADJR_C28 3               ADJR_C29 3            
   ADJR_C30 3               ADJR_C31 3               ADJR_C32 3            
   ADJR_C33 3               ADJR_C34 3               ADJR_C35 3            
   ADJR_C36 3               ADJR_C37 3               ADJR_C38 3            
   ADJR_C39 3               ADJR_C40 3               ADJR_C41 3            
   ADJR_C42 3               ADJR_CHI 3               ADJR_D1 3             
   ADJR_D2 3                ADJR_D3 3                ADJR_D4 3             
   ADJR_D5 3                ADJR_D6 3                ADJR_D7 3             
   ADJR_D8 3                ADJR_D9 3                ADJR_D10 3            
   ADJR_D11 3               ADJR_D12 3               ADJR_D13 3            
   ADJR_D14 3               ADJR_D15 3               ADJR_D16 3            
   ADJR_D17 3               ADJR_D18 3               ADJR_D19 3            
   ADJR_D20 3               ADJR_D21 3               ADJR_D22 3            
   ADJR_D23 3               ADJR_D24 3               ADJR_D25 3            
   ADJR_D26 3               ADJR_D27 3               ADJR_D28 3            
   ADJR_D29 3               ADJR_D30 3               ADJR_D31 3            
   ADJR_D32 3               ADJR_D33 3               ADJR_D34 3            
   ADJR_D35 3               ADJR_D36 3               ADJR_D37 3            
   ADJR_D38 3               ADJR_D39 3               ADJR_D40 3            
   ADJR_D41 3               ADJR_D42 3               ADJR_DHI 3            
   ADJR_E1 3                ADJR_E2 3                ADJR_E3 3             
   ADJR_E4 3                ADJR_E5 3                ADJR_E6 3             
   ADJR_E7 3                ADJR_E8 3                ADJR_E9 3             
   ADJR_E10 3               ADJR_E11 3               ADJR_E12 3            
   ADJR_E13 3               ADJR_E14 3               ADJR_E15 3            
   ADJR_E16 3               ADJR_E17 3               ADJR_E18 3            
   ADJR_E19 3               ADJR_E20 3               ADJR_E21 3            
   ADJR_E22 3               ADJR_E23 3               ADJR_E24 3            
   ADJR_E25 3               ADJR_E26 3               ADJR_E27 3            
   ADJR_E28 3               ADJR_E29 3               ADJR_E30 3            
   ADJR_E31 3               ADJR_E32 3               ADJR_E33 3            
   ADJR_E34 3               ADJR_E35 3               ADJR_E36 3            
   ADJR_E37 3               ADJR_E38 3               ADJR_E39 3            
   ADJR_E40 3               ADJR_E41 3               ADJR_E42 3            
   ADJR_EHI 3               ADJR_F1 3                ADJR_F2 3             
   ADJR_F3 3                ADJR_F4 3                ADJR_F5 3             
   ADJR_F6 3                ADJR_F7 3                ADJR_F8 3             
   ADJR_F9 3                ADJR_F10 3               ADJR_F11 3            
   ADJR_F12 3               ADJR_F13 3               ADJR_F14 3            
   ADJR_F15 3               ADJR_F16 3               ADJR_F17 3            
   ADJR_F18 3               ADJR_F19 3               ADJR_F20 3            
   ADJR_F21 3               ADJR_F22 3               ADJR_F23 3            
   ADJR_F24 3               ADJR_F25 3               ADJR_F26 3            
   ADJR_F27 3               ADJR_F28 3               ADJR_F29 3            
   ADJR_F30 3               ADJR_F31 3               ADJR_F32 3            
   ADJR_F33 3               ADJR_F34 3               ADJR_F35 3            
   ADJR_F36 3               ADJR_F37 3               ADJR_F38 3            
   ADJR_F39 3               ADJR_F40 3               ADJR_F41 3            
   ADJR_F42 3               ADJR_FHI 3               ADJR_G1 3             
   ADJR_G2 3                ADJR_G3 3                ADJR_G4 3             
   ADJR_G5 3                ADJR_G6 3                ADJR_G7 3             
   ADJR_G8 3                ADJR_G9 3                ADJR_G10 3            
   ADJR_G11 3               ADJR_G12 3               ADJR_G13 3            
   ADJR_G14 3               ADJR_G15 3               ADJR_G16 3            
   ADJR_G17 3               ADJR_G18 3               ADJR_G19 3            
   ADJR_G20 3               ADJR_G21 3               ADJR_G22 3            
   ADJR_G23 3               ADJR_G24 3               ADJR_G25 3            
   ADJR_G26 3               ADJR_G27 3               ADJR_G28 3            
   ADJR_G29 3               ADJR_G30 3               ADJR_G31 3            
   ADJR_G32 3               ADJR_G33 3               ADJR_G34 3            
   ADJR_G35 3               ADJR_G36 3               ADJR_G37 3            
   ADJR_G38 3               ADJR_G39 3               ADJR_G40 3            
   ADJR_G41 3               ADJR_G42 3               ADJR_GHI 3            
   ADJR_H1 3                ADJR_H2 3                ADJR_H3 3             
   ADJR_H4 3                ADJR_H5 3                ADJR_H6 3             
   ADJR_H7 3                ADJR_H8 3                ADJR_H9 3             
   ADJR_H10 3               ADJR_H11 3               ADJR_H12 3            
   ADJR_H13 3               ADJR_H14 3               ADJR_H15 3            
   ADJR_H16 3               ADJR_H17 3               ADJR_H18 3            
   ADJR_H19 3               ADJR_H20 3               ADJR_H21 3            
   ADJR_H22 3               ADJR_H23 3               ADJR_H24 3            
   ADJR_H25 3               ADJR_H26 3               ADJR_H27 3            
   ADJR_H28 3               ADJR_H29 3               ADJR_H30 3            
   ADJR_H31 3               ADJR_H32 3               ADJR_H33 3            
   ADJR_H34 3               ADJR_H35 3               ADJR_H36 3            
   ADJR_H37 3               ADJR_H38 3               ADJR_H39 3            
   ADJR_H40 3               ADJR_H41 3               ADJR_H42 3            
   ADJR_HHI 3               ADJR_I1 3                ADJR_I2 3             
   ADJR_I3 3                ADJR_I4 3                ADJR_I5 3             
   ADJR_I6 3                ADJR_I7 3                ADJR_I8 3             
   ADJR_I9 3                ADJR_I10 3               ADJR_I11 3            
   ADJR_I12 3               ADJR_I13 3               ADJR_I14 3            
   ADJR_I15 3               ADJR_I16 3               ADJR_I17 3            
   ADJR_I18 3               ADJR_I19 3               ADJR_I20 3            
   ADJR_I21 3               ADJR_I22 3               ADJR_I23 3            
   ADJR_I24 3               ADJR_I25 3               ADJR_I26 3            
   ADJR_I27 3               ADJR_I28 3               ADJR_I29 3            
   ADJR_I30 3               ADJR_I31 3               ADJR_I32 3            
   ADJR_I33 3               ADJR_I34 3               ADJR_I35 3            
   ADJR_I36 3               ADJR_I37 3               ADJR_I38 3            
   ADJR_I39 3               ADJR_I40 3               ADJR_I41 3            
   ADJR_I42 3               ADJR_IHI 3               ADJR_J1 3             
   ADJR_J2 3                ADJR_J3 3                ADJR_J4 3             
   ADJR_J5 3                ADJR_J6 3                ADJR_J7 3             
   ADJR_J8 3                ADJR_J9 3                ADJR_J10 3            
   ADJR_J11 3               ADJR_J12 3               ADJR_J13 3            
   ADJR_J14 3               ADJR_J15 3               ADJR_J16 3            
   ADJR_J17 3               ADJR_J18 3               ADJR_J19 3            
   ADJR_J20 3               ADJR_J21 3               ADJR_J22 3            
   ADJR_J23 3               ADJR_J24 3               ADJR_J25 3            
   ADJR_J26 3               ADJR_J27 3               ADJR_J28 3            
   ADJR_J29 3               ADJR_J30 3               ADJR_J31 3            
   ADJR_J32 3               ADJR_J33 3               ADJR_J34 3            
   ADJR_J35 3               ADJR_J36 3               ADJR_J37 3            
   ADJR_J38 3               ADJR_J39 3               ADJR_J40 3            
   ADJR_J41 3               ADJR_J42 3               ADJR_JHI 3            
   ADJR_K1 3                ADJR_K2 3                ADJR_K3 3             
   ADJR_K4 3                ADJR_K5 3                ADJR_K6 3             
   ADJR_K7 3                ADJR_K8 3                ADJR_K9 3             
   ADJR_K10 3               ADJR_K11 3               ADJR_K12 3            
   ADJR_K13 3               ADJR_K14 3               ADJR_K15 3            
   ADJR_K16 3               ADJR_K17 3               ADJR_K18 3            
   ADJR_K19 3               ADJR_K20 3               ADJR_K21 3            
   ADJR_K22 3               ADJR_K23 3               ADJR_K24 3            
   ADJR_K25 3               ADJR_K26 3               ADJR_K27 3            
   ADJR_K28 3               ADJR_K29 3               ADJR_K30 3            
   ADJR_K31 3               ADJR_K32 3               ADJR_K33 3            
   ADJR_K34 3               ADJR_K35 3               ADJR_K36 3            
   ADJR_K37 3               ADJR_K38 3               ADJR_K39 3            
   ADJR_K40 3               ADJR_K41 3               ADJR_K42 3            
   ADJR_KHI 3               ADJR_L1 3                ADJR_L2 3             
   ADJR_L3 3                ADJR_L4 3                ADJR_L5 3             
   ADJR_L6 3                ADJR_L7 3                ADJR_L8 3             
   ADJR_L9 3                ADJR_L10 3               ADJR_L11 3            
   ADJR_L12 3               ADJR_L13 3               ADJR_L14 3            
   ADJR_L15 3               ADJR_L16 3               ADJR_L17 3            
   ADJR_L18 3               ADJR_L19 3               ADJR_L20 3            
   ADJR_L21 3               ADJR_L22 3               ADJR_L23 3            
   ADJR_L24 3               ADJR_L25 3               ADJR_L26 3            
   ADJR_L27 3               ADJR_L28 3               ADJR_L29 3            
   ADJR_L30 3               ADJR_L31 3               ADJR_L32 3            
   ADJR_L33 3               ADJR_L34 3               ADJR_L35 3            
   ADJR_L36 3               ADJR_L37 3               ADJR_L38 3            
   ADJR_L39 3               ADJR_L40 3               ADJR_L41 3            
   ADJR_L42 3               ADJR_LHI 3               ADJR_M1 3             
   ADJR_M2 3                ADJR_M3 3                ADJR_M4 3             
   ADJR_M5 3                ADJR_M6 3                ADJR_M7 3             
   ADJR_M8 3                ADJR_M9 3                ADJR_M10 3            
   ADJR_M11 3               ADJR_M12 3               ADJR_M13 3            
   ADJR_M14 3               ADJR_M15 3               ADJR_M16 3            
   ADJR_M17 3               ADJR_M18 3               ADJR_M19 3            
   ADJR_M20 3               ADJR_M21 3               ADJR_M22 3            
   ADJR_M23 3               ADJR_M24 3               ADJR_M25 3            
   ADJR_M26 3               ADJR_M27 3               ADJR_M28 3            
   ADJR_M29 3               ADJR_M30 3               ADJR_M31 3            
   ADJR_M32 3               ADJR_M33 3               ADJR_M34 3            
   ADJR_M35 3               ADJR_M36 3               ADJR_M37 3            
   ADJR_M38 3               ADJR_M39 3               ADJR_M40 3            
   ADJR_M41 3               ADJR_M42 3               ADJR_MHI 3            
   ADJR_N1 3                ADJR_N2 3                ADJR_N3 3             
   ADJR_N4 3                ADJR_N5 3                ADJR_N6 3             
   ADJR_N7 3                ADJR_N8 3                ADJR_N9 3             
   ADJR_N10 3               ADJR_N11 3               ADJR_N12 3            
   ADJR_N13 3               ADJR_N14 3               ADJR_N15 3            
   ADJR_N16 3               ADJR_N17 3               ADJR_N18 3            
   ADJR_N19 3               ADJR_N20 3               ADJR_N21 3            
   ADJR_N22 3               ADJR_N23 3               ADJR_N24 3            
   ADJR_N25 3               ADJR_N26 3               ADJR_N27 3            
   ADJR_N28 3               ADJR_N29 3               ADJR_N30 3            
   ADJR_N31 3               ADJR_N32 3               ADJR_N33 3            
   ADJR_N34 3               ADJR_N35 3               ADJR_N36 3            
   ADJR_N37 3               ADJR_N38 3               ADJR_N39 3            
   ADJR_N40 3               ADJR_N41 3               ADJR_N42 3            
   ADJR_NHI 3               ADJR_O1 3                ADJR_O2 3             
   ADJR_O3 3                ADJR_O4 3                ADJR_O5 3             
   ADJR_O6 3                ADJR_O7 3                ADJR_O8 3             
   ADJR_O9 3                ADJR_O10 3               ADJR_O11 3            
   ADJR_O12 3               ADJR_O13 3               ADJR_O14 3            
   ADJR_O15 3               ADJR_O16 3               ADJR_O17 3            
   ADJR_O18 3               ADJR_O19 3               ADJR_O20 3            
   ADJR_O21 3               ADJR_O22 3               ADJR_O23 3            
   ADJR_O24 3               ADJR_O25 3               ADJR_O26 3            
   ADJR_O27 3               ADJR_O28 3               ADJR_O29 3            
   ADJR_O30 3               ADJR_O31 3               ADJR_O32 3            
   ADJR_O33 3               ADJR_O34 3               ADJR_O35 3            
   ADJR_O36 3               ADJR_O37 3               ADJR_O38 3            
   ADJR_O39 3               ADJR_O40 3               ADJR_O41 3            
   ADJR_O42 3               ADJR_OHI 3               ADJR_P1 3             
   ADJR_P2 3                ADJR_P3 3                ADJR_P4 3             
   ADJR_P5 3                ADJR_P6 3                ADJR_P7 3             
   ADJR_P8 3                ADJR_P9 3                ADJR_P10 3            
   ADJR_P11 3               ADJR_P12 3               ADJR_P13 3            
   ADJR_P14 3               ADJR_P15 3               ADJR_P16 3            
   ADJR_P17 3               ADJR_P18 3               ADJR_P19 3            
   ADJR_P20 3               ADJR_P21 3               ADJR_P22 3            
   ADJR_P23 3               ADJR_P24 3               ADJR_P25 3            
   ADJR_P26 3               ADJR_P27 3               ADJR_P28 3            
   ADJR_P29 3               ADJR_P30 3               ADJR_P31 3            
   ADJR_P32 3               ADJR_P33 3               ADJR_P34 3            
   ADJR_P35 3               ADJR_P36 3               ADJR_P37 3            
   ADJR_P38 3               ADJR_P39 3               ADJR_P40 3            
   ADJR_P41 3               ADJR_P42 3               ADJR_PHI 3            
   ADJ_B1 3                 ADJ_B2 3                 ADJ_B3 3              
   ADJ_B4 3                 ADJ_B5 3                 ADJ_B6 3              
   ADJ_B7 3                 ADJ_B8 3                 ADJ_B9 3              
   ADJ_B10 3                ADJ_B11 3                ADJ_B12 3             
   ADJ_B13 3                ADJ_B14 3                ADJ_B15 3             
   ADJ_B16 3                ADJ_B17 3                ADJ_B18 3             
   ADJ_B19 3                ADJ_B20 3                ADJ_B21 3             
   ADJ_B22 3                ADJ_B23 3                ADJ_B24 3             
   ADJ_B25 3                ADJ_B26 3                ADJ_B27 3             
   ADJ_B28 3                ADJ_B29 3                ADJ_B30 3             
   ADJ_B31 3                ADJ_B32 3                ADJ_B33 3             
   ADJ_B34 3                ADJ_B35 3                ADJ_B36 3             
   ADJ_B37 3                ADJ_B38 3                ADJ_B39 3             
   ADJ_B40 3                ADJ_B41 3                ADJ_B42 3             
   ADJ_BHI 3                ADJ_C1 3                 ADJ_C2 3              
   ADJ_C3 3                 ADJ_C4 3                 ADJ_C5 3              
   ADJ_C6 3                 ADJ_C7 3                 ADJ_C8 3              
   ADJ_C9 3                 ADJ_C10 3                ADJ_C11 3             
   ADJ_C12 3                ADJ_C13 3                ADJ_C14 3             
   ADJ_C15 3                ADJ_C16 3                ADJ_C17 3             
   ADJ_C18 3                ADJ_C19 3                ADJ_C20 3             
   ADJ_C21 3                ADJ_C22 3                ADJ_C23 3             
   ADJ_C24 3                ADJ_C25 3                ADJ_C26 3             
   ADJ_C27 3                ADJ_C28 3                ADJ_C29 3             
   ADJ_C30 3                ADJ_C31 3                ADJ_C32 3             
   ADJ_C33 3                ADJ_C34 3                ADJ_C35 3             
   ADJ_C36 3                ADJ_C37 3                ADJ_C38 3             
   ADJ_C39 3                ADJ_C40 3                ADJ_C41 3             
   ADJ_C42 3                ADJ_CHI 3                ADJ_D1 3              
   ADJ_D2 3                 ADJ_D3 3                 ADJ_D4 3              
   ADJ_D5 3                 ADJ_D6 3                 ADJ_D7 3              
   ADJ_D8 3                 ADJ_D9 3                 ADJ_D10 3             
   ADJ_D11 3                ADJ_D12 3                ADJ_D13 3             
   ADJ_D14 3                ADJ_D15 3                ADJ_D16 3             
   ADJ_D17 3                ADJ_D18 3                ADJ_D19 3             
   ADJ_D20 3                ADJ_D21 3                ADJ_D22 3             
   ADJ_D23 3                ADJ_D24 3                ADJ_D25 3             
   ADJ_D26 3                ADJ_D27 3                ADJ_D28 3             
   ADJ_D29 3                ADJ_D30 3                ADJ_D31 3             
   ADJ_D32 3                ADJ_D33 3                ADJ_D34 3             
   ADJ_D35 3                ADJ_D36 3                ADJ_D37 3             
   ADJ_D38 3                ADJ_D39 3                ADJ_D40 3             
   ADJ_D41 3                ADJ_D42 3                ADJ_DHI 3             
   ADJ_E1 3                 ADJ_E2 3                 ADJ_E3 3              
   ADJ_E4 3                 ADJ_E5 3                 ADJ_E6 3              
   ADJ_E7 3                 ADJ_E8 3                 ADJ_E9 3              
   ADJ_E10 3                ADJ_E11 3                ADJ_E12 3             
   ADJ_E13 3                ADJ_E14 3                ADJ_E15 3             
   ADJ_E16 3                ADJ_E17 3                ADJ_E18 3             
   ADJ_E19 3                ADJ_E20 3                ADJ_E21 3             
   ADJ_E22 3                ADJ_E23 3                ADJ_E24 3             
   ADJ_E25 3                ADJ_E26 3                ADJ_E27 3             
   ADJ_E28 3                ADJ_E29 3                ADJ_E30 3             
   ADJ_E31 3                ADJ_E32 3                ADJ_E33 3             
   ADJ_E34 3                ADJ_E35 3                ADJ_E36 3             
   ADJ_E37 3                ADJ_E38 3                ADJ_E39 3             
   ADJ_E40 3                ADJ_E41 3                ADJ_E42 3             
   ADJ_EHI 3                ADJ_F1 3                 ADJ_F2 3              
   ADJ_F3 3                 ADJ_F4 3                 ADJ_F5 3              
   ADJ_F6 3                 ADJ_F7 3                 ADJ_F8 3              
   ADJ_F9 3                 ADJ_F10 3                ADJ_F11 3             
   ADJ_F12 3                ADJ_F13 3                ADJ_F14 3             
   ADJ_F15 3                ADJ_F16 3                ADJ_F17 3             
   ADJ_F18 3                ADJ_F19 3                ADJ_F20 3             
   ADJ_F21 3                ADJ_F22 3                ADJ_F23 3             
   ADJ_F24 3                ADJ_F25 3                ADJ_F26 3             
   ADJ_F27 3                ADJ_F28 3                ADJ_F29 3             
   ADJ_F30 3                ADJ_F31 3                ADJ_F32 3             
   ADJ_F33 3                ADJ_F34 3                ADJ_F35 3             
   ADJ_F36 3                ADJ_F37 3                ADJ_F38 3             
   ADJ_F39 3                ADJ_F40 3                ADJ_F41 3             
   ADJ_F42 3                ADJ_FHI 3                ADJ_G1 3              
   ADJ_G2 3                 ADJ_G3 3                 ADJ_G4 3              
   ADJ_G5 3                 ADJ_G6 3                 ADJ_G7 3              
   ADJ_G8 3                 ADJ_G9 3                 ADJ_G10 3             
   ADJ_G11 3                ADJ_G12 3                ADJ_G13 3             
   ADJ_G14 3                ADJ_G15 3                ADJ_G16 3             
   ADJ_G17 3                ADJ_G18 3                ADJ_G19 3             
   ADJ_G20 3                ADJ_G21 3                ADJ_G22 3             
   ADJ_G23 3                ADJ_G24 3                ADJ_G25 3             
   ADJ_G26 3                ADJ_G27 3                ADJ_G28 3             
   ADJ_G29 3                ADJ_G30 3                ADJ_G31 3             
   ADJ_G32 3                ADJ_G33 3                ADJ_G34 3             
   ADJ_G35 3                ADJ_G36 3                ADJ_G37 3             
   ADJ_G38 3                ADJ_G39 3                ADJ_G40 3             
   ADJ_G41 3                ADJ_G42 3                ADJ_GHI 3             
   ADJ_H1 3                 ADJ_H2 3                 ADJ_H3 3              
   ADJ_H4 3                 ADJ_H5 3                 ADJ_H6 3              
   ADJ_H7 3                 ADJ_H8 3                 ADJ_H9 3              
   ADJ_H10 3                ADJ_H11 3                ADJ_H12 3             
   ADJ_H13 3                ADJ_H14 3                ADJ_H15 3             
   ADJ_H16 3                ADJ_H17 3                ADJ_H18 3             
   ADJ_H19 3                ADJ_H20 3                ADJ_H21 3             
   ADJ_H22 3                ADJ_H23 3                ADJ_H24 3             
   ADJ_H25 3                ADJ_H26 3                ADJ_H27 3             
   ADJ_H28 3                ADJ_H29 3                ADJ_H30 3             
   ADJ_H31 3                ADJ_H32 3                ADJ_H33 3             
   ADJ_H34 3                ADJ_H35 3                ADJ_H36 3             
   ADJ_H37 3                ADJ_H38 3                ADJ_H39 3             
   ADJ_H40 3                ADJ_H41 3                ADJ_H42 3             
   ADJ_HHI 3                ADJ_I1 3                 ADJ_I2 3              
   ADJ_I3 3                 ADJ_I4 3                 ADJ_I5 3              
   ADJ_I6 3                 ADJ_I7 3                 ADJ_I8 3              
   ADJ_I9 3                 ADJ_I10 3                ADJ_I11 3             
   ADJ_I12 3                ADJ_I13 3                ADJ_I14 3             
   ADJ_I15 3                ADJ_I16 3                ADJ_I17 3             
   ADJ_I18 3                ADJ_I19 3                ADJ_I20 3             
   ADJ_I21 3                ADJ_I22 3                ADJ_I23 3             
   ADJ_I24 3                ADJ_I25 3                ADJ_I26 3             
   ADJ_I27 3                ADJ_I28 3                ADJ_I29 3             
   ADJ_I30 3                ADJ_I31 3                ADJ_I32 3             
   ADJ_I33 3                ADJ_I34 3                ADJ_I35 3             
   ADJ_I36 3                ADJ_I37 3                ADJ_I38 3             
   ADJ_I39 3                ADJ_I40 3                ADJ_I41 3             
   ADJ_I42 3                ADJ_IHI 3                ADJ_J1 3              
   ADJ_J2 3                 ADJ_J3 3                 ADJ_J4 3              
   ADJ_J5 3                 ADJ_J6 3                 ADJ_J7 3              
   ADJ_J8 3                 ADJ_J9 3                 ADJ_J10 3             
   ADJ_J11 3                ADJ_J12 3                ADJ_J13 3             
   ADJ_J14 3                ADJ_J15 3                ADJ_J16 3             
   ADJ_J17 3                ADJ_J18 3                ADJ_J19 3             
   ADJ_J20 3                ADJ_J21 3                ADJ_J22 3             
   ADJ_J23 3                ADJ_J24 3                ADJ_J25 3             
   ADJ_J26 3                ADJ_J27 3                ADJ_J28 3             
   ADJ_J29 3                ADJ_J30 3                ADJ_J31 3             
   ADJ_J32 3                ADJ_J33 3                ADJ_J34 3             
   ADJ_J35 3                ADJ_J36 3                ADJ_J37 3             
   ADJ_J38 3                ADJ_J39 3                ADJ_J40 3             
   ADJ_J41 3                ADJ_J42 3                ADJ_JHI 3             
   ADJ_K1 3                 ADJ_K2 3                 ADJ_K3 3              
   ADJ_K4 3                 ADJ_K5 3                 ADJ_K6 3              
   ADJ_K7 3                 ADJ_K8 3                 ADJ_K9 3              
   ADJ_K10 3                ADJ_K11 3                ADJ_K12 3             
   ADJ_K13 3                ADJ_K14 3                ADJ_K15 3             
   ADJ_K16 3                ADJ_K17 3                ADJ_K18 3             
   ADJ_K19 3                ADJ_K20 3                ADJ_K21 3             
   ADJ_K22 3                ADJ_K23 3                ADJ_K24 3             
   ADJ_K25 3                ADJ_K26 3                ADJ_K27 3             
   ADJ_K28 3                ADJ_K29 3                ADJ_K30 3             
   ADJ_K31 3                ADJ_K32 3                ADJ_K33 3             
   ADJ_K34 3                ADJ_K35 3                ADJ_K36 3             
   ADJ_K37 3                ADJ_K38 3                ADJ_K39 3             
   ADJ_K40 3                ADJ_K41 3                ADJ_K42 3             
   ADJ_KHI 3                ADJ_L1 3                 ADJ_L2 3              
   ADJ_L3 3                 ADJ_L4 3                 ADJ_L5 3              
   ADJ_L6 3                 ADJ_L7 3                 ADJ_L8 3              
   ADJ_L9 3                 ADJ_L10 3                ADJ_L11 3             
   ADJ_L12 3                ADJ_L13 3                ADJ_L14 3             
   ADJ_L15 3                ADJ_L16 3                ADJ_L17 3             
   ADJ_L18 3                ADJ_L19 3                ADJ_L20 3             
   ADJ_L21 3                ADJ_L22 3                ADJ_L23 3             
   ADJ_L24 3                ADJ_L25 3                ADJ_L26 3             
   ADJ_L27 3                ADJ_L28 3                ADJ_L29 3             
   ADJ_L30 3                ADJ_L31 3                ADJ_L32 3             
   ADJ_L33 3                ADJ_L34 3                ADJ_L35 3             
   ADJ_L36 3                ADJ_L37 3                ADJ_L38 3             
   ADJ_L39 3                ADJ_L40 3                ADJ_L41 3             
   ADJ_L42 3                ADJ_LHI 3                ADJ_M1 3              
   ADJ_M2 3                 ADJ_M3 3                 ADJ_M4 3              
   ADJ_M5 3                 ADJ_M6 3                 ADJ_M7 3              
   ADJ_M8 3                 ADJ_M9 3                 ADJ_M10 3             
   ADJ_M11 3                ADJ_M12 3                ADJ_M13 3             
   ADJ_M14 3                ADJ_M15 3                ADJ_M16 3             
   ADJ_M17 3                ADJ_M18 3                ADJ_M19 3             
   ADJ_M20 3                ADJ_M21 3                ADJ_M22 3             
   ADJ_M23 3                ADJ_M24 3                ADJ_M25 3             
   ADJ_M26 3                ADJ_M27 3                ADJ_M28 3             
   ADJ_M29 3                ADJ_M30 3                ADJ_M31 3             
   ADJ_M32 3                ADJ_M33 3                ADJ_M34 3             
   ADJ_M35 3                ADJ_M36 3                ADJ_M37 3             
   ADJ_M38 3                ADJ_M39 3                ADJ_M40 3             
   ADJ_M41 3                ADJ_M42 3                ADJ_MHI 3             
   ADJ_N1 3                 ADJ_N2 3                 ADJ_N3 3              
   ADJ_N4 3                 ADJ_N5 3                 ADJ_N6 3              
   ADJ_N7 3                 ADJ_N8 3                 ADJ_N9 3              
   ADJ_N10 3                ADJ_N11 3                ADJ_N12 3             
   ADJ_N13 3                ADJ_N14 3                ADJ_N15 3             
   ADJ_N16 3                ADJ_N17 3                ADJ_N18 3             
   ADJ_N19 3                ADJ_N20 3                ADJ_N21 3             
   ADJ_N22 3                ADJ_N23 3                ADJ_N24 3             
   ADJ_N25 3                ADJ_N26 3                ADJ_N27 3             
   ADJ_N28 3                ADJ_N29 3                ADJ_N30 3             
   ADJ_N31 3                ADJ_N32 3                ADJ_N33 3             
   ADJ_N34 3                ADJ_N35 3                ADJ_N36 3             
   ADJ_N37 3                ADJ_N38 3                ADJ_N39 3             
   ADJ_N40 3                ADJ_N41 3                ADJ_N42 3             
   ADJ_NHI 3                ADJ_O1 3                 ADJ_O2 3              
   ADJ_O3 3                 ADJ_O4 3                 ADJ_O5 3              
   ADJ_O6 3                 ADJ_O7 3                 ADJ_O8 3              
   ADJ_O9 3                 ADJ_O10 3                ADJ_O11 3             
   ADJ_O12 3                ADJ_O13 3                ADJ_O14 3             
   ADJ_O15 3                ADJ_O16 3                ADJ_O17 3             
   ADJ_O18 3                ADJ_O19 3                ADJ_O20 3             
   ADJ_O21 3                ADJ_O22 3                ADJ_O23 3             
   ADJ_O24 3                ADJ_O25 3                ADJ_O26 3             
   ADJ_O27 3                ADJ_O28 3                ADJ_O29 3             
   ADJ_O30 3                ADJ_O31 3                ADJ_O32 3             
   ADJ_O33 3                ADJ_O34 3                ADJ_O35 3             
   ADJ_O36 3                ADJ_O37 3                ADJ_O38 3             
   ADJ_O39 3                ADJ_O40 3                ADJ_O41 3             
   ADJ_O42 3                ADJ_OHI 3                ADJ_P1 3              
   ADJ_P2 3                 ADJ_P3 3                 ADJ_P4 3              
   ADJ_P5 3                 ADJ_P6 3                 ADJ_P7 3              
   ADJ_P8 3                 ADJ_P9 3                 ADJ_P10 3             
   ADJ_P11 3                ADJ_P12 3                ADJ_P13 3             
   ADJ_P14 3                ADJ_P15 3                ADJ_P16 3             
   ADJ_P17 3                ADJ_P18 3                ADJ_P19 3             
   ADJ_P20 3                ADJ_P21 3                ADJ_P22 3             
   ADJ_P23 3                ADJ_P24 3                ADJ_P25 3             
   ADJ_P26 3                ADJ_P27 3                ADJ_P28 3             
   ADJ_P29 3                ADJ_P30 3                ADJ_P31 3             
   ADJ_P32 3                ADJ_P33 3                ADJ_P34 3             
   ADJ_P35 3                ADJ_P36 3                ADJ_P37 3             
   ADJ_P38 3                ADJ_P39 3                ADJ_P40 3             
   ADJ_P41 3                ADJ_P42 3                ADJ_PHI 3             
   AGGRLR1 3                AGGRLR2 3                AGGRLR3 3             
   AGGRLR4 3                AGGRLR5 3                AGGRLR6 3             
   AGGRLR7 3                AGGRLR8 3                AGGRLR9 3             
   AGGRLR10 3               AGGRLR11 3               AGGRLR12 3            
   AGGRLR13 3               AGGRLR14 3               AGGRLR15 3            
   AGGRLR16 3               AGGRLR17 3               AGGRLR18 3            
   AGGRLR19 3               AGGRLR20 3               AGGRLR21 3            
   AGGRLR22 3               AGGRLR23 3               AGGRLR24 3            
   AGGRLR25 3               AGGRLR26 3               AGGRLR27 3            
   AGGRLR28 3               AGGRLR29 3               AGGRLR30 3            
   AGGRLR31 3               AGGRLR32 3               AGGRLR33 3            
   AGGRLR34 3               AGGRLR35 3               AGGRLR36 3            
   AGGRLR37 3               AGGRLR38 3               AGGRLR39 3            
   AGGRLR40 3               AGGRLR41 3               AGGRLR42 3            
   AGGRLRHI 3               AGGROL1 3                AGGROL2 3             
   AGGROL3 3                AGGROL4 3                AGGROL5 3             
   AGGROL6 3                AGGROL7 3                AGGROL8 3             
   AGGROL9 3                AGGROL10 3               AGGROL11 3            
   AGGROL12 3               AGGROL13 3               AGGROL14 3            
   AGGROL15 3               AGGROL16 3               AGGROL17 3            
   AGGROL18 3               AGGROL19 3               AGGROL20 3            
   AGGROL21 3               AGGROL22 3               AGGROL23 3            
   AGGROL24 3               AGGROL25 3               AGGROL26 3            
   AGGROL27 3               AGGROL28 3               AGGROL29 3            
   AGGROL30 3               AGGROL31 3               AGGROL32 3            
   AGGROL33 3               AGGROL34 3               AGGROL35 3            
   AGGROL36 3               AGGROL37 3               AGGROL38 3            
   AGGROL39 3               AGGROL40 3               AGGROL41 3            
   AGGROL42 3               AGGROLHI 3               BASADJ1 3             
   BASADJ2 3                BASADJ3 3                BASADJ4 3             
   BASADJ5 3                BASADJ6 3                BASADJ7 3             
   BASADJ8 3                BASADJ9 3                BASADJ10 3            
   BASADJ11 3               BASADJ12 3               BASADJ13 3            
   BASADJ14 3               BASADJ15 3               BASADJ16 3            
   BASADJ17 3               BASADJ18 3               BASADJ19 3            
   BASADJ20 3               BASADJ21 3               BASADJ22 3            
   BASADJ23 3               BASADJ24 3               BASADJ25 3            
   BASADJ26 3               BASADJ27 3               BASADJ28 3            
   BASADJ29 3               BASADJ30 3               BASADJ31 3            
   BASADJ32 3               BASADJ33 3               BASADJ34 3            
   BASADJ35 3               BASADJ36 3               BASADJ37 3            
   BASADJ38 3               BASADJ39 3               BASADJ40 3            
   BASADJ41 3               BASADJ42 3               BASADJHI 3            
   BASADR1 3                BASADR2 3                BASADR3 3             
   BASADR4 3                BASADR5 3                BASADR6 3             
   BASADR7 3                BASADR8 3                BASADR9 3             
   BASADR10 3               BASADR11 3               BASADR12 3            
   BASADR13 3               BASADR14 3               BASADR15 3            
   BASADR16 3               BASADR17 3               BASADR18 3            
   BASADR19 3               BASADR20 3               BASADR21 3            
   BASADR22 3               BASADR23 3               BASADR24 3            
   BASADR25 3               BASADR26 3               BASADR27 3            
   BASADR28 3               BASADR29 3               BASADR30 3            
   BASADR31 3               BASADR32 3               BASADR33 3            
   BASADR34 3               BASADR35 3               BASADR36 3            
   BASADR37 3               BASADR38 3               BASADR39 3            
   BASADR40 3               BASADR41 3               BASADR42 3            
   BASADRHI 3               BASE1 3                  BASE2 3               
   BASE3 3                  BASE4 3                  BASE5 3               
   BASE6 3                  BASE7 3                  BASE8 3               
   BASE9 3                  BASE10 3                 BASE11 3              
   BASE12 3                 BASE13 3                 BASE14 3              
   BASE15 3                 BASE16 3                 BASE17 3              
   BASE18 3                 BASE19 3                 BASE20 3              
   BASE21 3                 BASE22 3                 BASE23 3              
   BASE24 3                 BASE25 3                 BASE26 3              
   BASE27 3                 BASE28 3                 BASE29 3              
   BASE30 3                 BASE31 3                 BASE32 3              
   BASE33 3                 BASE34 3                 BASE35 3              
   BASE36 3                 BASE37 3                 BASE38 3              
   BASE39 3                 BASE40 3                 BASE41 3              
   BASE42 3                 BASEHI 3                 BASER1 3              
   BASER2 3                 BASER3 3                 BASER4 3              
   BASER5 3                 BASER6 3                 BASER7 3              
   BASER8 3                 BASER9 3                 BASER10 3             
   BASER11 3                BASER12 3                BASER13 3             
   BASER14 3                BASER15 3                BASER16 3             
   BASER17 3                BASER18 3                BASER19 3             
   BASER20 3                BASER21 3                BASER22 3             
   BASER23 3                BASER24 3                BASER25 3             
   BASER26 3                BASER27 3                BASER28 3             
   BASER29 3                BASER30 3                BASER31 3             
   BASER32 3                BASER33 3                BASER34 3             
   BASER35 3                BASER36 3                BASER37 3             
   BASER38 3                BASER39 3                BASER40 3             
   BASER41 3                BASER42 3                BASERHI 3             
   FLGHTR1 3                FLGHTR2 3                FLGHTR3 3             
   FLGHTR4 3                FLGHTR5 3                FLGHTR6 3             
   FLGHTR7 3                FLGHTR8 3                FLGHTR9 3             
   FLGHTR10 3               FLGHTR11 3               FLGHTR12 3            
   FLGHTR13 3               FLGHTR14 3               FLGHTR15 3            
   FLGHTR16 3               FLGHTR17 3               FLGHTR18 3            
   FLGHTR19 3               FLGHTR20 3               FLGHTR21 3            
   FLGHTR22 3               FLGHTR23 3               FLGHTR24 3            
   FLGHTR25 3               FLGHTR26 3               FLGHTR27 3            
   FLGHTR28 3               FLGHTR29 3               FLGHTR30 3            
   FLGHTR31 3               FLGHTR32 3               FLGHTR33 3            
   FLGHTR34 3               FLGHTR35 3               FLGHTR36 3            
   FLGHTR37 3               FLGHTR38 3               FLGHTR39 3            
   FLGHTR40 3               FLGHTR41 3               FLGHTR42 3            
   FLGHTRHI 3               FLIGHT1 3                FLIGHT2 3             
   FLIGHT3 3                FLIGHT4 3                FLIGHT5 3             
   FLIGHT6 3                FLIGHT7 3                FLIGHT8 3             
   FLIGHT9 3                FLIGHT10 3               FLIGHT11 3            
   FLIGHT12 3               FLIGHT13 3               FLIGHT14 3            
   FLIGHT15 3               FLIGHT16 3               FLIGHT17 3            
   FLIGHT18 3               FLIGHT19 3               FLIGHT20 3            
   FLIGHT21 3               FLIGHT22 3               FLIGHT23 3            
   FLIGHT24 3               FLIGHT25 3               FLIGHT26 3            
   FLIGHT27 3               FLIGHT28 3               FLIGHT29 3            
   FLIGHT30 3               FLIGHT31 3               FLIGHT32 3            
   FLIGHT33 3               FLIGHT34 3               FLIGHT35 3            
   FLIGHT36 3               FLIGHT37 3               FLIGHT38 3            
   FLIGHT39 3               FLIGHT40 3               FLIGHT41 3            
   FLIGHT42 3               FLIGHTHI 3               MITRLR1 3             
   MITRLR2 3                MITRLR3 3                MITRLR4 3             
   MITRLR5 3                MITRLR6 3                MITRLR7 3             
   MITRLR8 3                MITRLR9 3                MITRLR10 3            
   MITRLR11 3               MITRLR12 3               MITRLR13 3            
   MITRLR14 3               MITRLR15 3               MITRLR16 3            
   MITRLR17 3               MITRLR18 3               MITRLR19 3            
   MITRLR20 3               MITRLR21 3               MITRLR22 3            
   MITRLR23 3               MITRLR24 3               MITRLR25 3            
   MITRLR26 3               MITRLR27 3               MITRLR28 3            
   MITRLR29 3               MITRLR30 3               MITRLR31 3            
   MITRLR32 3               MITRLR33 3               MITRLR34 3            
   MITRLR35 3               MITRLR36 3               MITRLR37 3            
   MITRLR38 3               MITRLR39 3               MITRLR40 3            
   MITRLR41 3               MITRLR42 3               MITRLRHI 3            
   MITROL1 3                MITROL2 3                MITROL3 3             
   MITROL4 3                MITROL5 3                MITROL6 3             
   MITROL7 3                MITROL8 3                MITROL9 3             
   MITROL10 3               MITROL11 3               MITROL12 3            
   MITROL13 3               MITROL14 3               MITROL15 3            
   MITROL16 3               MITROL17 3               MITROL18 3            
   MITROL19 3               MITROL20 3               MITROL21 3            
   MITROL22 3               MITROL23 3               MITROL24 3            
   MITROL25 3               MITROL26 3               MITROL27 3            
   MITROL28 3               MITROL29 3               MITROL30 3            
   MITROL31 3               MITROL32 3               MITROL33 3            
   MITROL34 3               MITROL35 3               MITROL36 3            
   MITROL37 3               MITROL38 3               MITROL39 3            
   MITROL40 3               MITROL41 3               MITROL42 3            
   MITROLHI 3               OBSTRC1 3                OBSTRC2 3             
   OBSTRC3 3                OBSTRC4 3                OBSTRC5 3             
   OBSTRC6 3                OBSTRC7 3                OBSTRC8 3             
   OBSTRC9 3                OBSTRC10 3               OBSTRC11 3            
   OBSTRC12 3               OBSTRC13 3               OBSTRC14 3            
   OBSTRC15 3               OBSTRC16 3               OBSTRC17 3            
   OBSTRC18 3               OBSTRC19 3               OBSTRC20 3            
   OBSTRC21 3               OBSTRC22 3               OBSTRC23 3            
   OBSTRC24 3               OBSTRC25 3               OBSTRC26 3            
   OBSTRC27 3               OBSTRC28 3               OBSTRC29 3            
   OBSTRC30 3               OBSTRC31 3               OBSTRC32 3            
   OBSTRC33 3               OBSTRC34 3               OBSTRC35 3            
   OBSTRC36 3               OBSTRC37 3               OBSTRC38 3            
   OBSTRC39 3               OBSTRC40 3               OBSTRC41 3            
   OBSTRC42 3               OBSTRCHI 3               OBSTRR1 3             
   OBSTRR2 3                OBSTRR3 3                OBSTRR4 3             
   OBSTRR5 3                OBSTRR6 3                OBSTRR7 3             
   OBSTRR8 3                OBSTRR9 3                OBSTRR10 3            
   OBSTRR11 3               OBSTRR12 3               OBSTRR13 3            
   OBSTRR14 3               OBSTRR15 3               OBSTRR16 3            
   OBSTRR17 3               OBSTRR18 3               OBSTRR19 3            
   OBSTRR20 3               OBSTRR21 3               OBSTRR22 3            
   OBSTRR23 3               OBSTRR24 3               OBSTRR25 3            
   OBSTRR26 3               OBSTRR27 3               OBSTRR28 3            
   OBSTRR29 3               OBSTRR30 3               OBSTRR31 3            
   OBSTRR32 3               OBSTRR33 3               OBSTRR34 3            
   OBSTRR35 3               OBSTRR36 3               OBSTRR37 3            
   OBSTRR38 3               OBSTRR39 3               OBSTRR40 3            
   OBSTRR41 3               OBSTRR42 3               OBSTRRHI 3            
   OFFVCR1 3                OFFVCR2 3                OFFVCR3 3             
   OFFVCR4 3                OFFVCR5 3                OFFVCR6 3             
   OFFVCR7 3                OFFVCR8 3                OFFVCR9 3             
   OFFVCR10 3               OFFVCR11 3               OFFVCR12 3            
   OFFVCR13 3               OFFVCR14 3               OFFVCR15 3            
   OFFVCR16 3               OFFVCR17 3               OFFVCR18 3            
   OFFVCR19 3               OFFVCR20 3               OFFVCR21 3            
   OFFVCR22 3               OFFVCR23 3               OFFVCR24 3            
   OFFVCR25 3               OFFVCR26 3               OFFVCR27 3            
   OFFVCR28 3               OFFVCR29 3               OFFVCR30 3            
   OFFVCR31 3               OFFVCR32 3               OFFVCR33 3            
   OFFVCR34 3               OFFVCR35 3               OFFVCR36 3            
   OFFVCR37 3               OFFVCR38 3               OFFVCR39 3            
   OFFVCR40 3               OFFVCR41 3               OFFVCR42 3            
   OFFVCRHI 3               OFFVCT1 3                OFFVCT2 3             
   OFFVCT3 3                OFFVCT4 3                OFFVCT5 3             
   OFFVCT6 3                OFFVCT7 3                OFFVCT8 3             
   OFFVCT9 3                OFFVCT10 3               OFFVCT11 3            
   OFFVCT12 3               OFFVCT13 3               OFFVCT14 3            
   OFFVCT15 3               OFFVCT16 3               OFFVCT17 3            
   OFFVCT18 3               OFFVCT19 3               OFFVCT20 3            
   OFFVCT21 3               OFFVCT22 3               OFFVCT23 3            
   OFFVCT24 3               OFFVCT25 3               OFFVCT26 3            
   OFFVCT27 3               OFFVCT28 3               OFFVCT29 3            
   OFFVCT30 3               OFFVCT31 3               OFFVCT32 3            
   OFFVCT33 3               OFFVCT34 3               OFFVCT35 3            
   OFFVCT36 3               OFFVCT37 3               OFFVCT38 3            
   OFFVCT39 3               OFFVCT40 3               OFFVCT41 3            
   OFFVCT42 3               OFFVCTHI 3               RLADJR1 3             
   RLADJR2 3                RLADJR3 3                RLADJR4 3             
   RLADJR5 3                RLADJR6 3                RLADJR7 3             
   RLADJR8 3                RLADJR9 3                RLADJR10 3            
   RLADJR11 3               RLADJR12 3               RLADJR13 3            
   RLADJR14 3               RLADJR15 3               RLADJR16 3            
   RLADJR17 3               RLADJR18 3               RLADJR19 3            
   RLADJR20 3               RLADJR21 3               RLADJR22 3            
   RLADJR23 3               RLADJR24 3               RLADJR25 3            
   RLADJR26 3               RLADJR27 3               RLADJR28 3            
   RLADJR29 3               RLADJR30 3               RLADJR31 3            
   RLADJR32 3               RLADJR33 3               RLADJR34 3            
   RLADJR35 3               RLADJR36 3               RLADJR37 3            
   RLADJR38 3               RLADJR39 3               RLADJR40 3            
   RLADJR41 3               RLADJR42 3               RLADJRHI 3            
   ROLADJ1 3                ROLADJ2 3                ROLADJ3 3             
   ROLADJ4 3                ROLADJ5 3                ROLADJ6 3             
   ROLADJ7 3                ROLADJ8 3                ROLADJ9 3             
   ROLADJ10 3               ROLADJ11 3               ROLADJ12 3            
   ROLADJ13 3               ROLADJ14 3               ROLADJ15 3            
   ROLADJ16 3               ROLADJ17 3               ROLADJ18 3            
   ROLADJ19 3               ROLADJ20 3               ROLADJ21 3            
   ROLADJ22 3               ROLADJ23 3               ROLADJ24 3            
   ROLADJ25 3               ROLADJ26 3               ROLADJ27 3            
   ROLADJ28 3               ROLADJ29 3               ROLADJ30 3            
   ROLADJ31 3               ROLADJ32 3               ROLADJ33 3            
   ROLADJ34 3               ROLADJ35 3               ROLADJ36 3            
   ROLADJ37 3               ROLADJ38 3               ROLADJ39 3            
   ROLADJ40 3               ROLADJ41 3               ROLADJ42 3            
   ROLADJHI 3               RSTRVC1 3                RSTRVC2 3             
   RSTRVC3 3                RSTRVC4 3                RSTRVC5 3             
   RSTRVC6 3                RSTRVC7 3                RSTRVC8 3             
   RSTRVC9 3                RSTRVC10 3               RSTRVC11 3            
   RSTRVC12 3               RSTRVC13 3               RSTRVC14 3            
   RSTRVC15 3               RSTRVC16 3               RSTRVC17 3            
   RSTRVC18 3               RSTRVC19 3               RSTRVC20 3            
   RSTRVC21 3               RSTRVC22 3               RSTRVC23 3            
   RSTRVC24 3               RSTRVC25 3               RSTRVC26 3            
   RSTRVC27 3               RSTRVC28 3               RSTRVC29 3            
   RSTRVC30 3               RSTRVC31 3               RSTRVC32 3            
   RSTRVC33 3               RSTRVC34 3               RSTRVC35 3            
   RSTRVC36 3               RSTRVC37 3               RSTRVC38 3            
   RSTRVC39 3               RSTRVC40 3               RSTRVC41 3            
   RSTRVC42 3               RSTRVCHI 3               RSTRVR1 3             
   RSTRVR2 3                RSTRVR3 3                RSTRVR4 3             
   RSTRVR5 3                RSTRVR6 3                RSTRVR7 3             
   RSTRVR8 3                RSTRVR9 3                RSTRVR10 3            
   RSTRVR11 3               RSTRVR12 3               RSTRVR13 3            
   RSTRVR14 3               RSTRVR15 3               RSTRVR16 3            
   RSTRVR17 3               RSTRVR18 3               RSTRVR19 3            
   RSTRVR20 3               RSTRVR21 3               RSTRVR22 3            
   RSTRVR23 3               RSTRVR24 3               RSTRVR25 3            
   RSTRVR26 3               RSTRVR27 3               RSTRVR28 3            
   RSTRVR29 3               RSTRVR30 3               RSTRVR31 3            
   RSTRVR32 3               RSTRVR33 3               RSTRVR34 3            
   RSTRVR35 3               RSTRVR36 3               RSTRVR37 3            
   RSTRVR38 3               RSTRVR39 3               RSTRVR40 3            
   RSTRVR41 3               RSTRVR42 3               RSTRVRHI 3            
   TEROR1 3                 TEROR2 3                 TEROR3 3              
   TEROR4 3                 TEROR5 3                 TEROR6 3              
   TEROR7 3                 TEROR8 3                 TEROR9 3              
   TEROR10 3                TEROR11 3                TEROR12 3             
   TEROR13 3                TEROR14 3                TEROR15 3             
   TEROR16 3                TEROR17 3                TEROR18 3             
   TEROR19 3                TEROR20 3                TEROR21 3             
   TEROR22 3                TEROR23 3                TEROR24 3             
   TEROR25 3                TEROR26 3                TEROR27 3             
   TEROR28 3                TEROR29 3                TEROR30 3             
   TEROR31 3                TEROR32 3                TEROR33 3             
   TEROR34 3                TEROR35 3                TEROR36 3             
   TEROR37 3                TEROR38 3                TEROR39 3             
   TEROR40 3                TEROR41 3                TEROR42 3             
   TERORHI 3                TERORR1 3                TERORR2 3             
   TERORR3 3                TERORR4 3                TERORR5 3             
   TERORR6 3                TERORR7 3                TERORR8 3             
   TERORR9 3                TERORR10 3               TERORR11 3            
   TERORR12 3               TERORR13 3               TERORR14 3            
   TERORR15 3               TERORR16 3               TERORR17 3            
   TERORR18 3               TERORR19 3               TERORR20 3            
   TERORR21 3               TERORR22 3               TERORR23 3            
   TERORR24 3               TERORR25 3               TERORR26 3            
   TERORR27 3               TERORR28 3               TERORR29 3            
   TERORR30 3               TERORR31 3               TERORR32 3            
   TERORR33 3               TERORR34 3               TERORR35 3            
   TERORR36 3               TERORR37 3               TERORR38 3            
   TERORR39 3               TERORR40 3               TERORR41 3            
   TERORR42 3               TERORRHI 3               USKID1 3              
   USKID2 3                 USKID3 3                 USKID4 3              
   USKID5 3                 USKID6 3                 USKID7 3              
   USKID8 3                 USKID9 3                 USKID10 3             
   USKID11 3                USKID12 3                USKID13 3             
   USKID14 3                USKID15 3                USKID16 3             
   USKID17 3                USKID18 3                USKID19 3             
   USKID20 3                USKID21 3                USKID22 3             
   USKID23 3                USKID24 3                USKID25 3             
   USKID26 3                USKID27 3                USKID28 3             
   USKID29 3                USKID30 3                USKID31 3             
   USKID32 3                USKID33 3                USKID34 3             
   USKID35 3                USKID36 3                USKID37 3             
   USKID38 3                USKID39 3                USKID40 3             
   USKID41 3                USKID42 3                USKIDHI 3             
   USKIDR1 3                USKIDR2 3                USKIDR3 3             
   USKIDR4 3                USKIDR5 3                USKIDR6 3             
   USKIDR7 3                USKIDR8 3                USKIDR9 3             
   USKIDR10 3               USKIDR11 3               USKIDR12 3            
   USKIDR13 3               USKIDR14 3               USKIDR15 3            
   USKIDR16 3               USKIDR17 3               USKIDR18 3            
   USKIDR19 3               USKIDR20 3               USKIDR21 3            
   USKIDR22 3               USKIDR23 3               USKIDR24 3            
   USKIDR25 3               USKIDR26 3               USKIDR27 3            
   USKIDR28 3               USKIDR29 3               USKIDR30 3            
   USKIDR31 3               USKIDR32 3               USKIDR33 3            
   USKIDR34 3               USKIDR35 3               USKIDR36 3            
   USKIDR37 3               USKIDR38 3               USKIDR39 3            
   USKIDR40 3               USKIDR41 3               USKIDR42 3            
   USKIDRHI 3               VCADJR1 3                VCADJR2 3             
   VCADJR3 3                VCADJR4 3                VCADJR5 3             
   VCADJR6 3                VCADJR7 3                VCADJR8 3             
   VCADJR9 3                VCADJR10 3               VCADJR11 3            
   VCADJR12 3               VCADJR13 3               VCADJR14 3            
   VCADJR15 3               VCADJR16 3               VCADJR17 3            
   VCADJR18 3               VCADJR19 3               VCADJR20 3            
   VCADJR21 3               VCADJR22 3               VCADJR23 3            
   VCADJR24 3               VCADJR25 3               VCADJR26 3            
   VCADJR27 3               VCADJR28 3               VCADJR29 3            
   VCADJR30 3               VCADJR31 3               VCADJR32 3            
   VCADJR33 3               VCADJR34 3               VCADJR35 3            
   VCADJR36 3               VCADJR37 3               VCADJR38 3            
   VCADJR39 3               VCADJR40 3               VCADJR41 3            
   VCADJR42 3               VCADJRHI 3               VCTADJ1 3             
   VCTADJ2 3                VCTADJ3 3                VCTADJ4 3             
   VCTADJ5 3                VCTADJ6 3                VCTADJ7 3             
   VCTADJ8 3                VCTADJ9 3                VCTADJ10 3            
   VCTADJ11 3               VCTADJ12 3               VCTADJ13 3            
   VCTADJ14 3               VCTADJ15 3               VCTADJ16 3            
   VCTADJ17 3               VCTADJ18 3               VCTADJ19 3            
   VCTADJ20 3               VCTADJ21 3               VCTADJ22 3            
   VCTADJ23 3               VCTADJ24 3               VCTADJ25 3            
   VCTADJ26 3               VCTADJ27 3               VCTADJ28 3            
   VCTADJ29 3               VCTADJ30 3               VCTADJ31 3            
   VCTADJ32 3               VCTADJ33 3               VCTADJ34 3            
   VCTADJ35 3               VCTADJ36 3               VCTADJ37 3            
   VCTADJ38 3               VCTADJ39 3               VCTADJ40 3            
   VCTADJ41 3               VCTADJ42 3               VCTADJHI 3            
   VULVCR1 3                VULVCR2 3                VULVCR3 3             
   VULVCR4 3                VULVCR5 3                VULVCR6 3             
   VULVCR7 3                VULVCR8 3                VULVCR9 3             
   VULVCR10 3               VULVCR11 3               VULVCR12 3            
   VULVCR13 3               VULVCR14 3               VULVCR15 3            
   VULVCR16 3               VULVCR17 3               VULVCR18 3            
   VULVCR19 3               VULVCR20 3               VULVCR21 3            
   VULVCR22 3               VULVCR23 3               VULVCR24 3            
   VULVCR25 3               VULVCR26 3               VULVCR27 3            
   VULVCR28 3               VULVCR29 3               VULVCR30 3            
   VULVCR31 3               VULVCR32 3               VULVCR33 3            
   VULVCR34 3               VULVCR35 3               VULVCR36 3            
   VULVCR37 3               VULVCR38 3               VULVCR39 3            
   VULVCR40 3               VULVCR41 3               VULVCR42 3            
   VULVCRHI 3               VULVCT1 3                VULVCT2 3             
   VULVCT3 3                VULVCT4 3                VULVCT5 3             
   VULVCT6 3                VULVCT7 3                VULVCT8 3             
   VULVCT9 3                VULVCT10 3               VULVCT11 3            
   VULVCT12 3               VULVCT13 3               VULVCT14 3            
   VULVCT15 3               VULVCT16 3               VULVCT17 3            
   VULVCT18 3               VULVCT19 3               VULVCT20 3            
   VULVCT21 3               VULVCT22 3               VULVCT23 3            
   VULVCT24 3               VULVCT25 3               VULVCT26 3            
   VULVCT27 3               VULVCT28 3               VULVCT29 3            
   VULVCT30 3               VULVCT31 3               VULVCT32 3            
   VULVCT33 3               VULVCT34 3               VULVCT35 3            
   VULVCT36 3               VULVCT37 3               VULVCT38 3            
   VULVCT39 3               VULVCT40 3               VULVCT41 3            
   VULVCT42 3               VULVCTHI 3               LOSS17 4              
   LOSS18 4                 LOSS19 3                 LOSS20 3              
   LOSS21 3                 LOSS22 3                 LOSS23 3              
   LOSS24 3                 LOSS25 4                 LOSS26 3              
   LOSS27 3                 LOSS28 3                 LOSS29 3              
   LOSS30 3                 LOSS31 3                 LOSS32 3              
   LOSS33 3                 LOSS34 3                 LOSS35 3              
   LOSS36 3                 LOSS37 3                 LOSS38 3              
   LOSS39 3                 LOSS40 3                 LOSS41 6              
   LOSS42 3                 LOSSR6 6                 LOSSR7 3              
   LOSSR8 3                 LOSSR10 4                LOSSR11 6             
   LOSSR12 3                LOSSR13 3                LOSSR14 6             
   LOSSR15 4                LOSSR16 6                LOSSR17 3             
   LOSSR18 3                LOSSR19 3                LOSSR20 3             
   LOSSR21 3                LOSSR22 3                LOSSR23 3             
   LOSSR24 3                LOSSR25 3                LOSSR26 3             
   LOSSR27 3                LOSSR28 3                LOSSR29 3             
   LOSSR30 3                LOSSR31 3                LOSSR32 3             
   LOSSR33 3                LOSSR34 3                LOSSR35 3             
   LOSSR36 3                LOSSR37 3                LOSSR38 3             
   LOSSR39 3                LOSSR40 3                LOSSR41 3             
   LOSSR42 3                CRPTS 3                  DATO4 3               
   DATO5 3                  DAFROM4 4                DAFROM5 3             
   CH5G13YN 3               DEPART_S 3               DEPART_D 3 ;

      

RUN ;
